@@ -17,7 +17,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-/* $Id: class.boaddressbook.inc.php 4862 2010-02-19 13:54:57Z sigurd $ */
+/* $Id: class.boaddressbook.inc.php 13898 2015-09-15 09:15:53Z sigurdne $ */
 
 	class boaddressbook
 	{
@@ -46,7 +46,7 @@
 			'add_vcard' => true  // call from addressbook.uivcard.in to import a vcard
 		);
 
-		function boaddressbook($session=True)
+		function __construct($session=True)
 		{
 			$this->so = CreateObject('addressbook.soaddressbook');
 			$this->rights = $this->so->rights;
