@@ -17,7 +17,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-/* $Id: class.soaddressbook.inc.php 8976 2012-03-14 07:49:14Z sigurdne $ */
+/* $Id: class.soaddressbook.inc.php 13898 2015-09-15 09:15:53Z sigurdne $ */
 
 	class soaddressbook
 	{
@@ -62,7 +62,7 @@
 		*
 		* @param bool $useacl respect the access controls - should be true unless you know what you are doing
 		*/
-		function soaddressbook($useacl = true)
+		function __construct($useacl = true)
 		{
 			$this->contacts = CreateObject('phpgwapi.contacts');
 
