@@ -11,7 +11,7 @@
  *  option) any later version.                                              *
  \**************************************************************************/
 
-/* $Id: class.uifields.inc.php 3149 2009-06-20 15:40:33Z sigurd $ */
+/* $Id: class.uifields.inc.php 13920 2015-09-15 19:47:34Z sigurdne $ */
 
 	class uifields
 	{
@@ -23,7 +23,7 @@
 			'delete' => true
 		);
 
-		function uifields()
+		function __construct()
 		{
 			if ( !isset($GLOBALS['phpgw']->template) || !is_object($GLOBALS['phpgw']->template) )
 			{
@@ -510,7 +510,7 @@
 					}
 					if($new)
 					{
-						$tmp = strtolower(ereg_replace(' ','_',$new));
+						$tmp = strtolower(preg_replace('/ /','_',$new));
 						$this->config->config_data['custom_fields'][$tmp] = $new;
 					}
 					break;
@@ -533,7 +533,7 @@
 					}
 					if($new)
 					{
-						$tmp = strtolower(ereg_replace(' ','_',$new));
+						$tmp = strtolower(preg_replace('/ /','_',$new));
 						$this->config->config_data['custom_org_fields'][$tmp] = $new;
 					}
 					break;
@@ -556,7 +556,7 @@
 					}
 					if($new)
 					{
-						$tmp = strtolower(ereg_replace(' ','_',$new));
+						$tmp = strtolower(preg_replace('/ /','_',$new));
 						$this->config->config_data['custom_fields'][$tmp] = $new;
 					}
 					if(!is_array($this->config->config_data['custom_org_fields']))
@@ -571,7 +571,7 @@
 					}
 					if($new)
 					{
-						$tmp = strtolower(ereg_replace(' ','_',$new));
+						$tmp = strtolower(preg_replace('/ /','_',$new));
 						$this->config->config_data['custom_org_fields'][$tmp] = $new;
 					}
 					break;
