@@ -9,11 +9,11 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.boaccess_history.inc.php 6838 2011-01-25 07:37:07Z sigurdne $ */
+	/* $Id: class.boaccess_history.inc.php 13892 2015-09-14 20:07:23Z sigurdne $ */
 
 	class boaccess_history
 	{
-		function boaccess_history()
+		function __construct()
 		{
 			$this->so       = createobject('admin.soaccess_history');
 		}
