@@ -9,13 +9,13 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: class.boapplications.inc.php 690 2008-02-02 10:11:33Z dave $ */
+  /* $Id: class.boapplications.inc.php 13892 2015-09-14 20:07:23Z sigurdne $ */
 
 	class boapplications
 	{
 		var $so;
 
-		function boapplications()
+		function __construct()
 		{
 			$this->so = CreateObject('admin.soapplications');
 		}
