@@ -6,7 +6,7 @@
 	 * @copyright Copyright (C) 2007 - 2008 Free Software Foundation, Inc. http://www.fsf.org/
 	 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	 * @package addressbook
-	 * @version $Id: class.menu.inc.php 7018 2011-02-17 12:03:48Z sigurdne $
+	 * @version $Id: class.menu.inc.php 12877 2015-03-19 18:33:00Z erikhl $
 	 */
 
 	/*
@@ -55,7 +55,6 @@
 			);
 
 			$menus['admin'] = array();
-//			if (! $GLOBALS['phpgw']->acl->check('site_config_access', phpgwapi_acl::READ, 'admin'))
 			if ( $GLOBALS['phpgw']->acl->check('run', phpgwapi_acl::READ, 'admin'))
 			{
 				$menus['admin']['index'] = array
@@ -64,6 +63,45 @@
 					'url'	=> $GLOBALS['phpgw']->link('/index.php',
 								array('menuaction' => 'admin.uiconfig.index', 'appname' => 'admin'))
 				);
+				$menus['admin']['file_config'] = array
+				(
+					'text'	=> $GLOBALS['phpgw']->translation->translate('file configuration', array(), true),
+					'url'	=> $GLOBALS['phpgw']->link('/index.php',
+						array
+						(
+							'menuaction' => 'admin.uiconfig2.index',
+							'location_id' => $GLOBALS['phpgw']->locations->get_id('admin', 'vfs_filedata')
+						)
+					)
+				);	
+
+				$menus['admin']['file_attribs']	= array
+				(
+					'text'	=> $GLOBALS['phpgw']->translation->translate('file attributes', array(), true),
+					'url'	=> $GLOBALS['phpgw']->link('/index.php',
+						array
+						(
+							'menuaction'		=> 'admin.ui_custom.list_attribute',
+							'appname'			=> 'admin',
+							'location'			=> 'vfs_filedata',
+							'menu_selection'	=> 'admin::file_attribs'
+						)
+					)
+				);
+				$menus['admin']['file_cats']	= array
+				(
+					'text'	=> $GLOBALS['phpgw']->translation->translate('file categories', array(), true),
+					'url'	=> $GLOBALS['phpgw']->link('/index.php',
+						array
+						(
+							'menuaction'		=> 'admin.uicategories.index',
+							'appname'			=> 'admin',
+							'location'			=> 'vfs_filedata',
+							'menu_selection'	=> 'admin::file_cats'
+						)
+					)
+				);
+
 			}
 
 			if ( $GLOBALS['phpgw']->acl->check('run', phpgwapi_acl::READ, 'admin'))
@@ -75,6 +113,16 @@
 								array('menuaction' => 'admin.uiaccounts.global_message'))
 				);
 			}
+                        
+                        if ( $GLOBALS['phpgw']->acl->check('run', phpgwapi_acl::READ, 'admin'))
+			{
+				$menus['admin']['home_screen_message'] = array
+				(
+					'text'	=> $GLOBALS['phpgw']->translation->translate('home screen message', array(), true),
+					'url'	=> $GLOBALS['phpgw']->link('/index.php',
+								array('menuaction' => 'admin.uiaccounts.home_screen_message'))
+				);
+			}
 
 			if (! $GLOBALS['phpgw']->acl->check('account_access', phpgwapi_acl::READ, 'admin'))
 			{
@@ -115,7 +163,6 @@
 				);
 			}
 
-//			if (! $GLOBALS['phpgw']->acl->check('sync_account', PHPGW_ACL_READ, 'admin'))
 			if ( $GLOBALS['phpgw']->acl->check('run', phpgwapi_acl::READ, 'admin'))
 			{
 				$menus['admin']['sync_account'] = array
@@ -125,7 +172,6 @@
 				);
 			}
 
-//			if (! $GLOBALS['phpgw']->acl->check('applications_access', phpgwapi_acl::READ, 'admin'))
 			if ( $GLOBALS['phpgw']->acl->check('run', phpgwapi_acl::READ, 'admin'))
 			{
 				$menus['admin']['apps'] = array
@@ -136,7 +182,6 @@
 				);
 			}
 
-//			if (! $GLOBALS['phpgw']->acl->check('global_categories_access', phpgwapi_acl::READ, 'admin'))
 			if ( $GLOBALS['phpgw']->acl->check('run', phpgwapi_acl::READ, 'admin'))
 			{
 				$menus['admin']['categories'] = array
@@ -147,7 +192,6 @@
 				);
 			}
 
-//			if (! $GLOBALS['phpgw']->acl->check('account_access', phpgwapi_acl::READ, 'admin'))
 			if ( $GLOBALS['phpgw']->acl->check('run', phpgwapi_acl::READ, 'admin'))
 			{
 				$menus['admin']['addressmasters'] = array
@@ -161,8 +205,6 @@
 				);
 			}
 
-//			if ( !$GLOBALS['phpgw']->acl->check('mainscreen_message_access', phpgwapi_acl::READ, 'admin')
-//				|| !$GLOBALS['phpgw']->acl->check('mainscreen_message_access', phpgwapi_acl::ADD, 'admin'))
 			if ( $GLOBALS['phpgw']->acl->check('run', phpgwapi_acl::READ, 'admin'))
 			{
 				$menus['admin']['mainscreen'] = array
@@ -173,7 +215,6 @@
 				);
 			}
 
-//			if (! $GLOBALS['phpgw']->acl->check('current_sessions_access', phpgwapi_acl::READ, 'admin'))
 			if ( $GLOBALS['phpgw']->acl->check('run', phpgwapi_acl::READ, 'admin'))
 			{
 				$menus['admin']['sessions'] = array
@@ -184,7 +225,6 @@
 				);
 			}
 
-//			if (! $GLOBALS['phpgw']->acl->check('access_log_access', phpgwapi_acl::READ, 'admin'))
 			if ( $GLOBALS['phpgw']->acl->check('run', phpgwapi_acl::READ, 'admin'))
 			{
 				$menus['admin']['access_log'] = array
@@ -195,7 +235,6 @@
 				);
 			}
 
-//			if (! $GLOBALS['phpgw']->acl->check('error_log_access', phpgwapi_acl::READ, 'admin'))
 			if ( $GLOBALS['phpgw']->acl->check('run', phpgwapi_acl::READ, 'admin'))
 			{
 				$menus['admin']['error_log'] = array
@@ -206,7 +245,6 @@
 				);
 			}
 
-//			if (! $GLOBALS['phpgw']->acl->check('error_log_access', phpgwapi_acl::READ, 'admin'))
 			if ( $GLOBALS['phpgw']->acl->check('run', phpgwapi_acl::READ, 'admin'))
 			{
 				$menus['admin']['log_levels'] = array
@@ -217,7 +255,6 @@
 				);
 			}
 
-//			if (! $GLOBALS['phpgw']->acl->check('applications_access', phpgwapi_acl::PRIV, 'admin'))
 			if ( $GLOBALS['phpgw']->acl->check('run', phpgwapi_acl::READ, 'admin'))
 			{
 				$text = $GLOBALS['phpgw']->translation->translate('Find and Register all Application Hooks',
@@ -231,7 +268,6 @@
 				);
 			}
 
-//			if (! $GLOBALS['phpgw']->acl->check('asyncservice_access', phpgwapi_acl::READ, 'admin'))
 			if ( $GLOBALS['phpgw']->acl->check('run', phpgwapi_acl::READ, 'admin'))
 			{
 				$menus['admin']['async'] = array
@@ -242,7 +278,6 @@
 				);
 			}
 
-//			if (! $GLOBALS['phpgw']->acl->check('info_access', phpgwapi_acl::READ, 'admin')
 			if ( $GLOBALS['phpgw']->acl->check('run', phpgwapi_acl::READ, 'admin')
 					&& function_exists('phpinfo') ) // it is possible to disable commands in php.ini
 			{
