@@ -9,13 +9,13 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.solog.inc.php 7215 2011-04-12 20:06:07Z sigurdne $ */
+	/* $Id: class.solog.inc.php 13892 2015-09-14 20:07:23Z sigurdne $ */
 
 	class solog
 	{
 		var $db;
 
-		function solog()
+		function __construct()
 		{
 			$this->db =& $GLOBALS['phpgw']->db;
 		}
