@@ -8,7 +8,7 @@
 	* @license http://www.gnu.org/licenses/ GNU General Public License v2 or later
 	* @package phpgroupware
 	* @subpackage admin
-	* @version $Id: class.uiaccounts.inc.php 6744 2011-01-10 14:36:50Z sigurdne $
+	* @version $Id: class.uiaccounts.inc.php 15259 2016-06-06 12:26:20Z sigurdne $
 	*/
 
 	/*
@@ -26,7 +26,7 @@
 	   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 	 */
 
-	phpgw::import_class('phpgwapi.yui');
+	phpgw::import_class('phpgwapi.jquery');
 
 	/**
 	* phpGroupWare Administration - Accounts User Interface
@@ -56,7 +56,8 @@
 			'sync_accounts_contacts'	=> true,
 			'clear_user_cache'			=> true,
 			'clear_cache'				=> true,
-			'global_message'			=> true
+			'global_message'			=> true,
+                        'home_screen_message'                   => true
 		);
 
 		/**
@@ -778,7 +779,6 @@
 				'data'	=> array('label' => lang('group data'), 'link' => '#group'),
 				'apps'	=> array('label' => lang('applications'), 'link' => '#apps')
 			);
-			phpgwapi_yui::tabview_setup('group_edit_tabview');
 
 			// this is in the api, so lets not waste loops looking for it the app tpl dirs
 			$GLOBALS['phpgw']->xslttpl->add_file('msgbox', PHPGW_TEMPLATE_DIR, 3);
@@ -810,7 +810,7 @@
 				'msgbox_data'		=> $error_list,
 				'select_size'		=> 5,
 				'value_account_name'=> $group->lid,
-				'tabs'				=> phpgwapi_yui::tabview_generate($tabs, 'data')
+				'tabs'				=> phpgwapi_jquery::tabview_generate($tabs, 'data','group_edit_tabview')
 			);
 
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw', array('group_edit' => $data));
@@ -859,6 +859,12 @@
 		public function _user_save()
 		{
 			$values									= phpgw::get_var('values', 'string', 'POST');
+			if(isset($values['passwd']))
+			{
+				// remove entities to stop mangling
+				$values['passwd'] = html_entity_decode($values['passwd']);
+				$values['passwd_2'] = html_entity_decode($values['passwd_2']);
+			}
 			$values['account_groups']				= (array) phpgw::get_var('account_groups', 'int', 'POST');
 			$account_permissions					= phpgw::get_var('account_permissions', 'int', 'POST');
 			$account_permissions_admin				= phpgw::get_var('account_permissions_admin', 'int', 'POST');
@@ -1076,9 +1082,13 @@
 
 
 			$all_groups = $account->get_list('groups');
-
 			if(!$GLOBALS['phpgw']->acl->check('run', phpgwapi_acl::READ, 'admin'))
 			{
+				$test_admins = $GLOBALS['phpgw']->acl->get_ids_for_location('run', phpgwapi_acl::READ, 'admin');
+				foreach ($test_admins as $test_admin)
+				{
+					unset($all_groups[$test_admin]); // not allowed to elevate privileges
+				}
 				$available_apps = $GLOBALS['phpgw_info']['apps'];
 				$valid_groups = array();
 				foreach($available_apps as $_app => $dummy)
@@ -1179,8 +1189,6 @@
 				'groups'	=> array('label' => lang('groups'), 'link' => '#groups'),
 				'apps'	=> array('label' => lang('applications'), 'link' => '#apps')
 			);
-			phpgwapi_yui::tabview_setup('account_edit_tabview');
-
 
 			$data = array
 			(
@@ -1224,7 +1232,7 @@
 				'app_list'				=> $app_list,
 				'url_contacts'			=> $url_contacts,
 				'url_contacts_text'		=> $url_contacts_text,
-				'tabs'					=> phpgwapi_yui::tabview_generate($tabs, 'data')
+				'tabs'					=> phpgwapi_jquery::tabview_generate($tabs, 'data','account_edit_tabview')
 			);
 
 			/*
@@ -1564,6 +1572,55 @@
 			$GLOBALS['phpgw']->xslttpl->add_file('global_message');
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw', array('global_message' => $data));
 		}
+                
+                /**
+		* Set a message on bottom of home-screen
+		*
+		* @return void
+		*/
+
+		function home_screen_message()
+		{
+			if(	!$GLOBALS['phpgw']->acl->check('run', phpgwapi_acl::READ, 'admin') )
+			{
+				$GLOBALS['phpgw']->redirect_link('/admin/index.php');
+			}
+                        
+                        if(phpgw::get_var('msg_title', 'string'))
+                        {
+                                $msg_title = phpgw::get_var('msg_title', 'string');
+                        }
+                        else
+                        {
+                                $msg_title = lang("important message");
+                        }
+                        
+			if(phpgw::get_var('message', 'string'))
+			{
+                                phpgwapi_cache::system_set('phpgwapi', 'phpgw_home_screen_message_title',$msg_title);
+				phpgwapi_cache::system_set('phpgwapi', 'phpgw_home_screen_message',phpgw::get_var('message', 'html'));			
+			}
+
+			if(phpgw::get_var('delete_message', 'bool'))
+			{
+                                phpgwapi_cache::system_clear('phpgwapi', 'phpgw_home_screen_message_title');
+				phpgwapi_cache::system_clear('phpgwapi', 'phpgw_home_screen_message');
+			}
+
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('administration');
+
+			$data = array
+			(
+                                'value_title'		=> phpgwapi_cache::system_get('phpgwapi', 'phpgw_home_screen_message_title'),
+				'value_message'		=> phpgwapi_cache::system_get('phpgwapi', 'phpgw_home_screen_message'),
+				'form_action'		=> $GLOBALS['phpgw']->link('/index.php',
+										array('menuaction' => 'admin.uiaccounts.home_screen_message')),
+				'lang_cancel'		=> lang('cancel'),
+				'lang_submit'		=> lang('submit')
+			);
+			$GLOBALS['phpgw']->xslttpl->add_file('home_screen_message');
+			$GLOBALS['phpgw']->xslttpl->set_var('phpgw', array('home_screen_message' => $data));
+		}
 
 		/**
 		 * Render a confirmation form for clear all cache (user,and system)
