@@ -1,13 +1,18 @@
 <?php
-class BimObject {
 	
-	public function transformObjectToArray() {
+	class BimObject
+	{
+
+		public function transformObjectToArray()
+		{
 		$reflection = new ReflectionObject($this);
 		$publicMethods = $reflection->getMethods(ReflectionProperty::IS_PUBLIC);
 		$result = array();
-		foreach($publicMethods as $method) {
+			foreach($publicMethods as $method)
+			{
 			/* @var $method ReflectionMethod */
-			if(preg_match("/^get(.+)/", $method->getName(), $matches)) {
+				if(preg_match("/^get(.+)/", $method->getName(), $matches))
+				{
 				$memberVarible = lcfirst($matches[1]);
 				$value = $method->invoke($this);
 				$result[$memberVarible] = $value;
@@ -15,4 +20,4 @@ class BimObject {
 		}
 		return $result;
 	}
-}
\ No newline at end of file
+	}
\ No newline at end of file
