@@ -2,12 +2,14 @@
 
 //phpgw::import_class('phpgwapi.datetime');  // just a test import
 
-/*
+	/*
  * parent SO object defining table names
  */
-interface sobim {
+	interface sobim
+	{
 	 
 	const bimItemTable = 'fm_bim_item';
 	const bimTypeTable = 'fm_bim_type';
 	const bimModelTable = 'fm_bim_model';
-}
+
+	}
\ No newline at end of file
