@@ -1,30 +1,40 @@
 <?php
-/*
+	/*
  * Requires the following to work:
  * Curl library
  * HTTP_Request (Pear)
  */
 
-phpgw::import_class('bim.restrequest');
+	phpgw::import_class('bim.restrequest');
+
+	interface sobimrest
+	{
 
-interface sobimrest {
 	public function getRepositoryCountJson();
-}
+	}
+
+	class sobimrest_impl implements sobimrest
+	{
 
-class sobimrest_impl implements sobimrest{
 	private $baseUrl = "http://localhost:8080/RestTests/rest/repositories";
 	
-	public function __construct() {
-		if(!$this->iscurlinstalled()) {
+		public function __construct()
+		{
+			if(!$this->iscurlinstalled())
+			{
 			throw new Exception("Curl library is required for this to work!");
 		}
 	}
-	private function iscurlinstalled() {
-		return  (in_array  ('curl', get_loaded_extensions()));
+
+		private function iscurlinstalled()
+		{
+			return (in_array('curl', get_loaded_extensions()));
 	}
-	public function getRepositoryCountJson() {
 		
-		$url = $this->baseUrl."/count";
+		public function getRepositoryCountJson()
+		{
+
+			$url = $this->baseUrl . "/count";
 		$method = "GET";
 		$rest = new RestRequest($url, $method);
 		//$rest->setAcceptType("application/xml");
@@ -33,8 +43,9 @@ class sobimrest_impl implements sobimrest{
 		echo $output;
 	}
 	
-	public function getRepositoryNames() {
-		$url = $this->baseUrl."/names";
+		public function getRepositoryNames()
+		{
+			$url = $this->baseUrl . "/names";
 		$method = "GET";
 		$rest = new RestRequest($url, $method);
 		//$rest->setAcceptType("application/xml");
@@ -42,4 +53,4 @@ class sobimrest_impl implements sobimrest{
 		$output = $rest->getResponseBody();
 		echo $output;
 	}
-}
+	}
\ No newline at end of file
