@@ -4,10 +4,13 @@
 	 * do not add any global variables into this code!
 	 * Any global variables needed should be injected via methods
 	 */
-	interface sobimtype extends sobim {
+
+	interface sobimtype extends sobim
+	{
 		/*
     	 * @param string type
     	 */
+
     	public function getBimObjectType($type);
     	/*
     	 * @param $description max 512char string, may be null
@@ -15,63 +18,73 @@
     	 * @throws exception if object type already exists
     	 * @return int id of new object type
     	 */
+
     	public function addBimObjectType($name, $description);
     	
     	public function deleteBimObjectType($name);
     	
     	public function updateBimObjectTypeDescription($name, $newDescription);
-    	
 	}
 	
-	class sobimtype_impl implements sobimtype {
-		
+	class sobimtype_impl implements sobimtype
+	{
 		/* @var phpgwapi_db_ */
+
 		private $db;
 
-        public function __construct(& $db) {
+		public function __construct(& $db)
+		{
            // $this->db = & $GLOBALS['phpgw']->db;
            $this->db = $db;
         }
 		/*
          * @return null|BimType
          */
-        public function getBimObjectType($type) {
+
+		public function getBimObjectType($type)
+		{
         	$resultAlias = 'test_type_count';
-			$sql  = "SELECT  *  FROM public.".self::bimTypeTable." WHERE ".self::bimTypeTable.".name = '".$type."'";
-			$q = $this->db->query($sql,__LINE__,__FILE__);
-			if(is_null($q)) {
+			$sql = "SELECT  *  FROM public." . self::bimTypeTable . " WHERE " . self::bimTypeTable . ".name = '" . $type . "'";
+			$q = $this->db->query($sql, __LINE__, __FILE__);
+			if(is_null($q))
+			{
 				throw new Exception('Query to get object type was unsuccessful');
 			}
-	        if($this->db->num_rows() == 0) {
+			if($this->db->num_rows() == 0)
+			{
 				return null;
-			} else {
+			}
+			else
+			{
 				$this->db->next_record();
-				return new BimType($this->db->f('id'),$this->db->f('name'), $this->db->f('description'));
+				return new BimType($this->db->f('id'), $this->db->f('name'), $this->db->f('description'));
 			}
         }
-        
 		/*
          * @return boolean
          * @throws exception if query fails
          */
-        public function addBimObjectType($name, $description = null) {
-        	if($this->getBimObjectType($name) != null) {
+
+		public function addBimObjectType($name, $description = null)
+		{
+			if($this->getBimObjectType($name) != null)
+			{
         		throw new Exception('Type already exists!');
         	}
 
-			$location_id = $GLOBALS['phpgw']->locations->add($name, $description ? $description : $name , 'bim');
+			$location_id = $GLOBALS['phpgw']->locations->add($name, $description ? $description : $name, 'bim');
 
         	if(is_null($description))
         	{
-        		$sql = "INSERT INTO ".self::bimTypeTable." (location_id, name) VALUES ($location_id, '$name')";
+				$sql = "INSERT INTO " . self::bimTypeTable . " (location_id, name) VALUES ($location_id, '$name')";
         	}
         	else
         	{
         		$description = $this->db->db_addslashes($description);
-        		$sql = "INSERT INTO ".self::bimTypeTable." (location_id, name, description) VALUES ($location_id, '$name', '$description')";
+				$sql = "INSERT INTO " . self::bimTypeTable . " (location_id, name, description) VALUES ($location_id, '$name', '$description')";
         	} 
 
-			if(is_null($this->db->query($sql,__LINE__,__FILE__) ))
+			if(is_null($this->db->query($sql, __LINE__, __FILE__)))
 			{
 				throw new Exception("Error adding object type!");
 			}
@@ -83,46 +96,65 @@
         /*
          * @return boolean
          */
-        public function deleteBimObjectType($name) {
-        	$sql  = "Delete FROM public.".self::bimTypeTable." WHERE ".self::bimTypeTable.".name = '".$name."'";
-       		if(is_null($this->db->query($sql,__LINE__,__FILE__) )){
+
+		public function deleteBimObjectType($name)
+		{
+			$sql = "Delete FROM public." . self::bimTypeTable . " WHERE " . self::bimTypeTable . ".name = '" . $name . "'";
+			if(is_null($this->db->query($sql, __LINE__, __FILE__)))
+			{
 				throw new Exception("Error deleting object type!");
-			} else {
+			}
+			else
+			{
 				return true;
 			}
         }
         
-        public function updateBimObjectTypeDescription($name, $newDescription) {
-        	$sql = "Update ".self::bimTypeTable." set description='$newDescription' where name='".$name."'";
-       	 	if(is_null($this->db->query($sql,__LINE__,__FILE__) )){
+		public function updateBimObjectTypeDescription($name, $newDescription)
+		{
+			$sql = "Update " . self::bimTypeTable . " set description='$newDescription' where name='" . $name . "'";
+			if(is_null($this->db->query($sql, __LINE__, __FILE__)))
+			{
 				throw new Exception("Error updating description of object type!");
-			} else {
+			}
+			else
+			{
 				return true;
 			}
         }
-	
 	}
 	
-	class BimType {
+	class BimType
+	{
+
     	private $id;
     	private $name;
     	private $description;
-    	function __construct($id = null, $name = null, $description = null) {
+
+		function __construct($id = null, $name = null, $description = null)
+		{
     		$this->id = $id;
     		$this->name = $name;
     		$this->description = $description;
     	}
-    	function getId() {
+
+		function getId()
+		{
     		return $this->id;
     	}
-    	function getName() {
+
+		function getName()
+		{
     		return $this->name;
     	}
-    	function getDescription() {
+
+		function getDescription()
+		{
     		return $this->description;
     	}
-    	function setId($id) {
+
+		function setId($id)
+		{
     		$this->id = $id;
     	}
-    	
     }
