@@ -1,19 +1,23 @@
 <?php
-class TestUIbim extends TestBimCommon
-{
+
+	class TestUIbim extends TestBimCommon
+	{
+
 	protected $backupGlobals = false;
 	
-	public function __construct() {
+		public function __construct()
+		{
 		
 	}
+
 	protected function setUp()
 	{
 		$currentDirectory = dirname(__FILE__);
-		$this->vfsFileNameWithFullPath = $currentDirectory.DIRECTORY_SEPARATOR.$this->vfsFileName;
-		
+			$this->vfsFileNameWithFullPath = $currentDirectory . DIRECTORY_SEPARATOR . $this->vfsFileName;
 	}
 	
-	public function testUploadFile() {
+		public function testUploadFile()
+		{
 		$uibim = new bim_uibim();
 		$this->modelName;
 		$uploadedFileArray = array();
@@ -22,5 +26,4 @@ class TestUIbim extends TestBimCommon
 		$result = $uibim->uploadFile($uploadedFileArray, $this->modelName, true);
 		print_r($result);
 	}
-	
-}
+	}
\ No newline at end of file
