@@ -3,25 +3,27 @@
 
 	class booking_uiaccount_code_dimension extends booking_uicommon
 	{
+
 		public $public_functions = array
-		(
-			'index'			=>	true,
+			(
+			'index' => true,
+			'query' => true,
 		);
-		
+
 		public function __construct()
 		{
 			parent::__construct();
 			self::set_active_menu('booking::settings::account_code_dimensions');
 		}
-		
+
 		public function index()
 		{
-			$config	= CreateObject('phpgwapi.config','booking');
+			$config = CreateObject('phpgwapi.config', 'booking');
 			$config->read();
 
-			if($_SERVER['REQUEST_METHOD'] == 'POST')
+			if ($_SERVER['REQUEST_METHOD'] == 'POST')
 			{
-				foreach($_POST as $dim => $value)
+				foreach ($_POST as $dim => $value)
 				{
 					if (strlen(trim($value)) > 0)
 					{
@@ -34,7 +36,20 @@
 				}
 				$config->save_repository();
 			}
-			
-			self::render_template('account_code_dimension', array('config_data' =>$config->config_data));
+
+			$tabs = array();
+			$tabs['generic'] = array('label' => lang('Account Code Dimension'), 'link' => '#account_code');
+			$active_tab = 'generic';
+
+			$data = array();
+			$data['tabs'] = phpgwapi_jquery::tabview_generate($tabs, $active_tab);
+
+			self::render_template_xsl('account_code_dimension', array('config_data' => $config->config_data,
+				'data' => $data));
 		}
-	}
+
+		public function query()
+		{
+
+		}
+	}
\ No newline at end of file
