@@ -1,16 +1,16 @@
 <?php
 	$setup_info['bookingfrontend']['name'] = 'bookingfrontend';
-	$setup_info['bookingfrontend']['version'] = '0.1';
+	$setup_info['bookingfrontend']['version'] = '0.1.1';
 	$setup_info['bookingfrontend']['app_order'] = 9;
 	$setup_info['bookingfrontend']['enable'] = 1;
-	$setup_info['bookingfrontend']['app_group']	= 'office';
+	$setup_info['bookingfrontend']['app_group'] = 'office';
 
 	$setup_info['bookingfrontend']['description'] = 'Bergen kommune bookingfrontend';
 
 	$setup_info['bookingfrontend']['author'][] = array
-	(
-		'name'	=> 'Redpill Linpro',
-		'email'	=> 'info@redpill-linpro.com'
+		(
+		'name' => 'Redpill Linpro',
+		'email' => 'info@redpill-linpro.com'
 	);
 
 	/* Dependencies for this app to work */
@@ -21,7 +21,8 @@
 
 	$setup_info['bookingfrontend']['depends'][] = array(
 		'appname' => 'booking',
-		'versions' => Array('0.2.00', '0.2.01','0.2.02','0.2.03','0.2.04','0.2.05','0.2.06','0.2.07','0.2.08','0.2.09','0.2.10','0.2.11','0.2.12')
+		'versions' => array('0.2.20', '0.2.21', '0.2.22', '0.2.23', '0.2.24', '0.2.25',
+			'0.2.26', '0.2.27')
 	);
 
 	$setup_info['bookingfrontend']['depends'][] = array(
@@ -31,7 +32,7 @@
 
 	/* The hooks this app includes, needed for hooks registration */
 	$setup_info['bookingfrontend']['hooks'] = array
-	(
-		'menu'	=> 'bookingfrontend.menu.get_menu',
+		(
+		'menu' => 'bookingfrontend.menu.get_menu',
 		'config'
 	);
