@@ -12,7 +12,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-	/* $Id: class.bocalendar.inc.php 10797 2013-02-12 12:18:01Z sigurdne $ */
+	/* $Id: class.bocalendar.inc.php 13955 2015-09-17 16:45:28Z sigurdne $ */
 
 	phpgw::import_class('phpgwapi.datetime');
 
@@ -182,7 +182,7 @@
 			}
 //_debug_array($owner);
 			$referer = isset($_SERVER['HTTP_REFERER']) ? $_SERVER['HTTP_REFERER'] : '';
-			ereg('menuaction=([a-zA-Z.]+)', $referer, $regs);
+			preg_match('/menuaction=([a-zA-Z.]+)/', $referer, $regs);
 			$from = $regs[1];
 			if ((substr($_SERVER['PHP_SELF'],-8) == 'home.php' && substr($this->prefs['calendar']['defaultcalendar'],0,7) == 'planner'
 				 || ( isset($GLOBALS['phpgw_info']['menuaction']) && $GLOBALS['phpgw_info']['menuaction'] == 'calendar.uicalendar.planner')
@@ -2564,7 +2564,7 @@
 					$details['startdate'] = $GLOBALS['phpgw']->common->show_date($starttime);
 					$details['enddate']   = $GLOBALS['phpgw']->common->show_date($endtime);
 				
-					list($subject,$body) = split("\n",$GLOBALS['phpgw']->preferences->parse_notify($notify_msg,$details),2);
+					list($subject,$body) = explode("\n",$GLOBALS['phpgw']->preferences->parse_notify($notify_msg,$details),2);
 					$subject = trim($send->encode_subject($subject));
 					switch($part_prefs['calendar']['update_format'])
  					{
