@@ -10,7 +10,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-	/* $Id: class.bocustom_fields.inc.php 18358 2007-11-27 04:43:37Z skwashd $ */
+	/* $Id: class.bocustom_fields.inc.php 1906 2008-11-28 22:47:27Z sigurd $ */
 
 	class calendar_bocustom_fields
 	{
@@ -38,7 +38,7 @@
 		public function __construct()
 		{
 			$this->config = CreateObject('phpgwapi.config','calendar');
-			$this->config->read_repository();
+			$this->config->read();
 
 			$this->fields = &$this->config->config_data['fields'];
 
