@@ -9,7 +9,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-	/* $Id: preferences.php 18358 2007-11-27 04:43:37Z skwashd $ */
+	/* $Id: preferences.php 1906 2008-11-28 22:47:27Z sigurd $ */
 
 	$phpgw_info['flags'] = array
 	(
@@ -26,7 +26,7 @@
 
 	if ( phpgw::get_var('submit', 'bool', 'POST') )
 	{
-		$phpgw->preferences->read_repository();
+		$phpgw->preferences->read();
 		$phpgw->preferences->add('calendar','weekdaystarts');
 		$phpgw->preferences->add('calendar','workdaystarts');
 		$phpgw->preferences->add('calendar','workdayends');
@@ -88,8 +88,7 @@
 
 		$phpgw->preferences->save_repository(True);
      
-		Header('Location: '.$phpgw->link('/preferences/index.php'));
-		$phpgw->common->phpgw_exit();
+		$phpgw->redirect_link('/preferences/index.php');
 	}
 
 	function display_item($field,$data)
