@@ -9,7 +9,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: header.inc.php 17679 2006-12-12 15:19:11Z sigurdne $ */
+  /* $Id: header.inc.php 1142 2008-06-05 07:45:48Z sigurd $ */
 
 	function add_col(&$tpl,$str)
 	{
@@ -44,8 +44,8 @@
 	{
 		$tpl->set_var('cols',7);
 	}
-
-	$today = date('Ymd',$GLOBALS['phpgw']->datetime->users_localtime);
+	phpgw::import_class('phpgwapi.datetime');
+	$today = date('Ymd',phpgwapi_datetime::user_localtime());
 
 	$col_width = 12;
 
@@ -225,4 +225,3 @@
 	$tpl->set_var('str','<td align="right" valign="bottom">'.$button.'</td>');
 	$tpl->parse('header_column','head_col',True);
 	echo $tpl->parse('row','head_table',True);
-?>
