@@ -8,7 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package catch
 	* @subpackage setup
- 	* @version $Id: tables_update.inc.php 10797 2013-02-12 12:18:01Z sigurdne $
+ 	* @version $Id: tables_update.inc.php 13989 2015-09-22 11:33:14Z sigurdne $
 	*/
 
 	/**
@@ -483,3 +483,177 @@
 		}
 	}
 
+	/**
+	* Update catch version from 0.9.17.515 to 0.9.17.516
+	* Add department-flag to entities
+	*/
+
+	$test[] = '0.9.17.515';
+	function catch_upgrade0_9_17_515()
+	{
+		$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_begin();
+
+		$GLOBALS['phpgw_setup']->oProc->AddColumn('fm_catch_category','department',array('type' => 'int','precision' => 2,'nullable' => True));
+
+		if($GLOBALS['phpgw_setup']->oProc->m_odb->transaction_commit())
+		{
+			$GLOBALS['setup_info']['catch']['currentver'] = '0.9.17.516';
+			return $GLOBALS['setup_info']['catch']['currentver'];
+		}
+	}
+
+
+	/**
+	* Update catch version from 0.9.17.516 to 0.9.17.517
+	* Add department_id to catch tables
+	*/
+	$test[] = '0.9.17.516';
+	function catch_upgrade0_9_17_516()
+	{
+		$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_begin();
+
+		$GLOBALS['phpgw_setup']->oProc->query("SELECT * FROM fm_catch_category");
+
+		$categories = array();
+		while ($GLOBALS['phpgw_setup']->oProc->next_record())
+		{
+			$categories[] = array
+			(
+				'entity_id'	=> $GLOBALS['phpgw_setup']->oProc->f('entity_id'),
+				'cat_id'	=> $GLOBALS['phpgw_setup']->oProc->f('id')
+			);
+		}
+
+		$tables = $GLOBALS['phpgw_setup']->oProc->m_odb->table_names();
+
+		foreach ($categories as $category)
+		{
+			$table = "fm_catch_{$category['entity_id']}_{$category['cat_id']}";
+			if(in_array($table, $tables))
+			{
+				$metadata = $GLOBALS['phpgw_setup']->oProc->m_odb->metadata($table);
+				if(!isset($metadata['department_id']))
+				{
+					$GLOBALS['phpgw_setup']->oProc->AddColumn($table,'department_id',array('type' => 'int','precision' => 4,'nullable' => True));				
+				}
+			}
+		}
+
+		if($GLOBALS['phpgw_setup']->oProc->m_odb->transaction_commit())
+		{
+			$GLOBALS['setup_info']['catch']['currentver'] = '0.9.17.517';
+			return $GLOBALS['setup_info']['catch']['currentver'];
+		}
+	}
+
+	/**
+	* Update catch version from 0.9.17.517 to 0.9.17.518
+	* Change name from department to org_unit
+	*/
+	$test[] = '0.9.17.517';
+	function catch_upgrade0_9_17_517()
+	{
+		$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_begin();
+
+		$GLOBALS['phpgw_setup']->oProc->query("SELECT * FROM fm_catch_category");
+
+		$categories = array();
+		while ($GLOBALS['phpgw_setup']->oProc->next_record())
+		{
+			$categories[] = array
+			(
+				'entity_id'	=> $GLOBALS['phpgw_setup']->oProc->f('entity_id'),
+				'cat_id'	=> $GLOBALS['phpgw_setup']->oProc->f('id')
+			);
+		}
+
+		$tables = $GLOBALS['phpgw_setup']->oProc->m_odb->table_names();
+
+		foreach ($categories as $category)
+		{
+			$table = "fm_catch_{$category['entity_id']}_{$category['cat_id']}";
+			if(in_array($table, $tables))
+			{
+				$metadata = $GLOBALS['phpgw_setup']->oProc->m_odb->metadata($table);
+				if(isset($metadata['department_id']))
+				{
+					$GLOBALS['phpgw_setup']->oProc->RenameColumn($table,'department_id','org_unit_id');
+				}
+			}
+		}
+
+		if($GLOBALS['phpgw_setup']->oProc->m_odb->transaction_commit())
+		{
+			$GLOBALS['setup_info']['catch']['currentver'] = '0.9.17.518';
+			return $GLOBALS['setup_info']['catch']['currentver'];
+		}
+	}
+
+	/**
+	* Update catch version from 0.9.17.518 to 0.9.17.519
+	* Add controller-flag to entities
+	*/
+
+	$test[] = '0.9.17.518';
+	function catch_upgrade0_9_17_518()
+	{
+		$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_begin();
+
+		$GLOBALS['phpgw_setup']->oProc->AddColumn('fm_catch_category','enable_controller',array('type' => 'int','precision' => 2,'nullable' => True));
+
+		if($GLOBALS['phpgw_setup']->oProc->m_odb->transaction_commit())
+		{
+			$GLOBALS['setup_info']['catch']['currentver'] = '0.9.17.519';
+			return $GLOBALS['setup_info']['catch']['currentver'];
+		}
+	}
+
+	$test[] = '0.9.17.519';
+	function catch_upgrade0_9_17_519()
+	{
+		$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_begin();
+		$GLOBALS['phpgw_setup']->oProc->RenameColumn('fm_catch_category','department','org_unit');
+		$GLOBALS['phpgw_setup']->oProc->AddColumn('fm_catch_category','entity_group_id',array('type' => 'int','precision' => 4,'nullable' => True));
+
+		if($GLOBALS['phpgw_setup']->oProc->m_odb->transaction_commit())
+		{
+			$GLOBALS['setup_info']['catch']['currentver'] = '0.9.17.520';
+			return $GLOBALS['setup_info']['catch']['currentver'];
+		}
+	}
+
+	$test[] = '0.9.17.520';
+	function catch_upgrade0_9_17_520()
+	{
+		$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_begin();
+
+		$GLOBALS['phpgw_setup']->oProc->query("SELECT * FROM fm_catch_category");
+
+		$categories = array();
+		while ($GLOBALS['phpgw_setup']->oProc->next_record())
+		{
+			$categories[] = array
+			(
+				'entity_id'	=> $GLOBALS['phpgw_setup']->oProc->f('entity_id'),
+				'cat_id'	=> $GLOBALS['phpgw_setup']->oProc->f('id')
+			);
+		}
+
+		$tables = $GLOBALS['phpgw_setup']->oProc->m_odb->table_names();
+
+		foreach ($categories as $category)
+		{
+			$table = "fm_catch_{$category['entity_id']}_{$category['cat_id']}";
+			if(in_array($table, $tables))
+			{
+				$GLOBALS['phpgw_setup']->oProc->AddColumn($table,'modified_by', array('type' => 'int', 'precision' => 4,'nullable' => true));
+				$GLOBALS['phpgw_setup']->oProc->AddColumn($table,'modified_on', array('type' => 'int', 'precision' => 8,'nullable' => true));
+			}
+		}
+
+		if($GLOBALS['phpgw_setup']->oProc->m_odb->transaction_commit())
+		{
+			$GLOBALS['setup_info']['catch']['currentver'] = '0.9.17.521';
+			return $GLOBALS['setup_info']['catch']['currentver'];
+		}
+	}
\ No newline at end of file
