@@ -1,33 +1,32 @@
 <?php
 	/**
-	* phpGroupWare - controller: a part of a Facilities Management System.
-	*
-	* @author Erink Holm-Larsen <erik.holm-larsen@bouvet.no>
-	* @author Torstein Vadla <torstein.vadla@bouvet.no>
-	* @copyright Copyright (C) 2011,2012 Free Software Foundation, Inc. http://www.fsf.org/
-	* This file is part of phpGroupWare.
-	*
-	* phpGroupWare is free software; you can redistribute it and/or modify
-	* it under the terms of the GNU General Public License as published by
-	* the Free Software Foundation; either version 2 of the License, or
-	* (at your option) any later version.
-	*
-	* phpGroupWare is distributed in the hope that it will be useful,
-	* but WITHOUT ANY WARRANTY; without even the implied warranty of
-	* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-	* GNU General Public License for more details.
-	*
-	* You should have received a copy of the GNU General Public License
-	* along with phpGroupWare; if not, write to the Free Software
-	* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-	*
-	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
-	* @internal Development of this application was funded by http://www.bergen.kommune.no/
-	* @package property
-	* @subpackage controller
- 	* @version $Id: class.soprocedure.inc.php 11230 2013-07-03 07:18:27Z sigurdne $
-	*/	
-
+	 * phpGroupWare - controller: a part of a Facilities Management System.
+	 *
+	 * @author Erink Holm-Larsen <erik.holm-larsen@bouvet.no>
+	 * @author Torstein Vadla <torstein.vadla@bouvet.no>
+	 * @copyright Copyright (C) 2011,2012 Free Software Foundation, Inc. http://www.fsf.org/
+	 * This file is part of phpGroupWare.
+	 *
+	 * phpGroupWare is free software; you can redistribute it and/or modify
+	 * it under the terms of the GNU General Public License as published by
+	 * the Free Software Foundation; either version 2 of the License, or
+	 * (at your option) any later version.
+	 *
+	 * phpGroupWare is distributed in the hope that it will be useful,
+	 * but WITHOUT ANY WARRANTY; without even the implied warranty of
+	 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+	 * GNU General Public License for more details.
+	 *
+	 * You should have received a copy of the GNU General Public License
+	 * along with phpGroupWare; if not, write to the Free Software
+	 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+	 *
+	 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License
+	 * @internal Development of this application was funded by http://www.bergen.kommune.no/
+	 * @package property
+	 * @subpackage controller
+	 * @version $Id: class.soprocedure.inc.php 14733 2016-02-12 14:14:26Z sigurdne $
+	 */
 	phpgw::import_class('controller.socommon');
 	phpgw::import_class('controller.uidocument');
 
@@ -36,6 +35,7 @@
 
 	class controller_soprocedure extends controller_socommon
 	{
+
 		protected static $so;
 
 		/**
@@ -58,21 +58,21 @@
 		 * @param activitycalendar_activity $activity the party to be added
 		 * @return bool true if successful, false otherwise
 		 */
-		function add(&$procedure)
+		function add( &$procedure )
 		{
 			$cols = array(
-					'title',
-					'purpose',
-					'responsibility',
-					'description',
-					'reference',
-					'attachment',
-					'start_date',
-					'end_date',
-					'procedure_id',
-					'revision_no',
-					'revision_date',
-					'control_area_id'
+				'title',
+				'purpose',
+				'responsibility',
+				'description',
+				'reference',
+				'attachment',
+				'start_date',
+				'end_date',
+				'procedure_id',
+				'revision_no',
+				'revision_date',
+				'control_area_id'
 			);
 
 			$values = array(
@@ -90,9 +90,9 @@
 				$this->marshal($procedure->get_control_area_id(), 'int')
 			);
 
-			$result = $this->db->query('INSERT INTO controller_procedure (' . join(',', $cols) . ') VALUES (' . join(',', $values) . ')', __LINE__,__FILE__);
+			$result = $this->db->query('INSERT INTO controller_procedure (' . join(',', $cols) . ') VALUES (' . join(',', $values) . ')', __LINE__, __FILE__);
 
-			if($result)
+			if ($result)
 			{
 				// Get the new procedure ID and return it
 				return $this->db->get_last_insert_id('controller_procedure', 'id');
@@ -101,7 +101,6 @@
 			{
 				return 0;
 			}
-
 		}
 
 		/**
@@ -110,8 +109,7 @@
 		 * @param $activity the activity to be updated
 		 * @return boolean true if successful, false otherwise
 		 */
-
-		function update($procedure)
+		function update( $procedure )
 		{
 			$id = intval($procedure->get_id());
 
@@ -130,7 +128,7 @@
 				'control_area_id = ' . $this->marshal($procedure->get_control_area_id(), 'int')
 			);
 
-			$result = $this->db->query('UPDATE controller_procedure SET ' . join(',', $values) . " WHERE id=$id", __LINE__,__FILE__);
+			$result = $this->db->query('UPDATE controller_procedure SET ' . join(',', $values) . " WHERE id=$id", __LINE__, __FILE__);
 
 			return $result;
 		}
@@ -141,10 +139,10 @@
 		 * @param	$id	id of the procedure to return
 		 * @return a controller_procedure
 		 */
-		function get_single($id)
+		function get_single( $id )
 		{
 			$id = (int)$id;
-			
+
 			$counter = 0;
 			$documents = null;
 
@@ -154,7 +152,8 @@
 			$this->db->query($sql, __LINE__, __FILE__);
 			while ($this->db->next_record())
 			{
-				if($counter == 0){
+				if ($counter == 0)
+				{
 					$procedure = new controller_procedure($this->unmarshal($this->db->f('id'), 'int'));
 					$procedure->set_title($this->unmarshal($this->db->f('title', true), 'string'));
 					$procedure->set_purpose($this->unmarshal($this->db->f('purpose', true), 'string'));
@@ -168,43 +167,43 @@
 					$procedure->set_revision_no($this->unmarshal($this->db->f('revision_no'), 'int'));
 					$procedure->set_revision_date($this->unmarshal($this->db->f('revision_date'), 'int'));
 					$procedure->set_control_area_id($this->unmarshal($this->db->f('control_area_id', 'int')));
-					
-					$category    = execMethod('phpgwapi.categories.return_single', $this->unmarshal($this->db->f('control_area_id', 'int')));
+
+					$category = execMethod('phpgwapi.categories.return_single', $this->unmarshal($this->db->f('control_area_id', 'int')));
 					$procedure->set_control_area_name($category[0]['name']);
-					
+
 					//$procedure->set_control_area_name($this->unmarshal($this->db->f('control_area_name', 'string')));
 				}
-				
-				if($this->db->f('document_id') != '')
+
+				if ($this->db->f('document_id') != '')
 				{
 					$document = new controller_document($this->unmarshal($this->db->f('document_id'), 'int'));
 					$document->set_procedure_id($procedure->get_id());
 					$document->set_title($this->unmarshal($this->db->f('document_title', true), 'string'));
 					$document->set_description($this->unmarshal($this->db->f('document_description', true), 'string'));
-					
+
 					$procedure->add_document($document);
 				}
-				
+
 				$counter++;
 			}
 //var_dump($procedure);
 			return $procedure;
 		}
-		
-		function get_single_with_documents($id, $return_type = "return_object")
+
+		function get_single_with_documents( $id, $return_type = "return_object" )
 		{
 			$id = (int)$id;
-			
+
 			$counter = 0;
 			$documents = null;
-			
+
 			$joins .= " {$this->left_join} controller_document ON (p.id = controller_document.procedure_id)";
 			$sql = "SELECT p.*, controller_document.id AS document_id, controller_document.title AS document_title, controller_document.description as document_description FROM controller_procedure p {$joins} WHERE p.id = " . $id;
 			//var_dump($sql);
 			$this->db->query($sql, __LINE__, __FILE__);
 			while ($this->db->next_record())
 			{
-				if(!$counter)
+				if (!$counter)
 				{
 					$procedure = new controller_procedure($this->unmarshal($this->db->f('id'), 'int'));
 					$procedure->set_title($this->unmarshal($this->db->f('title', true), 'string'));
@@ -219,21 +218,22 @@
 					$procedure->set_revision_no($this->unmarshal($this->db->f('revision_no'), 'int'));
 					$procedure->set_revision_date($this->unmarshal($this->db->f('revision_date'), 'int'));
 					$procedure->set_control_area_id($this->unmarshal($this->db->f('control_area_id', 'int')));
-					$category    = execMethod('phpgwapi.categories.return_single', $this->unmarshal($this->db->f('control_area_id', 'int')));
+					$category = execMethod('phpgwapi.categories.return_single', $this->unmarshal($this->db->f('control_area_id', 'int')));
 					$procedure->set_control_area_name($category[0]['name']);
 				}
-				
-				if($this->db->f('document_id'))
+
+				if ($this->db->f('document_id'))
 				{
 					$document = new controller_document($this->unmarshal($this->db->f('document_id'), 'int'));
 					$document->set_procedure_id($procedure->get_id());
 					$document->set_title($this->unmarshal($this->db->f('document_title', true), 'string'));
 					$document->set_description($this->unmarshal($this->db->f('document_description', true), 'string'));
-					
-					if($return_type == "return_array")
+
+					if ($return_type == "return_array")
 					{
 						$doc_as_array = $document->toArray();
-						$doc_as_array['document_link'] = controller_uidocument::link(array('menuaction' => 'controller.uidocument.view', 'id' => $document->get_id()));
+						$doc_as_array['document_link'] = controller_uidocument::link(array('menuaction' => 'controller.uidocument.view',
+								'id' => $document->get_id()));
 						//_debug_array($doc_as_array);
 						$documents_array[] = $doc_as_array;
 					}
@@ -242,15 +242,15 @@
 						$documents_array[] = $document;
 					}
 				}
-				
+
 				$counter++;
 			}
-			
-			if($procedure != null)
+
+			if ($procedure != null)
 			{
 				$procedure->set_documents($documents_array);
 
-				if($return_type == "return_array")
+				if ($return_type == "return_array")
 				{
 					return $procedure->toArray();
 				}
@@ -265,24 +265,24 @@
 			}
 		}
 
-		function get_procedures_by_control_area($control_area_id)
+		function get_procedures_by_control_area( $control_area_id )
 		{
-			$cat_id = (int) $control_area_id;
-			$cats	= CreateObject('phpgwapi.categories', -1, 'controller', '.control');
+			$cat_id = (int)$control_area_id;
+			$cats = CreateObject('phpgwapi.categories', -1, 'controller', '.control');
 			$cat_path = $cats->get_path($cat_id);
 			foreach ($cat_path as $_category)
 			{
 				$cat_filter[] = $_category['id'];
 			}
 
-			$filter_control_area = "controller_procedure.control_area_id IN (" .  implode(',', $cat_filter) .')';
+			$filter_control_area = "controller_procedure.control_area_id IN (" . implode(',', $cat_filter) . ')';
 
 			$results = array();
 
 			$sql = "SELECT * FROM controller_procedure WHERE {$filter_control_area} AND end_date IS NULL ORDER BY title ASC";
 			$this->db->query($sql);
 
-			while($this->db->next_record())
+			while ($this->db->next_record())
 			{
 				$procedure = new controller_procedure($this->unmarshal($this->db->f('id'), 'int'));
 				$procedure->set_title($this->unmarshal($this->db->f('title', true), 'string'));
@@ -300,9 +300,9 @@
 				$procedures_array[] = $procedure->toArray();
 			}
 
-			if( count( $procedures_array ) > 0 )
+			if (count($procedures_array) > 0)
 			{
-				return $procedures_array; 
+				return $procedures_array;
 			}
 			else
 			{
@@ -310,33 +310,33 @@
 			}
 		}
 
-		function get_procedures($start = 0, $results = 0, $sort = null, $dir = '', $query = null, $search_option = null, $filters = array())
+		function get_procedures( $start = 0, $results = 0, $sort = null, $dir = '', $query = null, $search_option = null, $filters = array() )
 		{
 			//$condition = $this->get_conditions($query, $filters,$search_option);
-			$order = $sort ? "ORDER BY $sort $dir ": '';
+			$order = $sort ? "ORDER BY $sort $dir " : '';
 
 			//$sql = "SELECT * FROM controller_procedure WHERE $condition $order";
 
 			$condition = "WHERE end_date IS NULL";
 
-			if(isset($filters['control_areas']) && $filters['control_areas'])
+			if (isset($filters['control_areas']) && $filters['control_areas'])
 			{
-				$cat_id = (int) $filters['control_areas'];
-				$cats	= CreateObject('phpgwapi.categories', -1, 'controller', '.control');
-				$cats->supress_info	= true;
-				$cat_list	= $cats->return_sorted_array(0, false, '', '', '', false, $cat_id, false);
+				$cat_id = (int)$filters['control_areas'];
+				$cats = CreateObject('phpgwapi.categories', -1, 'controller', '.control');
+				$cats->supress_info = true;
+				$cat_list = $cats->return_sorted_array(0, false, '', '', '', false, $cat_id, false);
 				$cat_filter = array($cat_id);
 				foreach ($cat_list as $_category)
 				{
 					$cat_filter[] = $_category['id'];
 				}
 
-				$condition .= " AND control_area_id IN (" .  implode(',', $cat_filter) .')';
+				$condition .= " AND control_area_id IN (" . implode(',', $cat_filter) . ')';
 			}
 
 			$sql = "SELECT * FROM controller_procedure $condition $order";
 
-			if($results)
+			if ($results)
 			{
 				$this->db->limit_query($sql, $start, __LINE__, __FILE__, $results);
 			}
@@ -367,15 +367,14 @@
 			return $values;
 		}
 
-		function get_procedures_as_array($start = 0, $results = 1000, $sort = null, $dir = '', $query = null, $search_option = null, $filters = array())
+		function get_procedures_as_array( $start = 0, $results = 1000, $sort = null, $dir = '', $query = null, $search_option = null, $filters = array() )
 		{
 			$results = array();
 
 			//$condition = $this->get_conditions($query, $filters,$search_option);
-			$order = $sort ? "ORDER BY $sort $dir ": '';
+			$order = $sort ? "ORDER BY $sort $dir " : '';
 
 			//$sql = "SELECT * FROM controller_procedure WHERE $condition $order";
-
 			//$condition = "WHERE end_date IS NULL";
 			$sql = "SELECT * FROM controller_procedure $condition $order";
 			$this->db->limit_query($sql, $start, __LINE__, __FILE__, $results);
@@ -395,15 +394,16 @@
 				$procedure->set_revision_no($this->unmarshal($this->db->f('revision_no'), 'int'));
 				$procedure->set_revision_date($this->unmarshal($this->db->f('revision_date'), 'int'));
 
-				$results[] = $procedure->toArray();;
+				$results[] = $procedure->toArray();
+				;
 			}
 
 			return $results;
 		}
 
-		function get_old_revisions($id)
+		function get_old_revisions( $id )
 		{
-			$id = (int) $id;
+			$id = (int)$id;
 			$results = array();
 
 			$sql = "SELECT p.* FROM controller_procedure p WHERE procedure_id = {$id} ORDER BY end_date DESC";
@@ -424,49 +424,50 @@
 				$procedure->set_revision_no($this->unmarshal($this->db->f('revision_no'), 'int'));
 				$procedure->set_revision_date(date($GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'], $this->unmarshal($this->db->f('revision_date'), 'int')));
 				$procedure->set_control_area_id($this->unmarshal($this->db->f('control_area_id'), 'int'));
-				$category    = execMethod('phpgwapi.categories.return_single', $this->unmarshal($this->db->f('control_area_id', 'int')));
+				$category = execMethod('phpgwapi.categories.return_single', $this->unmarshal($this->db->f('control_area_id', 'int')));
 				$procedure->set_control_area_name($category_name = $category[0]['name']);
 
-				$results[] = $procedure->toArray();;
+				$results[] = $procedure->toArray();
+				;
 			}
 
 			return $results;
 		}
 
-		function get_id_field_name($extended_info = false)
+		function get_id_field_name( $extended_info = false )
 		{
 
-			if(!$extended_info)
+			if (!$extended_info)
 			{
 				$ret = 'id';
 			}
 			else
 			{
 				$ret = array
-				(
-					'table'			=> 'procedure', // alias
-					'field'			=> 'id',
-					'translated'	=> 'id'
+					(
+					'table' => 'procedure', // alias
+					'field' => 'id',
+					'translated' => 'id'
 				);
 			}
 
 			return $ret;
 		}
 
-		protected function get_query(string $sort_field, boolean $ascending, string $search_for, string $search_type, array $filters, boolean $return_count)
+		protected function get_query( string $sort_field, boolean $ascending, string $search_for, string $search_type, array $filters, boolean $return_count )
 		{
 			$clauses = array('1=1');
-			if($search_for)
+			if ($search_for)
 			{
 				$like_pattern = "'%" . $this->db->db_addslashes($search_for) . "%'";
 				$like_clauses = array();
-				switch($search_type)
+				switch ($search_type)
 				{
 					default:
 						$like_clauses[] = "procedure.title $this->like $like_pattern";
 						break;
 				}
-				if(count($like_clauses))
+				if (count($like_clauses))
 				{
 					$clauses[] = '(' . join(' OR ', $like_clauses) . ')';
 				}
@@ -475,49 +476,49 @@
 			$filter_clauses = array();
 			$filter_clauses[] = "procedure.end_date IS NULL";
 			/*
-			switch($filters['is_active']){
-				case "non_active":
-					$filter_clauses[] = "NOT controller_procedure.end_date IS NULL";
-					break;
-				default:
-					$filter_clauses[] = "controller_procedure.end_date IS NULL";
-					break;
-			}
-			*/
+			  switch($filters['is_active']){
+			  case "non_active":
+			  $filter_clauses[] = "NOT controller_procedure.end_date IS NULL";
+			  break;
+			  default:
+			  $filter_clauses[] = "controller_procedure.end_date IS NULL";
+			  break;
+			  }
+			 */
 
-			if(isset($filters[$this->get_id_field_name()]))
+			if (isset($filters[$this->get_id_field_name()]))
 			{
-				$filter_clauses[] = "procedure.id = {$this->marshal($filters[$this->get_id_field_name()],'int')}";
+				$filter_clauses[] = "procedure.id = {$this->marshal($filters[$this->get_id_field_name()], 'int')}";
 			}
-			if(isset($filters['control_areas']))
+			if (isset($filters['control_areas']))
 			{
 //				$filter_clauses[] = "procedure.control_area_id = {$this->marshal($filters['control_areas'], 'int')}";
 
-				$cat_id = (int) $filters['control_areas'];
-				$cats	= CreateObject('phpgwapi.categories', -1, 'controller', '.control');
-				$cats->supress_info	= true;
-				$cat_list	= $cats->return_sorted_array(0, false, '', '', '', false, $cat_id, false);
+				$cat_id = (int)$filters['control_areas'];
+				$cats = CreateObject('phpgwapi.categories', -1, 'controller', '.control');
+				$cats->supress_info = true;
+				$cat_list = $cats->return_sorted_array(0, false, '', '', '', false, $cat_id, false);
 				$cat_filter = array($cat_id);
 				foreach ($cat_list as $_category)
 				{
 					$cat_filter[] = $_category['id'];
 				}
 
-				$filter_clauses[] = "procedure.control_area_id IN (" .  implode(',', $cat_filter) .')';
+				$filter_clauses[] = "procedure.control_area_id IN (" . implode(',', $cat_filter) . ')';
 			}
 
-			if(count($filter_clauses))
+			if (count($filter_clauses))
 			{
 				$clauses[] = join(' AND ', $filter_clauses);
 			}
 
-			$condition =  join(' AND ', $clauses);
+			$condition = join(' AND ', $clauses);
 
 			//$joins = " {$this->left_join} controller_control_area ON (controller_procedure.control_area_id = controller_control_area.id)";
 
 			$tables = "controller_procedure procedure";
 
-			if($return_count) // We should only return a count
+			if ($return_count) // We should only return a count
 			{
 				$cols = 'COUNT(DISTINCT(procedure.id)) AS count';
 			}
@@ -527,19 +528,19 @@
 			}
 			//var_dump($sort_field);
 			$dir = $ascending ? 'ASC' : 'DESC';
-			$order = $sort_field ? "ORDER BY {$this->marshal($sort_field, 'field')} $dir ": '';
+			$order = $sort_field ? "ORDER BY {$this->marshal($sort_field, 'field')} $dir " : '';
 
 			//var_dump("SELECT {$cols} FROM {$tables} {$joins} WHERE {$condition} {$order}");
 
 			return "SELECT {$cols} FROM {$tables} {$joins} WHERE {$condition} {$order}";
 		}
 
-		function populate(int $procedure_id, &$procedure)
+		function populate( int $procedure_id, &$procedure )
 		{
 
-			if($procedure == null)
+			if ($procedure == null)
 			{
-				$procedure = new controller_procedure((int) $procedure_id);
+				$procedure = new controller_procedure((int)$procedure_id);
 
 				$procedure->set_title($this->unmarshal($this->db->f('title'), 'string'));
 				$procedure->set_purpose($this->unmarshal($this->db->f('purpose'), 'string'));
@@ -554,10 +555,10 @@
 				$procedure->set_revision_date($this->unmarshal($this->db->f('revision_date'), 'int'));
 				$procedure->set_control_area_id($this->unmarshal($this->db->f('control_area_id', 'int')));
 				//$procedure->set_control_area_name($this->unmarshal($this->db->f('control_area_name', 'string')));
-				$category    = execMethod('phpgwapi.categories.return_single', $this->unmarshal($this->db->f('control_area_id', 'int')));
+				$category = execMethod('phpgwapi.categories.return_single', $this->unmarshal($this->db->f('control_area_id', 'int')));
 				$procedure->set_control_area_name($category[0]['name']);
 			}
 
 			return $procedure;
 		}
-	}
+	}
\ No newline at end of file
