@@ -1,11 +1,11 @@
 <?php
-
 	/**
 	 * phpGroupWare - controller: a part of a Facilities Management System.
 	 *
 	 * @author Erik Holm-Larsen <erik.holm-larsen@bouvet.no>
 	 * @author Torstein Vadla <torstein.vadla@bouvet.no>
-	 * @copyright Copyright (C) 2011,2012 Free Software Foundation, Inc. http://www.fsf.org/
+	 * @author Sigurd Nes <sigurdne@online.no>
+	 * @copyright Copyright (C) 2011,2012,2013,2014,2015 Free Software Foundation, Inc. http://www.fsf.org/
 	 * This file is part of phpGroupWare.
 	 *
 	 * phpGroupWare is free software; you can redistribute it and/or modify
@@ -26,14 +26,14 @@
 	 * @internal Development of this application was funded by http://www.bergen.kommune.no/
 	 * @package property
 	 * @subpackage controller
-	 * @version $Id: class.uicalendar.inc.php 11430 2013-11-05 09:09:03Z sigurdne $
+	 * @version $Id: class.uicalendar.inc.php 14733 2016-02-12 14:14:26Z sigurdne $
 	 */
 	/**
 	 * Import the jQuery class
 	 */
 	phpgw::import_class('phpgwapi.jquery');
 
-	phpgw::import_class('phpgwapi.uicommon');
+	phpgw::import_class('phpgwapi.uicommon_jquery');
 	phpgw::import_class('controller.socheck_list');
 
 	include_class('controller', 'check_list', 'inc/model/');
@@ -46,7 +46,7 @@
 	include_class('controller', 'year_calendar_agg', 'inc/component/');
 	include_class('controller', 'month_calendar', 'inc/component/');
 
-	class controller_uicalendar extends phpgwapi_uicommon
+	class controller_uicalendar extends phpgwapi_uicommon_jquery
 	{
 
 		private $so;
@@ -56,13 +56,14 @@
 		private $so_control_item;
 		private $so_check_list;
 		private $so_check_item;
-        private $location_finder;
+		private $location_finder;
 		public $public_functions = array
 			(
 			'view_calendar_for_month' => true,
 			'view_calendar_for_year' => true,
 			'view_calendar_year_for_locations' => true,
-			'view_calendar_month_for_locations' => true
+			'view_calendar_month_for_locations' => true,
+			'update_bookmark' => true
 		);
 
 		public function __construct()
@@ -84,9 +85,20 @@
 			$this->so_check_list = CreateObject('controller.socheck_list');
 			$this->so_check_item = CreateObject('controller.socheck_item');
 
-            $this->location_finder = new location_finder();
-			     
+			$this->location_finder = new location_finder();
+
 			self::set_active_menu('controller::location_check_list');
+
+			if (phpgw::get_var('noframework', 'bool'))
+			{
+				$GLOBALS['phpgw_info']['flags']['noframework'] = true;
+				phpgwapi_cache::session_set('controller', 'noframework', true);
+			}
+			else if (phpgwapi_cache::session_get('controller', 'noframework'))
+			{
+				$GLOBALS['phpgw_info']['flags']['noframework'] = true;
+			}
+			$GLOBALS['phpgw']->css->add_external_file('controller/templates/base/css/base.css');
 		}
 
 		public function view_calendar_for_month()
@@ -108,7 +120,6 @@
 
 			// Validates role.
 //			$role = $this->validate_role($role);
-
 			// Gets timestamp value of first day in month
 			$from_date_ts = month_calendar::get_start_date_month_ts($year, intval($month));
 
@@ -165,7 +176,8 @@
 					$location_id = $component->get_location_id();
 					$component_id = $component->get_id();
 
-					$short_desc = execMethod('property.soentity.get_short_description', array('location_id' => $location_id, 'id' => $component_id));
+					$short_desc = execMethod('property.soentity.get_short_description', array('location_id' => $location_id,
+						'id' => $component_id));
 					$component->set_xml_short_desc($short_desc);
 
 					$controls_for_component_array = $component->get_controls_array();
@@ -182,7 +194,8 @@
 						$month_calendar = new month_calendar($control, $year, $month, $component, null, "component");
 						$calendar_array = $month_calendar->build_calendar($control->get_check_lists_array());
 
-						$controls_components_calendar_array[] = array("control" => $control->toArray(), "calendar_array" => $calendar_array);
+						$controls_components_calendar_array[] = array("control" => $control->toArray(),
+							"calendar_array" => $calendar_array);
 					}
 
 					$components_calendar_array[] = array("component" => $component->toArray(), "controls_calendar" => $controls_components_calendar_array);
@@ -190,7 +203,8 @@
 
 				$location_array = execMethod('property.bolocation.read_single', array('location_code' => $location_code));
 
-				$property_array = execMethod('property.solocation.read', array('type_id' => 1, 'allrows' => true));
+				$property_array = execMethod('property.solocation.read', array('type_id' => 1,
+					'allrows' => true));
 
 				// Gets array of locations assigned to current user
 				$my_locations = $this->get_my_assigned_locations($location_code);
@@ -207,29 +221,29 @@
 				);
 
 				$data = array
-				(
-					'buildings_on_property'     => $buildings_on_property,
-					'my_locations'              => $my_locations,
-					'property_array'            => $property_array,
-					'current_location'          => $location_array,
-					'heading_array'             => $heading_array,
-					'controls_calendar_array'   => $controls_calendar_array,
+					(
+					'buildings_on_property' => $buildings_on_property,
+					'my_locations' => $my_locations,
+					'property_array' => $property_array,
+					'current_location' => $location_array,
+					'heading_array' => $heading_array,
+					'controls_calendar_array' => $controls_calendar_array,
 					'components_calendar_array' => $components_calendar_array,
-					'location_level'            => $level,
-					'roles_array'               => $roles_array,
-					'repeat_type_array'         => $repeat_type_array,
-					'current_year'              => $year,
-					'current_month_nr'          => $month,
-					'current_role'              => $role,
-					'current_repeat_type'       => $repeat_type
+					'location_level' => $level,
+					'roles_array' => $roles_array,
+					'repeat_type_array' => $repeat_type_array,
+					'current_year' => $year,
+					'current_month_nr' => $month,
+					'current_role' => $role,
+					'current_repeat_type' => $repeat_type
 				);
 
 				phpgwapi_jquery::load_widget('autocomplete');
 				self::add_javascript('controller', 'controller', 'ajax.js');
 				self::render_template_xsl(array('calendar/view_calendar_month', 'calendar/check_list_status_manager',
-                                                'calendar/icon_color_map', 'calendar/select_my_locations',
-												'calendar/select_buildings_on_property', 'calendar/nav_calendar_month',
-												'calendar/calendar_filters'), $data);
+					'calendar/icon_color_map', 'calendar/select_my_locations',
+					'calendar/select_buildings_on_property', 'calendar/nav_calendar_month',
+					'calendar/calendar_filters'), $data);
 			}
 			else
 			{
@@ -249,7 +263,7 @@
 		{
 			$location_code = phpgw::get_var('location_code');
 			$year = phpgw::get_var('year');
-			$role = phpgw::get_var('role', 'int', 'REQUEST', -1);
+			$role = phpgw::get_var('role', 'int');
 
 			$repeat_type = phpgw::get_var('repeat_type');
 
@@ -261,7 +275,6 @@
 
 			// Validates role.
 //			$role = $this->validate_role($role);
-
 			// Gets timestamp of first day in year
 			$from_date_ts = $this->get_start_date_year_ts($year);
 
@@ -347,7 +360,8 @@
 					$location_id = $component->get_location_id();
 					$id = $component->get_id();
 
-					$short_desc_arr = execMethod('property.soentity.get_short_description', array('location_id' => $location_id, 'id' => $id));
+					$short_desc_arr = execMethod('property.soentity.get_short_description', array(
+						'location_id' => $location_id, 'id' => $id));
 					$component->set_xml_short_desc($short_desc_arr);
 
 					$controls_for_component_array = $component->get_controls_array();
@@ -371,7 +385,8 @@
 							$year_calendar_agg = new year_calendar_agg($control, $year, $location_code, "VIEW_CONTROLS_FOR_LOCATION");
 							$calendar_array = $year_calendar_agg->build_calendar($agg_open_cases_pr_month_array);
 
-							$controls_components_calendar_array[] = array("control" => $control->toArray(), "calendar_array" => $calendar_array);
+							$controls_components_calendar_array[] = array("control" => $control->toArray(),
+								"calendar_array" => $calendar_array);
 						}
 						else
 						{
@@ -384,7 +399,8 @@
 							$year_calendar = new year_calendar($control, $year, $component, null, "component");
 							$calendar_array = $year_calendar->build_calendar($control->get_check_lists_array());
 
-							$controls_components_calendar_array[] = array("control" => $control->toArray(), "calendar_array" => $calendar_array);
+							$controls_components_calendar_array[] = array("control" => $control->toArray(),
+								"calendar_array" => $calendar_array);
 						}
 					}
 
@@ -427,9 +443,9 @@
 				self::add_javascript('controller', 'controller', 'ajax.js');
 
 				self::render_template_xsl(array('calendar/view_calendar_year', 'calendar/check_list_status_manager',
-                                                'calendar/icon_color_map', 'calendar/select_my_locations',
-                                                'calendar/select_buildings_on_property', 'calendar/nav_calendar_year',
-                                                'calendar/calendar_filters'), $data);
+					'calendar/icon_color_map', 'calendar/select_my_locations',
+					'calendar/select_buildings_on_property', 'calendar/nav_calendar_year',
+					'calendar/calendar_filters'), $data);
 			}
 			else
 			{
@@ -451,27 +467,42 @@
 			$control_id = phpgw::get_var('control_id', 'int');
 			$control = $this->so_control->get_single($control_id);
 			$year = phpgw::get_var('year', 'int');
-			$location_code = phpgw::get_var('location_code');
+			$location_id = phpgw::get_var('location_id', 'int');
+			$component_id = phpgw::get_var('component_id', 'int');
+			$serie_id = phpgw::get_var('serie_id', 'int');
+
+
+			$user_id = $GLOBALS['phpgw_info']['user']['account_id'];
+
+			$bookmarks = phpgwapi_cache::user_get('controller', "location_bookmark", $user_id);
+			if (is_array($bookmarks))
+			{
+				$bookmark_locations = array_keys($bookmarks);
+			}
+
+			if ($location_code = phpgw::get_var('location_code'))
+			{
+				$bookmark_locations[] = $location_code;
+			}
 
 			$locations_list = array();
 
 			if (is_numeric($control_id) & $control_id > 0)
 			{
 				$locations_for_control_array = $this->so_control->get_locations_for_control($control_id);
-				$components_for_control_array = $this->so_control->get_components_for_control($control_id);
+				$components_for_control_array = $this->so_control->get_components_for_control($control_id, $location_id, $component_id, $serie_id);
 				foreach ($locations_for_control_array as $location)
 				{
 					$locations_list[] = array
-					(
-						'id'		=> $location['location_code'],
-						'name'		=> $location['loc_name'],
-						'selected'	=> $location_code == $location['location_code'] ? 1 : 0
+						(
+						'id' => $location['location_code'],
+						'name' => $location['loc_name'],
+						'selected' => $location_code == $location['location_code'] ? 1 : 0
 					);
 				}
 
 				reset($locations_for_control_array);
 				unset($location);
-
 			}
 
 			// Validates year. If year is not set, current year is chosen
@@ -492,8 +523,8 @@
 				foreach ($locations_for_control_array as $location)
 				{
 					$curr_location_code = $location['location_code'];
-					
-					if(!$location_code || $curr_location_code != $location_code)
+
+					if (!$bookmark_locations || !in_array($curr_location_code, $bookmark_locations))
 					{
 						continue;
 					}
@@ -510,13 +541,37 @@
 
 					$year_calendar_agg = new year_calendar_agg($control, $year, $curr_location_code, "VIEW_LOCATIONS_FOR_CONTROL");
 					$calendar_array = $year_calendar_agg->build_calendar($agg_open_cases_pr_month_array);
-					$locations_with_calendar_array[] = array("location" => $location, "calendar_array" => $calendar_array);
+
+					$locations_with_calendar_array[] = array
+						(
+						'location' => $location,
+						'calendar_array' => $calendar_array,
+						'selected' => $bookmarks && isset($bookmarks[$curr_location_code])
+					);
 				}
 
 				// COMPONENTS: Process aggregated values for controls with repeat type day or week
 				foreach ($components_for_control_array as $component)
 				{
-					$short_desc_arr = execMethod('property.soentity.get_short_description', array('location_id' => $component->get_location_id(), 'id' => $component->get_id()));
+					$short_desc_arr = execMethod('property.soentity.get_short_description', array(
+						'location_id' => $component->get_location_id(), 'id' => $component->get_id()));
+					if (!isset($_location_name[$component->get_location_code()]))
+					{
+						$_location = execMethod('property.solocation.read_single', $component->get_location_code());
+						$location_arr = explode('-', $component->get_location_code());
+						$i = 1;
+						$name_arr = array();
+						foreach ($location_arr as $_dummy)
+						{
+							$name_arr[] = $_location["loc{$i}_name"];
+							$i++;
+						}
+
+						$_location_name[$component->get_location_code()] = implode('::', $name_arr);
+					}
+
+					$short_desc_arr .= ' [' . $_location_name[$component->get_location_code()] . ']';
+
 					$component->set_xml_short_desc($short_desc_arr);
 
 					$repeat_type = $control->get_repeat_type();
@@ -535,7 +590,8 @@
 
 					$year_calendar_agg = new year_calendar_agg($control, $year, $location_code, "VIEW_LOCATIONS_FOR_CONTROL");
 					$calendar_array = $year_calendar_agg->build_calendar($agg_open_cases_pr_month_array);
-					$components_with_calendar_array[] = array("component" => $component->toArray(), "calendar_array" => $calendar_array);
+					$components_with_calendar_array[] = array("component" => $component->toArray(),
+						"calendar_array" => $calendar_array);
 				}
 			}
 			// Process values for controls with repeat type month or year
@@ -545,7 +601,7 @@
 				{
 					$curr_location_code = $location['location_code'];
 
-					if(!$location_code || $curr_location_code != $location_code)
+					if (!$bookmark_locations || !in_array($curr_location_code, $bookmark_locations))
 					{
 						continue;
 					}
@@ -556,33 +612,39 @@
 					$year_calendar = new year_calendar($control, $year, null, $curr_location_code, "location");
 					$calendar_array = $year_calendar->build_calendar($check_lists_array);
 
-					$locations_with_calendar_array[] = array("location" => $location, "calendar_array" => $calendar_array);
+					$locations_with_calendar_array[] = array
+						(
+						'location' => $location,
+						'calendar_array' => $calendar_array,
+						'selected' => $bookmarks && isset($bookmarks[$curr_location_code])
+					);
 				}
 
 				foreach ($components_for_control_array as $component)
 				{
-					$short_desc_arr = execMethod('property.soentity.get_short_description', array('location_id' => $component->get_location_id(), 'id' => $component->get_id()));
+					$short_desc_arr = execMethod('property.soentity.get_short_description', array(
+						'location_id' => $component->get_location_id(), 'id' => $component->get_id()));
 
 					//FIXME - make generic
-					
-				/*=>*/
-					if(!isset($_location_name[$component->get_location_code()]))
+
+					/* => */
+					if (!isset($_location_name[$component->get_location_code()]))
 					{
 						$_location = execMethod('property.solocation.read_single', $component->get_location_code());
 						$location_arr = explode('-', $component->get_location_code());
-						$i=1;
+						$i = 1;
 						$name_arr = array();
-						foreach($location_arr as $_dummy)
+						foreach ($location_arr as $_dummy)
 						{
 							$name_arr[] = $_location["loc{$i}_name"];
 							$i++;
 						}
 
-						$_location_name[$component->get_location_code()]= implode('::', $name_arr);
+						$_location_name[$component->get_location_code()] = implode('::', $name_arr);
 					}
 
-					$short_desc_arr .= ' ['. $_location_name[$component->get_location_code()] . ']';
-				/*<=*/
+					$short_desc_arr .= ' [' . $_location_name[$component->get_location_code()] . ']';
+					/* <= */
 
 					$component->set_xml_short_desc($short_desc_arr);
 
@@ -591,10 +653,37 @@
 
 					$check_lists_array = $component_with_check_lists["check_lists_array"];
 
+					/*
+					 * start override control with data from serie
+					 */
+					$control_relation = $component->get_control_relation();
+					if (isset($control_relation['start_date']) && $control_relation['start_date'])
+					{
+						$control->set_start_date($control_relation['start_date']);
+					}
+
+					if (isset($control_relation['end_date']) && $control_relation['end_date'])
+					{
+						$control->set_end_date($control_relation['end_date']);
+					}
+					if (isset($control_relation['repeat_type']) && $control_relation['repeat_type'])
+					{
+						$control->set_repeat_type($control_relation['repeat_type']);
+					}
+					if (isset($control_relation['repeat_interval']) && $control_relation['repeat_interval'])
+					{
+						$control->set_repeat_interval($control_relation['repeat_interval']);
+					}
+
+					/*
+					 * End override control with data from serie
+					 */
+
 					$year_calendar = new year_calendar($control, $year, $component, null, "component");
 					$calendar_array = $year_calendar->build_calendar($check_lists_array);
 
-					$components_with_calendar_array[] = array("component" => $component->toArray(), "calendar_array" => $calendar_array);
+					$components_with_calendar_array[] = array("component" => $component->toArray(),
+						"calendar_array" => $calendar_array);
 				}
 			}
 
@@ -604,19 +693,20 @@
 			$heading_array = year_calendar::get_heading_array();
 
 			$data = array
-			(
-				'locations_list'					=> $locations_list,
-				'my_locations'						=> $my_locations,
-				'control'							=> $control->toArray(),
-				'heading_array'						=> $heading_array,
-				'locations_with_calendar_array'		=> $locations_with_calendar_array,
-				'components_with_calendar_array'	=> $components_with_calendar_array,
-				'current_year'						=> $year,
-				'location_code'						=> $location_code
+				(
+				'locations_list' => $locations_list,
+				'my_locations' => $my_locations,
+				'control' => $control->toArray(),
+				'heading_array' => $heading_array,
+				'locations_with_calendar_array' => $locations_with_calendar_array,
+				'components_with_calendar_array' => $components_with_calendar_array,
+				'current_year' => $year,
+				'location_code' => $location_code,
+				'serie_id' => $serie_id,
 			);
 
 			self::render_template_xsl(array('calendar/view_calendar_year_for_locations', 'calendar/check_list_status_manager',
-                                            'calendar/icon_color_map', 'calendar/select_my_locations', 'calendar/nav_calendar_year'), $data);
+				'calendar/icon_color_map', 'calendar/select_my_locations', 'calendar/nav_calendar_year'), $data);
 
 			phpgwapi_jquery::load_widget('core');
 			self::add_javascript('controller', 'controller', 'ajax.js');
@@ -624,29 +714,53 @@
 
 		public function view_calendar_month_for_locations()
 		{
-			$control_id = phpgw::get_var('control_id');
+			static $_location_name = array();
+			$control_id = phpgw::get_var('control_id', 'int');
 			$control = $this->so_control->get_single($control_id);
-			$year = intval(phpgw::get_var('year'));
-			$month = intval(phpgw::get_var('month'));
-			$location_code = phpgw::get_var('location_code');
+			if (!$year = intval(phpgw::get_var('year')))
+			{
+				$year = date('Y');
+			}
+			if (!$month = intval(phpgw::get_var('month')))
+			{
+				$month = date('m');
+			}
+
+			$location_id = phpgw::get_var('location_id', 'int');
+			$component_id = phpgw::get_var('component_id', 'int');
+			$serie_id = phpgw::get_var('serie_id', 'int');
+
+
+			$user_id = $GLOBALS['phpgw_info']['user']['account_id'];
+
+			$bookmark_locations = array();
+			$bookmarks = phpgwapi_cache::user_get('controller', "location_bookmark", $user_id);
+			if (is_array($bookmarks))
+			{
+				$bookmark_locations = array_keys($bookmarks);
+			}
+
+			if ($location_code = phpgw::get_var('location_code'))
+			{
+				$bookmark_locations[] = $location_code;
+			}
 
 			if (is_numeric($control_id) & $control_id > 0)
 			{
 				$locations_for_control_array = $this->so_control->get_locations_for_control($control_id);
-				$components_for_control_array = $this->so_control->get_components_for_control($control_id);
+				$components_for_control_array = $this->so_control->get_components_for_control($control_id, $location_id, $component_id, $serie_id);
 				foreach ($locations_for_control_array as $location)
 				{
 					$locations_list[] = array
-					(
-						'id'		=> $location['location_code'],
-						'name'		=> $location['loc_name'],
-						'selected'	=> $location_code == $location['location_code'] ? 1 : 0
+						(
+						'id' => $location['location_code'],
+						'name' => $location['loc_name'],
+						'selected' => $location_code == $location['location_code'] ? 1 : 0
 					);
 				}
 
 				reset($locations_for_control_array);
 				unset($location);
-
 			}
 
 			// Validates year. If year is not set, current year is chosen
@@ -667,7 +781,7 @@
 			{
 				$curr_location_code = $location['location_code'];
 
-				if(!$location_code || $curr_location_code != $location_code)
+				if (!$bookmark_locations || !in_array($curr_location_code, $bookmark_locations))
 				{
 					continue;
 				}
@@ -675,26 +789,78 @@
 				$repeat_type = $control->get_repeat_type();
 				$check_lists_array = $this->so->get_check_lists_for_control_and_location($control_id, $curr_location_code, $from_date_ts, $to_date_ts, $control->get_repeat_type());
 
-                $month_calendar = new month_calendar($control, $year, $month, null, $curr_location_code, "location");
+				$month_calendar = new month_calendar($control, $year, $month, null, $curr_location_code, "location");
 				$calendar_array = $month_calendar->build_calendar($check_lists_array);
 
-				$locations_with_calendar_array[] = array("location" => $location, "calendar_array" => $calendar_array);
+				$locations_with_calendar_array[] = array
+					(
+					'location' => $location,
+					'calendar_array' => $calendar_array,
+					'selected' => $bookmarks && isset($bookmarks[$curr_location_code])
+				);
 			}
 
 			foreach ($components_for_control_array as $component)
 			{
-				$short_desc_arr = execMethod('property.soentity.get_short_description', array('location_id' => $component->get_location_id(), 'id' => $component->get_id()));
+				$short_desc_arr = execMethod('property.soentity.get_short_description', array(
+					'location_id' => $component->get_location_id(), 'id' => $component->get_id()));
+				if (!isset($_location_name[$component->get_location_code()]))
+				{
+					$_location = execMethod('property.solocation.read_single', $component->get_location_code());
+					$location_arr = explode('-', $component->get_location_code());
+					$i = 1;
+					$name_arr = array();
+					foreach ($location_arr as $_dummy)
+					{
+						$name_arr[] = $_location["loc{$i}_name"];
+						$i++;
+					}
+
+					$_location_name[$component->get_location_code()] = implode('::', $name_arr);
+				}
+
+				$short_desc_arr .= ' [' . $_location_name[$component->get_location_code()] . ']';
+
 				$component->set_xml_short_desc($short_desc_arr);
 
 				$repeat_type = $control->get_repeat_type();
-				$component_with_check_lists = $this->so->get_check_lists_for_control_and_component($control_id, $component->get_location_id(), $component->get_id(), $from_date_ts, $to_date_ts, $control->get_repeat_type());
+				$component_with_check_lists = $this->so->get_check_lists_for_control_and_component($control_id, $component->get_location_id(), $component->get_id(), $from_date_ts, $to_date_ts, $repeat_type);
 
 				$check_lists_array = $component_with_check_lists["check_lists_array"];
 
+				/*
+				 * Start override control with data from serie
+				 */
+
+				$control_relation = $component->get_control_relation();
+				if (isset($control_relation['start_date']) && $control_relation['start_date'])
+				{
+					$control->set_start_date($control_relation['start_date']);
+				}
+
+				if (isset($control_relation['end_date']) && $control_relation['end_date'])
+				{
+					$control->set_end_date($control_relation['end_date']);
+				}
+				if (isset($control_relation['repeat_type']) && $control_relation['repeat_type'])
+				{
+					$control->set_repeat_type($control_relation['repeat_type']);
+				}
+				if (isset($control_relation['repeat_interval']) && $control_relation['repeat_interval'])
+				{
+					$control->set_repeat_interval($control_relation['repeat_interval']);
+				}
+
+				/*
+				 * End override control with data from serie
+				 */
+
 				$month_calendar = new month_calendar($control, $year, $month, $component, null, "component");
 				$calendar_array = $month_calendar->build_calendar($check_lists_array);
 
-				$components_with_calendar_array[] = array("component" => $component->toArray(), "calendar_array" => $calendar_array);
+
+				$components_with_calendar_array[] = array("component" => $component->toArray(),
+					"calendar_array" => $calendar_array);
 			}
 
 			// Gets array of locations assigned to current user
@@ -703,28 +869,30 @@
 			$heading_array = month_calendar::get_heading_array($year, $month);
 
 			$data = array
-			(
-				'control'							=> $control->toArray(),
-				'my_locations'						=> $my_locations,
-				'property_array'					=> $property_array,
-				'location_array'					=> $location_array,
-				'heading_array'						=> $heading_array,
-				'locations_with_calendar_array'		=> $locations_with_calendar_array,
-				'components_with_calendar_array'	=> $components_with_calendar_array,
-				'current_year'						=> $year,
-				'current_month_nr'					=> $month,
-				'locations_list'					=> $locations_list,
-				'location_code'						=> $location_code
+				(
+				'control' => $control->toArray(),
+				'my_locations' => $my_locations,
+				'property_array' => $property_array,
+				'location_array' => $location_array,
+				'heading_array' => $heading_array,
+				'locations_with_calendar_array' => $locations_with_calendar_array,
+				'components_with_calendar_array' => $components_with_calendar_array,
+				'current_year' => $year,
+				'current_month_nr' => $month,
+				'locations_list' => $locations_list,
+				'location_code' => $location_code,
+				'serie_id' => $serie_id,
 			);
 
-			self::render_template_xsl(array('calendar/view_calendar_month_for_locations', 'calendar/check_list_status_manager',
+			self::render_template_xsl(array('calendar/view_calendar_month_for_locations',
+				'calendar/check_list_status_manager',
 				'calendar/icon_color_map', 'calendar/select_my_locations', 'calendar/nav_calendar_month'), $data);
 
 			phpgwapi_jquery::load_widget('core');
 			self::add_javascript('controller', 'controller', 'ajax.js');
 		}
 
-		public function populate_controls_with_check_lists($controls_for_location_array, $control_id_with_check_list_array)
+		public function populate_controls_with_check_lists( $controls_for_location_array, $control_id_with_check_list_array )
 		{
 			$controls_with_check_list = array();
 
@@ -745,7 +913,7 @@
 		}
 
 		// Generates array of aggregated number of open cases for each month in time period
-		function build_agg_open_cases_pr_month_array($cl_criteria, $year, $from_month, $to_month)
+		function build_agg_open_cases_pr_month_array( $cl_criteria, $year, $from_month, $to_month )
 		{
 
 			$agg_open_cases_pr_month_array = array();
@@ -774,7 +942,7 @@
 			return $agg_open_cases_pr_month_array;
 		}
 
-		function get_start_month_for_control($control)
+		function get_start_month_for_control( $control )
 		{
 			// Checks if control starts in the year that is displayed
 			if (date("Y", $control->get_start_date()) == $year)
@@ -789,7 +957,7 @@
 			return $from_month;
 		}
 
-		function get_end_month_for_control($control)
+		function get_end_month_for_control( $control )
 		{
 			// Checks if control ends in the year that is displayed
 			if (date("Y", $control->get_end_date()) == $year)
@@ -804,7 +972,7 @@
 			return $to_month;
 		}
 
-		function validate_location_code($location_code)
+		function validate_location_code( $location_code )
 		{
 			$criteria = array
 				(
@@ -816,17 +984,17 @@
 
 			if (empty($location_code))
 			{
-                $my_locations = $this->location_finder->get_responsibilities($criteria);
-                if( count($my_locations) > 0 )
-                {
-                    $location_code = $my_locations[0]["location_code"];
-                }
+				$my_locations = $this->location_finder->get_responsibilities($criteria);
+				if (count($my_locations) > 0)
+				{
+					$location_code = $my_locations[0]["location_code"];
+				}
 			}
 
 			return $location_code;
 		}
 
-		function get_my_assigned_locations($current_location_code)
+		function get_my_assigned_locations( $current_location_code )
 		{
 			$criteria = array
 				(
@@ -851,7 +1019,7 @@
 			return $my_washed_locations;
 		}
 
-		function get_month_start_ts($year, $month)
+		function get_month_start_ts( $year, $month )
 		{
 			if ($month > 12)
 			{
@@ -862,12 +1030,12 @@
 			return strtotime("$month/01/$year");
 		}
 
-		function get_start_date_year_ts($year)
+		function get_start_date_year_ts( $year )
 		{
 			return strtotime("01/01/$year");
 		}
 
-		function get_end_date_year_ts($year)
+		function get_end_date_year_ts( $year )
 		{
 			$to_year = $year + 1;
 			$end_date_year_ts = strtotime("01/01/$to_year");
@@ -875,7 +1043,7 @@
 			return $end_date_year_ts;
 		}
 
-		function validate_year($validate_year)
+		function validate_year( $validate_year )
 		{
 			if (empty($validate_year))
 			{
@@ -887,7 +1055,7 @@
 			return $validate_year;
 		}
 
-		function validate_repeat_type($validate_repeat_type)
+		function validate_repeat_type( $validate_repeat_type )
 		{
 			if ($validate_repeat_type != 0 & (empty($validate_repeat_type) | ($validate_repeat_type > 3)))
 			{
@@ -897,7 +1065,7 @@
 			return $validate_repeat_type;
 		}
 
-		function validate_role($validate_role)
+		function validate_role( $validate_role )
 		{
 			if (empty($validate_role) | (!is_numeric($validate_role)) | ($validate_role < 1))
 			{
@@ -907,7 +1075,7 @@
 			return $validate_role;
 		}
 
-		function validate_month($month)
+		function validate_month( $month )
 		{
 			if (empty($month))
 			{
@@ -921,8 +1089,36 @@
 
 		public function query()
 		{
-
+			
 		}
 
-	}
+		public function update_bookmark()
+		{
+			$location_code = phpgw::get_var('location_code', 'string');
+			$user_id = $GLOBALS['phpgw_info']['user']['account_id'];
 
+			$bookmarks = phpgwapi_cache::user_get('controller', "location_bookmark", $user_id);
+			if ($bookmarks && is_array($bookmarks) && isset($bookmarks[$location_code]))
+			{
+				unset($bookmarks[$location_code]);
+				$status = lang('deleted');
+			}
+			else
+			{
+				if (!is_array($bookmarks))
+				{
+					$bookmarks = array();
+				}
+
+				$bookmarks[$location_code] = true;
+				$status = lang('added');
+			}
+
+			phpgwapi_cache::user_set('controller', "location_bookmark", $bookmarks, $user_id);
+
+			return array
+				(
+				'status' => $status
+			);
+		}
+	}
\ No newline at end of file
