@@ -10,19 +10,19 @@
 			'precision' => 4,
 			'nullable' => True
 		));
-		
+
 		$GLOBALS['phpgw_setup']->oProc->AddColumn('controller_procedure','revision_no',array(
 			'type' => 'int',
 			'precision' => 4,
 			'nullable' => True
 		));
-		
+
 		$GLOBALS['phpgw_setup']->oProc->AddColumn('controller_procedure','revision_date',array(
 			'type' => 'int',
 			'precision' => 8,
 			'nullable' => True
 		));
-		
+
 		$GLOBALS['setup_info']['controller']['currentver'] = '0.1.1';
 		return $GLOBALS['setup_info']['controller']['currentver'];
 	}
@@ -35,11 +35,11 @@
 			'precision' => 4,
 			'nullable' => True
 		));
-		
+
 		$GLOBALS['setup_info']['controller']['currentver'] = '0.1.2';
 		return $GLOBALS['setup_info']['controller']['currentver'];
 	}
-	
+
 	$test[] = '0.1.2';
 	function controller_upgrade0_1_2()
 	{
@@ -56,23 +56,23 @@
 			'ix' => array(),
 			'uc' => array()
 			)
-		);	
-		
+		);
+
 		$GLOBALS['setup_info']['controller']['currentver'] = '0.1.3';
 		return $GLOBALS['setup_info']['controller']['currentver'];
 	}
-	
+
 	$test[] = '0.1.3';
 	function controller_upgrade0_1_3()
 	{
 		$GLOBALS['phpgw_setup']->oProc->DropColumn('controller_control_group', array(), 'order_nr');
-			
+
 		$GLOBALS['setup_info']['controller']['currentver'] = '0.1.4';
 		return $GLOBALS['setup_info']['controller']['currentver'];
 	}
-	
+
 	/* Update Controller from v 0.1.4 to 0.1.5 */
-	
+
 	$test[] = '0.1.4';
 	function controller_upgrade0_1_4()
 	{
@@ -81,36 +81,36 @@
 			'precision' => 4,
 			'nullable' => True
 		));
-		
+
 		$GLOBALS['setup_info']['controller']['currentver'] = '0.1.5';
 		return $GLOBALS['setup_info']['controller']['currentver'];
 	}
-	
+
 	/* Update Controller from v 0.1.5 to 0.1.6 */
-	
+
 	$test[] = '0.1.5';
 	function controller_upgrade0_1_5()
 	{
 		$GLOBALS['phpgw_setup']->oProc->DropColumn('controller_check_list', array(), 'check_list_id');
-		
+
 		$GLOBALS['phpgw_setup']->oProc->AddColumn('controller_check_list','planned_date',array(
 			'type' => 'int',
 			'precision' => 8,
 			'nullable' => True
 		));
-		
+
 		$GLOBALS['phpgw_setup']->oProc->AddColumn('controller_check_list','completed_date',array(
 			'type' => 'int',
 			'precision' => 8,
 			'nullable' => True
 		));
-		
+
 		$GLOBALS['setup_info']['controller']['currentver'] = '0.1.6';
 		return $GLOBALS['setup_info']['controller']['currentver'];
 	}
-	
+
 	/* Update Controller from v 0.1.6 to 0.1.7 */
-	
+
 	$test[] = '0.1.6';
 	function controller_upgrade0_1_6()
 	{
@@ -125,31 +125,31 @@
 			'precision' => 4,
 			'nullable' => True
 		));
-		
+
 		$GLOBALS['setup_info']['controller']['currentver'] = '0.1.7';
 		return $GLOBALS['setup_info']['controller']['currentver'];
 	}
-	
+
 	/* Update Controller from v 0.1.7 to 0.1.8 */
-	
+
 	$test[] = '0.1.7';
 	function controller_upgrade0_1_7()
 	{
 		$GLOBALS['phpgw_setup']->oProc->DropColumn('controller_check_item', array(), 'status');
-		
+
 		$GLOBALS['phpgw_setup']->oProc->AddColumn('controller_check_item','status',array(
 			'type' => 'int',
 			'precision' => 2,
 			'nullable' => true,
 			'default' => 0
 		));
-			
+
 		$GLOBALS['setup_info']['controller']['currentver'] = '0.1.8';
 		return $GLOBALS['setup_info']['controller']['currentver'];
 	}
-	
+
 	/* Update Controller from v 0.1.8 to 0.1.9 */
-	
+
 	$test[] = '0.1.8';
 	function controller_upgrade0_1_8()
 	{
@@ -165,16 +165,16 @@
 			'ix' => array(),
 			'uc' => array()
 			)
-		);	
-			
+		);
+
 		$GLOBALS['setup_info']['controller']['currentver'] = '0.1.9';
 		return $GLOBALS['setup_info']['controller']['currentver'];
 	}
-	
+
 	/* Update Controller from v 0.1.9 to 0.1.10
 	 * Add table for connecting equipment (BIM) and control
 	*/
-	
+
 	$test[] = '0.1.9';
 	function controller_upgrade0_1_9()
 	{
@@ -190,8 +190,8 @@
 			'ix' => array(),
 			'uc' => array()
 			)
-		);	
-			
+		);
+
 		$GLOBALS['setup_info']['controller']['currentver'] = '0.1.10';
 		return $GLOBALS['setup_info']['controller']['currentver'];
 	}
@@ -199,7 +199,7 @@
 	/* Update Controller from v 0.1.10 to 0.1.11
 	 * Alter from naming from equipment to more generic component
 	*/
-	
+
 	$test[] = '0.1.10';
 	function controller_upgrade0_1_10()
 	{
@@ -215,11 +215,11 @@
 			'ix' => array(),
 			'uc' => array()
 			)
-		);	
+		);
 
 		$GLOBALS['phpgw_setup']->oProc->RenameColumn('controller_check_list','equipment_id','component_id');
 
-		$GLOBALS['phpgw_setup']->oProc->DropTable('controller_control_equipment_list');			
+		$GLOBALS['phpgw_setup']->oProc->DropTable('controller_control_equipment_list');
 
 		$GLOBALS['setup_info']['controller']['currentver'] = '0.1.11';
 		return $GLOBALS['setup_info']['controller']['currentver'];
@@ -228,13 +228,13 @@
 	/* Update Controller from v 0.1.11 to 0.1.12
 	 * Add locations for control and checklist
 	*/
-	
+
 	$test[] = '0.1.11';
 	function controller_upgrade0_1_11()
 	{
 		$GLOBALS['phpgw_setup']->oProc->RenameColumn('controller_control','equipment_type_id','component_type_id');
 		$GLOBALS['phpgw_setup']->oProc->RenameColumn('controller_control','equipment_id','component_id');
-				
+
 		$GLOBALS['phpgw']->locations->add('.control', 'Control', 'controller');
 		$GLOBALS['phpgw']->locations->add('.checklist', 'Checklist', 'controller');
 		$GLOBALS['phpgw']->locations->add('.procedure', 'Procedure', 'controller');
@@ -242,7 +242,7 @@
 		$GLOBALS['setup_info']['controller']['currentver'] = '0.1.12';
 		return $GLOBALS['setup_info']['controller']['currentver'];
 	}
-	
+
 	$test[] = '0.1.12';
 	function controller_upgrade0_1_12()
 	{
@@ -258,7 +258,7 @@
 				'uc' => array()
 			)
 		);
-		
+
 		$GLOBALS['phpgw_setup']->oProc->CreateTable(
 			'controller_document', array(
 				'fd' => array(
@@ -282,7 +282,7 @@
 		$GLOBALS['setup_info']['controller']['currentver'] = '0.1.13';
 		return $GLOBALS['setup_info']['controller']['currentver'];
 	}
-	
+
 	$test[] = '0.1.13';
 	function controller_upgrade0_1_13()
 	{
@@ -306,7 +306,7 @@
 			'nullable' => true,
 			'default' => 0
 		));
-		
+
 		$GLOBALS['phpgw_setup']->oProc->AddColumn('controller_control_item', 'type',array(
 			'type' => 'varchar',
 			'precision' => 255,
@@ -317,13 +317,13 @@
 		$GLOBALS['setup_info']['controller']['currentver'] = '0.1.15';
 		return $GLOBALS['setup_info']['controller']['currentver'];
 	}
-	
+
 	$test[] = '0.1.15';
 	function controller_upgrade0_1_15()
 	{
 		$GLOBALS['phpgw_setup']->oProc->DropColumn('controller_check_item', array(), 'message_ticket_id');
 		$GLOBALS['phpgw_setup']->oProc->DropColumn('controller_check_item', array(), 'measurement');
-		
+
 		$GLOBALS['phpgw_setup']->oProc->CreateTable(
 			'controller_check_item_case', array(
 				'fd' => array(
@@ -338,11 +338,11 @@
 				'uc' => array()
 			)
 		);
-		
+
 		$GLOBALS['setup_info']['controller']['currentver'] = '0.1.16';
 		return $GLOBALS['setup_info']['controller']['currentver'];
 	}
-	
+
 	$test[] = '0.1.16';
 	function controller_upgrade0_1_16()
 	{
@@ -351,22 +351,22 @@
 			'precision' => '8',
 			'nullable' => true
 		));
-		
+
 		$GLOBALS['phpgw_setup']->oProc->AlterColumn('controller_check_item_case','measurement',array(
 			'type' => 'varchar',
 			'precision' => '50',
 			'nullable' => true
 		));
-		
+
 		$GLOBALS['setup_info']['controller']['currentver'] = '0.1.17';
 		return $GLOBALS['setup_info']['controller']['currentver'];
 	}
-	
+
 	$test[] = '0.1.17';
 	function controller_upgrade0_1_17()
 	{
 		$GLOBALS['phpgw_setup']->oProc->DropTable('controller_check_item_case');
-		
+
 		$GLOBALS['phpgw_setup']->oProc->CreateTable(
 			'controller_check_item_case', array(
 				'fd' => array(
@@ -387,7 +387,7 @@
 	                'uc' => array()
 			)
 		);
-		
+
 		$GLOBALS['phpgw_setup']->oProc->AddColumn('controller_check_item', 'measurement',array(
 			'type' => 'varchar',
 			'precision' => 50,
@@ -397,7 +397,7 @@
 		$GLOBALS['setup_info']['controller']['currentver'] = '0.1.18';
 		return $GLOBALS['setup_info']['controller']['currentver'];
 	}
-	
+
 	$test[] = '0.1.18';
 	function controller_upgrade0_1_18()
 	{
@@ -406,17 +406,17 @@
 			'precision' => 8,
 			'nullable' => false
 		));
-		
+
 		$GLOBALS['phpgw_setup']->oProc->AlterColumn('controller_check_item_case','modified_date',array(
 			'type' => 'int',
 			'precision' => 8,
 			'nullable' => true
 		));
-		
+
 		$GLOBALS['setup_info']['controller']['currentver'] = '0.1.19';
 		return $GLOBALS['setup_info']['controller']['currentver'];
 	}
-	
+
 	$test[] = '0.1.19';
 	function controller_upgrade0_1_19()
 	{
@@ -425,7 +425,7 @@
 			'precision' => 4,
 			'nullable' => True
 		));
-		
+
 		$GLOBALS['setup_info']['controller']['currentver'] = '0.1.20';
 		return $GLOBALS['setup_info']['controller']['currentver'];
 	}
@@ -448,9 +448,9 @@
 		{
 			$GLOBALS['setup_info']['controller']['currentver'] = '0.1.21';
 			return $GLOBALS['setup_info']['controller']['currentver'];
-		}		
+		}
 	}
-	
+
 	$test[] = '0.1.21';
 	function controller_upgrade0_1_21()
 	{
@@ -459,7 +459,7 @@
 			'precision' => '255',
 			'nullable' => true
 		));
-		
+
 		$GLOBALS['setup_info']['controller']['currentver'] = '0.1.22';
 		return $GLOBALS['setup_info']['controller']['currentver'];
 	}
@@ -494,9 +494,9 @@
 		{
 			$GLOBALS['setup_info']['controller']['currentver'] = '0.1.23';
 			return $GLOBALS['setup_info']['controller']['currentver'];
-		}		
+		}
 	}
-	
+
 	$test[] = '0.1.23';
 	function controller_upgrade0_1_23()
 	{
@@ -504,11 +504,11 @@
 			'type' => 'text',
 			'nullable' => true
 		));
-		
+
 		$GLOBALS['setup_info']['controller']['currentver'] = '0.1.24';
 		return $GLOBALS['setup_info']['controller']['currentver'];
 	}
-	
+
 	$test[] = '0.1.24';
 	function controller_upgrade0_1_24()
 	{
@@ -527,13 +527,13 @@
 		{
 			$GLOBALS['setup_info']['controller']['currentver'] = '0.1.25';
 			return $GLOBALS['setup_info']['controller']['currentver'];
-		}		
+		}
 	}
-	
+
 	/* Update Controller from v 0.1.25 to 0.1.26
 	 * Added table for connecting gontrol groups to components
 	*/
-	
+
 	$test[] = '0.1.25';
 	function controller_upgrade0_1_25()
 	{
@@ -549,12 +549,12 @@
 			'ix' => array(),
 			'uc' => array()
 			)
-		);			
+		);
 
 		$GLOBALS['setup_info']['controller']['currentver'] = '0.1.26';
 		return $GLOBALS['setup_info']['controller']['currentver'];
 	}
-	
+
 	$test[] = '0.1.26';
 	function controller_upgrade0_1_26()
 	{
@@ -573,14 +573,14 @@
 		{
 			$GLOBALS['setup_info']['controller']['currentver'] = '0.1.27';
 			return $GLOBALS['setup_info']['controller']['currentver'];
-		}		
+		}
 	}
-	
+
 	$test[] = '0.1.27';
 	function controller_upgrade0_1_27()
 	{
 		$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_begin();
-		
+
 		$GLOBALS['phpgw_setup']->oProc->AddColumn('controller_check_item_case','measurement',array(
 			'type' => 'varchar',
 			'precision' => 50,
@@ -602,11 +602,11 @@
 			'precision' => 4,
 			'nullable' => True
 		));
-		
+
 		$GLOBALS['setup_info']['controller']['currentver'] = '0.1.29';
 		return $GLOBALS['setup_info']['controller']['currentver'];
 	}
-	
+
 	$test[] = '0.1.29';
 	function controller_upgrade0_1_29()
 	{
@@ -614,15 +614,15 @@
 			'type' => 'text',
 			'nullable' => true
 		));
-		
+
 		$sql = "INSERT INTO controller_document_types (title) values('procedures')";
 		$db = clone $GLOBALS['phpgw']->db;
 		$result = $db->query($sql, __LINE__, __FILE__);
-				
+
 		$GLOBALS['setup_info']['controller']['currentver'] = '0.1.30';
 		return $GLOBALS['setup_info']['controller']['currentver'];
 	}
-	
+
 	$test[] = '0.1.30';
 	function controller_upgrade0_1_30()
 	{
@@ -630,22 +630,22 @@
 			'type' => 'text',
 			'nullable' => true
 		));
-		
+
 		$GLOBALS['setup_info']['controller']['currentver'] = '0.1.31';
 		return $GLOBALS['setup_info']['controller']['currentver'];
 	}
-	
+
 	$test[] = '0.1.31';
 	function controller_upgrade0_1_31()
 	{
 		$GLOBALS['phpgw_setup']->oProc->DropColumn('controller_check_item', array(), 'status');
 		$GLOBALS['phpgw_setup']->oProc->DropColumn('controller_check_item', array(), 'comment');
 		$GLOBALS['phpgw_setup']->oProc->DropColumn('controller_check_item', array(), 'measurement');
-		
+
 		$GLOBALS['setup_info']['controller']['currentver'] = '0.1.32';
 		return $GLOBALS['setup_info']['controller']['currentver'];
 	}
-	
+
 	$test[] = '0.1.32';
 	function controller_upgrade0_1_32()
 	{
@@ -653,11 +653,11 @@
 			'type' => 'text',
 			'nullable' => true
 		));
-		
+
 		$GLOBALS['setup_info']['controller']['currentver'] = '0.1.33';
 		return $GLOBALS['setup_info']['controller']['currentver'];
 	}
-	
+
 	$test[] = '0.1.33';
 	function controller_upgrade0_1_33()
 	{
@@ -673,17 +673,17 @@
 			'ix' => array(),
 			'uc' => array()
 			)
-		);			
-		
+		);
+
 		$GLOBALS['setup_info']['controller']['currentver'] = '0.1.34';
 		return $GLOBALS['setup_info']['controller']['currentver'];
 	}
-	
+
 	$test[] = '0.1.34';
 	function controller_upgrade0_1_34()
 	{
 		$GLOBALS['phpgw_setup']->oProc->DropColumn('controller_control', array(), 'location_code');
-				
+
 		$GLOBALS['setup_info']['controller']['currentver'] = '0.1.35';
 		return $GLOBALS['setup_info']['controller']['currentver'];
 	}
@@ -692,7 +692,7 @@
 	function controller_upgrade0_1_35()
 	{
 		$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_begin();
-		
+
 		$GLOBALS['phpgw_setup']->oProc->AddColumn('controller_control_component_list','location_id',array(
 			'type' => 'int',
 			'precision' => 4,
@@ -705,12 +705,12 @@
 			return $GLOBALS['setup_info']['controller']['currentver'];
 		}
 	}
-	
+
 	$test[] = '0.1.36';
 	function controller_upgrade0_1_36()
 	{
 		$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_begin();
-		
+
 		$GLOBALS['phpgw_setup']->oProc->AddColumn('controller_check_list','location_id',array(
 			'type' => 'int',
 			'precision' => 4,
@@ -723,13 +723,13 @@
 			return $GLOBALS['setup_info']['controller']['currentver'];
 		}
 	}
-	
+
 	$test[] = '0.1.37';
 	function controller_upgrade0_1_37()
 	{
 		$GLOBALS['phpgw_setup']->oProc->DropColumn('controller_control', array(), 'component_type_id');
 		$GLOBALS['phpgw_setup']->oProc->DropColumn('controller_control', array(), 'component_id');
-				
+
 		$GLOBALS['setup_info']['controller']['currentver'] = '0.1.38';
 		return $GLOBALS['setup_info']['controller']['currentver'];
 	}
@@ -767,7 +767,7 @@
 			$sql = "UPDATE controller_check_list SET status = {$entry['status']} WHERE id = {$entry['id']} ";
 			$GLOBALS['phpgw_setup']->oProc->query($sql,__LINE__,__FILE__);
 		}
-				
+
 
 		$GLOBALS['phpgw_setup']->oProc->AlterColumn('controller_check_list','status',array(
 			'type' => 'int',
@@ -787,52 +787,52 @@
 			return $GLOBALS['setup_info']['controller']['currentver'];
 		}
 	}
-	
+
 	$test[] = '0.1.39';
 	function controller_upgrade0_1_39()
 	{
 		$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_begin();
-		
+
 		$GLOBALS['phpgw_setup']->oProc->DropColumn('controller_control_group_component_list', array(), 'component_id');
-				
+
 		$GLOBALS['phpgw_setup']->oProc->AddColumn('controller_control_group_component_list','location_id',array(
 			'type' => 'int',
 			'precision' => 4,
 			'nullable' => false
 		));
-		
+
 		if($GLOBALS['phpgw_setup']->oProc->m_odb->transaction_commit())
 		{
 			$GLOBALS['setup_info']['controller']['currentver'] = '0.1.40';
 			return $GLOBALS['setup_info']['controller']['currentver'];
 		}
 	}
-	
+
 	$test[] = '0.1.40';
 	function controller_upgrade0_1_40()
 	{
 		$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_begin();
-		
+
 	$GLOBALS['phpgw_setup']->oProc->DropTable('controller_control_area');
-		
+
 		if($GLOBALS['phpgw_setup']->oProc->m_odb->transaction_commit())
 		{
 			$GLOBALS['setup_info']['controller']['currentver'] = '0.1.41';
 			return $GLOBALS['setup_info']['controller']['currentver'];
 		}
 	}
-	
+
 	$test[] = '0.1.41';
 	function controller_upgrade0_1_41()
 	{
 		$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_begin();
-		
+
 		$GLOBALS['phpgw_setup']->oProc->AddColumn('controller_check_item_case','location_code',array(
 			'type' => 'varchar',
 			'precision' => '30',
 			'nullable' => true
 		));
-		
+
 		if($GLOBALS['phpgw_setup']->oProc->m_odb->transaction_commit())
 		{
 			$GLOBALS['setup_info']['controller']['currentver'] = '0.1.42';
@@ -844,7 +844,7 @@
 	function controller_upgrade0_1_42()
 	{
 		$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_begin();
-		
+
 		$GLOBALS['phpgw_setup']->oProc->AddColumn('controller_control_group_list','temp_order_nr',array(
 			'type' => 'int',
 			'precision' => '4',
@@ -855,7 +855,7 @@
 		$GLOBALS['phpgw_setup']->oProc->query($sql,__LINE__,__FILE__);
 
 		$GLOBALS['phpgw_setup']->oProc->DropColumn('controller_control_group_list', array(), 'order_nr');
-		
+
 		$GLOBALS['phpgw_setup']->oProc->RenameColumn('controller_control_group_list','temp_order_nr','order_nr');
 
 		if($GLOBALS['phpgw_setup']->oProc->m_odb->transaction_commit())
@@ -869,7 +869,7 @@
 	function controller_upgrade0_1_43()
 	{
 		$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_begin();
-		
+
 		$GLOBALS['phpgw_setup']->oProc->AddColumn('controller_check_list','assigned_to',array(
 			'type' => 'int',
 			'precision' => '4',
@@ -894,7 +894,7 @@
 	function controller_upgrade0_1_44()
 	{
 		$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_begin();
-		
+
 		$GLOBALS['phpgw_setup']->oProc->AddColumn('controller_control_group','component_location_id',array(
 			'type' => 'int',
 			'precision' => '4',
@@ -912,7 +912,7 @@
 	function controller_upgrade0_1_45()
 	{
 		$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_begin();
-		
+
 		$GLOBALS['phpgw_setup']->oProc->AddColumn('controller_check_item_case','component_id',array(
 			'type' => 'int',
 			'precision' => '4',
@@ -930,7 +930,7 @@
 	function controller_upgrade0_1_46()
 	{
 		$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_begin();
-		
+
 		$GLOBALS['phpgw_setup']->oProc->AddColumn('controller_control_group','component_criteria',array(
 			'type' => 'text',
 			'nullable' => true
@@ -951,7 +951,7 @@
 	function controller_upgrade0_1_47()
 	{
 		$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_begin();
-		
+
 		$GLOBALS['phpgw_setup']->oProc->AddColumn('controller_check_item_case','component_location_id',array(
 			'type' => 'int',
 			'precision' => '4',
@@ -965,3 +965,180 @@
 		}
 	}
 
+	/**
+	* Assign responsible user to control at componant from date.
+	**/
+	$test[] = '0.1.48';
+	function controller_upgrade0_1_48()
+	{
+		$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_begin();
+
+		$GLOBALS['phpgw_setup']->oProc->AddColumn('controller_control_component_list','assigned_to',array(
+			'type' => 'int',
+			'precision' => '4',
+			'nullable' => true
+		));
+
+			$GLOBALS['phpgw_setup']->oProc->AddColumn('controller_control_component_list','start_date',array(
+			'type' => 'int',
+			'precision' => '8',
+			'nullable' => true
+		));
+
+		if($GLOBALS['phpgw_setup']->oProc->m_odb->transaction_commit())
+		{
+			$GLOBALS['setup_info']['controller']['currentver'] = '0.1.49';
+			return $GLOBALS['setup_info']['controller']['currentver'];
+		}
+	}
+
+	/**
+	* Assign responsible user to control at componant from date.
+	**/
+	$test[] = '0.1.49';
+	function controller_upgrade0_1_49()
+	{
+		$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_begin();
+
+		$GLOBALS['phpgw_setup']->oProc->AddColumn('controller_control_component_list','repeat_type',array(
+			'type' => 'int',
+			'precision' => '2',
+			'nullable' => true
+		));
+
+			$GLOBALS['phpgw_setup']->oProc->AddColumn('controller_control_component_list','repeat_interval',array(
+			'type' => 'int',
+			'precision' => '4',
+			'nullable' => true
+		));
+
+		$GLOBALS['phpgw_setup']->oProc->AddColumn('controller_control_component_list','service_time',array(
+			'type' => 'decimal',
+			'precision' => 20,
+			'nullable' => true,
+			'scale' => '2',
+			'default' => '0.00'
+		));
+
+			$GLOBALS['phpgw_setup']->oProc->AddColumn('controller_control_component_list','controle_time',array(
+			'type' => 'decimal',
+			'precision' => 20,
+			'nullable' => true,
+			'scale' => '2',
+			'default' => '0.00'
+		));
+
+		if($GLOBALS['phpgw_setup']->oProc->m_odb->transaction_commit())
+		{
+			$GLOBALS['setup_info']['controller']['currentver'] = '0.1.50';
+			return $GLOBALS['setup_info']['controller']['currentver'];
+		}
+	}
+
+	$test[] = '0.1.50';
+	function controller_upgrade0_1_50()
+	{
+		$GLOBALS['phpgw_setup']->oProc->CreateTable(
+			'controller_control_serie', array(
+					'fd' => array(
+						'id'					=> array('type' => 'auto', 'nullable' => false),
+						'control_relation_id'	=> array('type' => 'int', 'precision' => '4', 'nullable' => false),
+						'control_relation_type'	=> array('type' => 'varchar', 'precision' => '10', 'nullable' => false),
+						'assigned_to'			=> array('type' => 'int', 'precision' => '4', 'nullable' => true),
+						'start_date'			=> array('type' => 'int', 'precision' => '8', 'nullable' => true),
+						'repeat_type'			=> array('type' => 'int', 'precision' => '2', 'nullable' => true),
+						'repeat_interval'		=> array('type' => 'int', 'precision' => '4', 'nullable' => true),
+						'service_time'			=> array('type' => 'decimal','precision' => '20','scale' => '2','nullable' => True,'default' => '0.00'),
+						'controle_time'			=> array('type' => 'decimal','precision' => '20','scale' => '2','nullable' => True,'default' => '0.00'),
+					),
+				'pk' => array('id'),
+				'fk' => array(),
+				'ix' => array(),
+				'uc' => array()
+			)
+		);
+
+		$GLOBALS['phpgw_setup']->oProc->AddColumn('controller_control_component_list','enabled',array(
+				'type' => 'int',
+				'precision' => '2',
+				'nullable' => true,
+				'default' => 1,
+			)
+		);
+		$GLOBALS['phpgw_setup']->oProc->AddColumn('controller_check_list','serie_id',array(
+				'type' => 'int',
+				'precision' => 4,
+				'nullable' => true
+			)
+		);
+
+		$GLOBALS['phpgw_setup']->oProc->DropColumn('controller_control_component_list',array(),'assigned_to');
+		$GLOBALS['phpgw_setup']->oProc->DropColumn('controller_control_component_list',array(),'start_date');
+		$GLOBALS['phpgw_setup']->oProc->DropColumn('controller_control_component_list',array(),'repeat_type');
+		$GLOBALS['phpgw_setup']->oProc->DropColumn('controller_control_component_list',array(),'repeat_interval');
+		$GLOBALS['phpgw_setup']->oProc->DropColumn('controller_control_component_list',array(),'service_time');
+		$GLOBALS['phpgw_setup']->oProc->DropColumn('controller_control_component_list',array(),'controle_time');
+
+		$GLOBALS['setup_info']['controller']['currentver'] = '0.1.51';
+		return $GLOBALS['setup_info']['controller']['currentver'];
+	}
+
+	$test[] = '0.1.51';
+	function controller_upgrade0_1_51()
+	{
+		$GLOBALS['phpgw_setup']->oProc->AddColumn('controller_control_serie','enabled',array(
+				'type' => 'int',
+				'precision' => '2',
+				'nullable' => true,
+				'default' => 1,
+			)
+		);
+
+		$GLOBALS['setup_info']['controller']['currentver'] = '0.1.52';
+		return $GLOBALS['setup_info']['controller']['currentver'];
+	}
+
+	$test[] = '0.1.52';
+	function controller_upgrade0_1_52()
+	{
+		$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_begin();
+
+		$GLOBALS['phpgw_setup']->oProc->CreateTable(
+			'controller_control_serie_history', array(
+					'fd' => array(
+						'id'					=> array('type' => 'auto', 'nullable' => false),
+						'serie_id'				=> array('type' => 'int', 'precision' => '4', 'nullable' => false),
+						'assigned_to'			=> array('type' => 'int', 'precision' => '4', 'nullable' => false),
+						'assigned_date'			=> array('type' => 'int', 'precision' => '8', 'nullable' => false),
+					),
+				'pk' => array('id'),
+				'fk' => array('controller_control_serie' => array('serie_id' => 'id')),
+				'ix' => array(),
+				'uc' => array()
+			)
+		);
+
+		$GLOBALS['phpgw_setup']->oProc->query('SELECT * FROM controller_control_serie');
+
+		$series = array();
+		while($GLOBALS['phpgw_setup']->oProc->next_record())
+		{
+			$series[] = array(
+				'serie_id' => $GLOBALS['phpgw_setup']->oProc->f('id'),
+				'assigned_to' => $GLOBALS['phpgw_setup']->oProc->f('assigned_to'),
+				'assigned_date'	=> time()
+			);
+		}
+
+		foreach($series as $serie)
+		{
+			$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO controller_control_serie_history (serie_id, assigned_to, assigned_date)"
+			. " VALUES ({$serie['serie_id']}, {$serie['assigned_to']}, {$serie['assigned_date']})  ");
+		}
+
+		if($GLOBALS['phpgw_setup']->oProc->m_odb->transaction_commit())
+		{
+			$GLOBALS['setup_info']['controller']['currentver'] = '0.1.53';
+			return $GLOBALS['setup_info']['controller']['currentver'];
+		}
+	}
