@@ -6,7 +6,7 @@
 	* @copyright Copyright (C) 2003-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package email
-	* @version $Id: addressbook-js.php 4237 2009-11-27 23:17:21Z sigurd $
+	* @version $Id: addressbook-js.php 13920 2015-09-15 19:47:34Z sigurdne $
 	* @internal WARNING-> The sheer size of this stupid file is what shows why there is a
 	* @internal three tiered design in phpgw...sigh.... now im even gonna put some php
 	* @internal functions in here.... dont be mad, be critical and show me how to move to
@@ -273,7 +273,7 @@ if(!$catlist)
 
 
 	$GLOBALS['phpgw']->template->set_var('cats_list',
-						ereg_replace( '&nbsp;&lt;' . lang('Global') . '&nbsp;' . lang($c->app_name) . '&gt;',
+							str_replace( '&nbsp;&lt;' . lang('Global') . '&nbsp;' . lang($c->app_name) . '&gt;',
 								"",
 								$catlist
 								)
@@ -528,4 +528,3 @@ if(!$catlist)
 	$GLOBALS['phpgw']->template->p('out');
 
 	$GLOBALS['phpgw']->common->phpgw_exit();
-?>
