@@ -8,7 +8,7 @@
 	* @copyright Copyright (C) 2003-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package email
-	* @version $Id: class.boattach_file.inc.php 4237 2009-11-27 23:17:21Z sigurd $
+	* @version $Id: class.boattach_file.inc.php 13901 2015-09-15 09:41:20Z sigurdne $
 	* @internal Based on AngleMail http://www.anglemail.org/
 	* @internal Squirrelmail circa 2000-2001 http://www.squirrelmail.org
 	*/
@@ -48,7 +48,7 @@
 		@function boattach_file *CONSTRUCTOR*
 		@abstract checks and makes sure we have a X->msg object to work with and initialized some blank data
 		*/
-		function boattach_file()
+		function __construct()
 		{
 			// we need a msg object BUT NO LOGIN IS NEEDED
 			$this->msg_bootstrap = CreateObject("email.msg_bootstrap");
