@@ -7,7 +7,7 @@
 	* @copyright Copyright (C) 2003-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package email
-	* @version $Id: class.bofolder.inc.php 4237 2009-11-27 23:17:21Z sigurd $
+	* @version $Id: class.bofolder.inc.php 13901 2015-09-15 09:41:20Z sigurdne $
 	* @internal Based on AngleMail http://www.anglemail.org/
 	*/
 
@@ -35,7 +35,7 @@
 		
 		var $xi;
 		
-		function bofolder()
+		function __construct()
 		{
 			//return;
 		}
@@ -464,4 +464,3 @@
 		}	
 	
 	}
-?>
