@@ -8,7 +8,7 @@
 	* @copyright Copyright (C) 2003-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package email
-	* @version $Id: class.bojsaddressbook.inc.php 4237 2009-11-27 23:17:21Z sigurd $
+	* @version $Id: class.bojsaddressbook.inc.php 13901 2015-09-15 09:41:20Z sigurdne $
 	* @internal 
 	*/
 
@@ -93,7 +93,7 @@
 		//if the cache is stale.... for example, caching the result form parse_contactquery and
 		//compare it with what results from parsing the incoming contactquery. If its the same,
 		//we shouldnt refetch.
-		function bojsaddressbook($contactquery="",$queryresults="")
+		function __construct($contactquery="",$queryresults="")
 		{
 			$this->contactsobject=CreateObject('phpgwapi.contacts');
 			//the idea is that here, right here, nowhere else, do we decide what to keep
@@ -428,4 +428,3 @@
 		}
 		
 	}
-?>
