@@ -8,7 +8,7 @@
 	* @copyright Copyright (C) 2003-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package email
-	* @version $Id: class.bosend.inc.php 4237 2009-11-27 23:17:21Z sigurd $
+	* @version $Id: class.bosend.inc.php 13901 2015-09-15 09:41:20Z sigurdne $
 	* @internal Based on AngleMail http://www.anglemail.org/
 	* @internal Server side attachment storage technique borrowed from Squirrelmail
 	*/
@@ -45,7 +45,7 @@
 		//var $debug_struct = 3;
 		var $company_disclaimer = '';
 		
-		function bosend()
+		function __construct()
 		{
 			if ($this->debug_constructor > 0) { echo 'email.bosend *constructor*: ENTERING<br />'; }
 			
@@ -884,4 +884,3 @@
 			$GLOBALS['phpgw']->redirect_link('/index.php', array('menuaction' => 'email.uiindex.index'));
 		}
 	}
-?>
