@@ -8,7 +8,7 @@
 	* @copyright Copyright (C) 2003-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package email
-	* @version $Id: class.mail_dcom_base.inc.php 4237 2009-11-27 23:17:21Z sigurd $
+	* @version $Id: class.mail_dcom_base.inc.php 13901 2015-09-15 09:41:20Z sigurdne $
 	* @internal Based on AngleMail http://www.anglemail.org/
 	*/
 
@@ -47,7 +47,7 @@
 		@author Angles
 		@access private
 		*/
-		function mail_dcom_base()
+		function __construct()
 		{
 			$this->err["code"] = " ";
 			$this->err["msg"]  = " ";
@@ -343,4 +343,4 @@
 		}
 
 	} // end of class mail_dcom
-?>
+
