@@ -10,7 +10,7 @@
 	* @copyright Copyright (C) 2003-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package email
-	* @version $Id: class.mail_dcom_pop3_sock.inc.php 4237 2009-11-27 23:17:21Z sigurd $
+	* @version $Id: class.mail_dcom_pop3_sock.inc.php 13920 2015-09-15 19:47:34Z sigurdne $
 	* @internal Based on AngleMail http://www.anglemail.org/
 	*/
 
@@ -1825,7 +1825,7 @@
 				}
 				$addr_details->mailbox = substr($addr_details->adl,0,$pos3);
 				$addr_details->host    = substr($addr_details->adl,$pos3+1);
-				$pos = ereg("\"",$addr_details->personal);
+				$pos = preg_match('/\"/',$addr_details->personal);
 				if ($pos)
 				{
 					$addr_details->personal = substr($addr_details->personal,1,strlen($addr_details->personal)-2);
@@ -2273,4 +2273,3 @@
 			return $body_glob;
 		}
 	}
-?>
