@@ -14,7 +14,7 @@
 	* @copyright Copyright (C) 2003-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package email
-	* @version $Id: class.mail_send.inc.php 4237 2009-11-27 23:17:21Z sigurd $
+	* @version $Id: class.mail_send.inc.php 13901 2015-09-15 09:41:20Z sigurdne $
 	* @internal Based on AngleMail http://www.anglemail.org/
 	*/
 
@@ -46,7 +46,7 @@
 		var $retain_copy_ignore = True;
 		var $assembled_copy = '';
 
-		function mail_send()
+		function __construct()
 		{
 			$this->err['code'] = '';
 			$this->err['msg']  = '';
@@ -404,4 +404,4 @@ $mypassword = "xxxxxxxxxx";
 		
 	// end of class
 	}
-?>
+
