@@ -7,7 +7,7 @@
 	* @copyright Copyright (C) 2003-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package email
-	* @version $Id: class.so_mail_msg.inc.php 4237 2009-11-27 23:17:21Z sigurd $
+	* @version $Id: class.so_mail_msg.inc.php 13901 2015-09-15 09:41:20Z sigurdne $
 	* @internal Based on AngleMail http://www.anglemail.org/
 	*/
 
@@ -37,7 +37,7 @@
 		@function so_mail_msg
 		@abstract Constructor
 		*/
-		function so_mail_msg()
+		function __construct()
 		{
 			if ($GLOBALS['phpgw']->msg->debug_so_class > 0) { $GLOBALS['phpgw']->msg->dbug->out('so_mail_msg: ('.__LINE__.'): *constructor*<br />'); }
 			return;
