@@ -14,7 +14,7 @@
 	* @copyright Copyright (C) 2003-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package email
-	* @version $Id: class.spell_struct.inc.php 4237 2009-11-27 23:17:21Z sigurd $
+	* @version $Id: class.spell_struct.inc.php 13901 2015-09-15 09:41:20Z sigurdne $
 	* @internal Based on AngleMail http://www.anglemail.org/
 	*/
 
@@ -64,7 +64,7 @@
 		 */
 		var $suggestions;
 		
-		function correction_info()
+		function __construct()
 		{
 			$this->orig_word='';
 			$this->orig_word_clean = '';
@@ -73,4 +73,3 @@
 			$this->suggestions=array();
 		}
 	}
-?>
