@@ -10,7 +10,7 @@
 	* @copyright Copyright (C) 2003-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package email
-	* @version $Id: class.spell_svc_none.inc.php 4237 2009-11-27 23:17:21Z sigurd $
+	* @version $Id: class.spell_svc_none.inc.php 13901 2015-09-15 09:41:20Z sigurdne $
 	* @internal Based on AngleMail http://www.anglemail.org/
 	*/
 
@@ -40,7 +40,7 @@
 		/**
 		* Constructor
 		*/
-		function spell_svc_none()
+		function __construct()
 		{
 			// this is a dummy module for installations with no spell capability
 			$this->can_spell = False;
@@ -123,4 +123,3 @@
 			return array();
 		}
 	}
-?>
