@@ -10,7 +10,7 @@
 	* @copyright Copyright (C) 2003-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package email
-	* @version $Id: class.spell_svc_php.inc.php 4237 2009-11-27 23:17:21Z sigurd $
+	* @version $Id: class.spell_svc_php.inc.php 13901 2015-09-15 09:41:20Z sigurdne $
 	* @internal Based on AngleMail http://www.anglemail.org/
 	*/
 
@@ -39,7 +39,7 @@
 		/**
 		* Constructor
 		*/
-		function spell_svc_php()
+		function __construct()
 		{
 			$this->can_spell = True;
 			// SP_FEED_WORDS is defined in the spell class.
@@ -123,4 +123,3 @@
 			return pspell_suggest($dictionary_link, $word);
 		}
 	}
-?>
