@@ -7,7 +7,7 @@
 	* @copyright Copyright (C) 2003-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package email
-	* @version $Id: class.svc_debug.inc.php 4237 2009-11-27 23:17:21Z sigurd $
+	* @version $Id: class.svc_debug.inc.php 13901 2015-09-15 09:41:20Z sigurdne $
 	* @internal Based on AngleMail http://www.anglemail.org/
 	*/
 
@@ -40,7 +40,7 @@
 		@function svc_debug
 		@abstract CONSTRUCTOR 
 		*/
-		function svc_debug()
+		function __construct()
 		{
 			// fill a timestamp
 			if ($this->t_on_creation == '##NOTHING##')
@@ -483,4 +483,4 @@ EOD;
 		}
 		
 	}
-?>
+
