@@ -8,7 +8,7 @@
 	* @copyright Copyright (C) 2000-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package email
-	* @version $Id: class.svc_nextmatches.inc.php 4237 2009-11-27 23:17:21Z sigurd $
+	* @version $Id: class.svc_nextmatches.inc.php 13955 2015-09-17 16:45:28Z sigurdne $
 	* @internal Based on AngleMail http://www.anglemail.org/
 	*/
 
@@ -37,7 +37,7 @@
 		@function svc_nextmatches
 		@abstract constructor
 		*/
-		function svc_nextmatches($website=False)
+		function __construct($website=False)
 		{
 			if(isset($GLOBALS['phpgw_info']['user']['preferences']['common']['maxmatchs']) &&
 				intval($GLOBALS['phpgw_info']['user']['preferences']['common']['maxmatchs']) > 0)
@@ -83,7 +83,7 @@
 			$extra = explode('&', $extra);
 			foreach( $extra as $v )
 			{
-				$b = split('=', $v);
+				$b = explode('=', $v);
 				if(isset($b[0]) && $b[0])
 				{
 					$new_extra[$b[0]] = $b[1];
@@ -197,7 +197,7 @@
 				$extravar = explode('&', $extravar);
 				foreach( $extravar as $v )
 				{
-					$b = split('=', $v);
+					$b = explode('=', $v);
 					if(isset($b[0]) && $b[0])
 					{
 						$new_extravar[$b[0]] = $b[1];
@@ -398,4 +398,3 @@
 			}
 		}
 	}
-?>
