@@ -7,7 +7,7 @@
 	* @copyright Copyright (C) 2003-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package email
-	* @version $Id: class.ui_mail_debug.inc.php 4237 2009-11-27 23:17:21Z sigurd $
+	* @version $Id: class.ui_mail_debug.inc.php 13901 2015-09-15 09:41:20Z sigurdne $
 	* @internal Based on AngleMail http://www.anglemail.org/
 	*/
 
@@ -38,7 +38,7 @@
 		@function ui_mail_debug
 		@abstract CONSTRUCTOR
 		*/
-		function ui_mail_debug()
+		function __construct()
 		{
 			if ($this->debug > 0) { echo 'ENTERING: email.ui_mail_debug.CONSTRUCTOR'.'<br />'."\r\n"; }
 			
@@ -703,4 +703,3 @@
 		*/
 		
 	}
-?>
