@@ -7,7 +7,7 @@
 	* @copyright Copyright (C) 2003-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package email
-	* @version $Id: class.uifolder.inc.php 4237 2009-11-27 23:17:21Z sigurd $
+	* @version $Id: class.uifolder.inc.php 13901 2015-09-15 09:41:20Z sigurdne $
 	* @internal Based on AngleMail http://www.anglemail.org/
 	*/
 
@@ -28,7 +28,7 @@
 			'folder' => True
 		);
 
-		function uifolder()
+		function __construct()
 		{
 			//return;
 		}
@@ -164,4 +164,3 @@
 			unset($GLOBALS['phpgw']->msg);
 		}
 	}
-?>
