@@ -7,7 +7,7 @@
 	* @copyright Copyright (C) 2003-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package email
-	* @version $Id: class.uiindex.inc.php 4237 2009-11-27 23:17:21Z sigurd $
+	* @version $Id: class.uiindex.inc.php 13901 2015-09-15 09:41:20Z sigurdne $
 	* @internal Based on AngleMail http://www.anglemail.org/
 	*/
 
@@ -30,7 +30,7 @@
 			'mlist' => True
 		);
 
-		function uiindex()
+		function __construct()
 		{
 			$GLOBALS['phpgw']->js->validate_file('core','base','phpgwapi');
 			
@@ -855,4 +855,3 @@ EOD;
 		
 		
 	}
-?>
