@@ -9,7 +9,7 @@
 	* @copyright Copyright (C) 2003-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package email
-	* @version $Id: class.uijsaddressbook.inc.php 4237 2009-11-27 23:17:21Z sigurd $
+	* @version $Id: class.uijsaddressbook.inc.php 13920 2015-09-15 19:47:34Z sigurdne $
 	*/
 
 
@@ -206,7 +206,7 @@
 		//so that when the mainframe triggers an event, it will call some functions in the frameset (its window.parent)
 		//And when the secondary frame returns from this public functions (which are all declared and defined in this file)
 		//It will also call some of the functions in the frameset.
-		function uijsaddressbook()
+		function __construct()
 		{
 			//We create our template
 						
@@ -569,7 +569,7 @@
 				//We get it from the category class and ...
 				$this->categoryobject=CreateObject('phpgwapi.categories');
 				$this->categoryobject->app_name = 'addressbook';
-				$this->catlist=ereg_replace( '&nbsp;&lt;' . lang('Global') . '&nbsp;' . lang($this->categoryobject->app_name).'&gt;'
+				$this->catlist=  str_replace( '&nbsp;&lt;' . lang('Global') . '&nbsp;' . lang($this->categoryobject->app_name).'&gt;'
 							,'',$this->categoryobject->formated_list('select','all',$this->cat_id,'True'));
 				//....save it in the cache
 //				$GLOBALS['phpgw']->session->appsession('jsuibook_catlist','email',$catlist);
