@@ -7,7 +7,7 @@
 	* @copyright Copyright (C) 2003-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package email
-	* @version $Id: class.uimessage.inc.php 4237 2009-11-27 23:17:21Z sigurd $
+	* @version $Id: class.uimessage.inc.php 13901 2015-09-15 09:41:20Z sigurdne $
 	* @internal Based on AngleMail http://www.anglemail.org/
 	*/
 
@@ -29,7 +29,7 @@
 			'printable' => True
 		);
 
-		function uimessage()
+		function __construct()
 		{
 			//return;
 		}
@@ -654,4 +654,3 @@
 		}
 		
 	}
-?>
