@@ -9,7 +9,7 @@
 	* @copyright Copyright (C) 2003-2006 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package email
-	* @version $Id: class.uipreferences.inc.php 4237 2009-11-27 23:17:21Z sigurd $
+	* @version $Id: class.uipreferences.inc.php 13901 2015-09-15 09:41:20Z sigurdne $
 	* @internal Based on AngleMail http://www.anglemail.org/
 	* @internal Based on Aeromail http://the.cushman.net/
 	*/
@@ -39,7 +39,7 @@
 		//var $debug = 3;
 
 
-		function uipreferences()
+		function __construct()
 		{
 			$this->nextmatchs = CreateObject('phpgwapi.nextmatchs');
 			$this->bo = CreateObject('email.bopreferences');
@@ -837,4 +837,3 @@
 			}
 		}
 	}
-?>
