@@ -9,7 +9,7 @@
 	* Free Software Foundation; either version 2 of the License, or (at your    *
 	* option) any later version.                                                *
 	\***************************************************************************/
-	/* $Id: class.defaultimap.inc.php 7026 2011-02-21 07:59:06Z sigurdne $ */
+	/* $Id: class.defaultimap.inc.php 13902 2015-09-15 10:21:26Z sigurdne $ */
 
 	if(!include_once PHPGW_INCLUDE_ROOT.'/felamimail/inc/egw-pear/Net/IMAP.php')
 	{
@@ -139,7 +139,7 @@
 		 *
 		 * @return void
 		 */
-		function defaultimap() 
+		function __construct()
 		{
 			if (function_exists('mb_convert_encoding')) {
 				$this->mbAvailable = TRUE;
@@ -508,4 +508,3 @@
 			return $this->hasCapability($_capability);
 		}
 	}
-?>
