@@ -27,7 +27,7 @@
 * under the terms of the GNU General Public License as published by the     *
 * Free Software Foundation; version 2 of the License.                       *
 \***************************************************************************/
-/* $Id: class.pleskimap.inc.php 4237 2009-11-27 23:17:21Z sigurd $ */
+/* $Id: class.pleskimap.inc.php 13955 2015-09-17 16:45:28Z sigurdne $ */
 
 include_once(PHPGW_SERVER_ROOT."/emailadmin/inc/class.defaultimap.inc.php");
 
@@ -423,7 +423,7 @@ class pleskimap extends defaultimap
 		while(!feof($fp))
 		{
 			$line = trim(fgets($fp));
-			list($name,$value) = split(': *',$line,2);
+			list($name,$value) = preg_split('/: */',$line,2);
 			if (!is_null($value) && strpos($name,'An error occured') === false && $name)
 			{
 				$values[$name] = $value;
