@@ -1,6 +1,6 @@
 <?php
 /*
- * $Id: class.Script.inc.php 4237 2009-11-27 23:17:21Z sigurd $
+ * $Id: class.Script.inc.php 13955 2015-09-17 16:45:28Z sigurdne $
  *
  * Copyright 2002 Stephen Grier <stephengrier@users.sourceforge.net>
  *
@@ -28,7 +28,7 @@ class Script {
 	var $debug=false;
 
 	// class constructor
-	function Script ($scriptname) {
+	function __construct ($scriptname) {
 		$this->name = $scriptname;
 		$this->script = '';
 		$this->size = 0;
@@ -380,7 +380,7 @@ class Script {
 						$if[] = 'address :contains ["To","TO","Cc","CC"] "'.$addr.'"';
 					}
 					$newscriptbody .= 'if anyof ('.implode(', ',$if).") {\n";
-					foreach(split(', ?',$vacation['forwards']) as $addr) {
+					foreach(preg_split('/, ?/',$vacation['forwards']) as $addr) {
 						$newscriptbody .= "\tredirect \"".$addr."\";\n";
 					}
 					$newscriptbody .= "\tkeep;\n}\n";
