@@ -12,7 +12,7 @@
 	* option) any later version.                                                *
 	\***************************************************************************/
 
-	/* $Id: class.ajaxfelamimail.inc.php 4237 2009-11-27 23:17:21Z sigurd $ */
+	/* $Id: class.ajaxfelamimail.inc.php 13903 2015-09-15 10:32:01Z sigurdne $ */
 
 	class ajaxfelamimail {
 		// which profile to use(currently only 0 is supported)
@@ -28,7 +28,7 @@
 		// boolean if openConnection was successfull or not
 		var $_connectionStatus;
 		
-		function ajaxfelamimail() 
+		function __construct()
 		{
 			if($this->_debug) error_log("ajaxfelamimail::ajaxfelamimail");
 			$this->charset		=  'utf-8';
@@ -1061,4 +1061,4 @@
 		}
 		
 	}
-?>
+
