@@ -10,7 +10,7 @@
 	* under the terms of the GNU General Public License as published by the     *
 	* Free Software Foundation; version 2 of the License.                       *
 	\***************************************************************************/
-	/* $Id: class.bocompose.inc.php 4237 2009-11-27 23:17:21Z sigurd $ */
+	/* $Id: class.bocompose.inc.php 13903 2015-09-15 10:32:01Z sigurdne $ */
 
 	class bocompose
 	{
@@ -23,7 +23,7 @@
 		var $attachments;	// Array of attachments
 		var $preferences;	// the prefenrences(emailserver, username, ...)
 
-		function bocompose($_composeID = '', $_charSet = 'utf-8')
+		function __construct($_composeID = '', $_charSet = 'utf-8')
 		{
 			$this->displayCharset	= strtolower($_charSet);
 			$this->bopreferences	=& CreateObject('felamimail.bopreferences');
