@@ -12,7 +12,7 @@
 	* option) any later version.                                                *
 	\***************************************************************************/
 
-	/* $Id: class.bofelamimail.inc.php 4237 2009-11-27 23:17:21Z sigurd $ */
+	/* $Id: class.bofelamimail.inc.php 13903 2015-09-15 10:32:01Z sigurdne $ */
 
 	/**
 	* the core logic of FeLaMiMail
@@ -58,7 +58,7 @@
 		 */
 		var $autoFolders = array('Drafts', 'Junk', 'Sent', 'Trash', 'Templates');
 		
-		function bofelamimail($_displayCharset='utf-8')
+		function __construct($_displayCharset='utf-8')
 		{
 			$this->restoreSessionData();
 
