@@ -11,7 +11,7 @@
 	* Free Software Foundation; either version 2 of the License, or (at your    *
 	* option) any later version.                                                *
 	\***************************************************************************/
-	/* $Id: class.bopreferences.inc.php 7026 2011-02-21 07:59:06Z sigurdne $ */
+	/* $Id: class.bopreferences.inc.php 13924 2015-09-15 20:06:13Z sigurdne $ */
 
 	require_once(PHPGW_INCLUDE_ROOT.'/felamimail/inc/class.sopreferences.inc.php');
 	 
@@ -25,9 +25,9 @@
 		// stores the users profile
 		var $profileData;
 		
-		function bopreferences()
+		function __construct()
 		{
-			parent::sopreferences();
+			parent::__construct();
 			$this->boemailadmin = CreateObject('emailadmin.emailadmin_bo');
 		//	$this->boemailadmin = new emailadmin_bo();
 		}
@@ -295,4 +295,4 @@
 			parent::setProfileActive($GLOBALS['phpgw_info']['user']['account_id'], $_status, $_identity);
 		}
 	}
-?>
+
