@@ -10,7 +10,7 @@
 	* under the terms of the GNU General Public License as published by the     *
 	* Free Software Foundation; version 2 of the License.                       *
 	\***************************************************************************/
-	/* $Id: class.uicompose.inc.php 4237 2009-11-27 23:17:21Z sigurd $ */
+	/* $Id: class.uicompose.inc.php 13903 2015-09-15 10:32:01Z sigurdne $ */
 
 	phpgw::import_class('felamimail.html');	
 
@@ -39,7 +39,7 @@
 			'folder'	=> 'folder'
 		);
 
-		function uicompose()
+		function __construct()
 		{
 			$GLOBALS['phpgw_info']['flags']['noframework'] = true;
 			require_once(PHPGW_SERVER_ROOT.'/felamimail/inc/xajax.inc.php');
@@ -574,5 +574,3 @@
 		}
 
 }
-
-?>
