@@ -26,7 +26,7 @@
 	*
 	*/
 
-	/* $Id: class.uidisplay.inc.php 4237 2009-11-27 23:17:21Z sigurd $ */
+	/* $Id: class.uidisplay.inc.php 13920 2015-09-15 19:47:34Z sigurdne $ */
 
 	phpgw::import_class('felamimail.html');
 
@@ -56,7 +56,7 @@
 		// the permanent id of the message
 		var $uid;
 
-		function uidisplay()
+		function __construct()
 		{
 			$GLOBALS['phpgw_info']['flags']['noframework'] = true;
 			$GLOBALS['phpgw']->js->validate_file('jsapi', 'jsapi', 'felamimail');
@@ -135,7 +135,7 @@
 			$addresses = array();
 
 			/* Find all the email addresses in the body */
-			while(eregi($Email_RegExp_Match, $sbody, $regs)) {
+			while(preg_match("/$Email_RegExp_Match/i", $sbody, $regs)) {
 				$addresses[$regs[0]] = strtr($regs[0], array('&amp;' => '&'));
 				$start = strpos($sbody, $regs[0]) + strlen($regs[0]);
 				$sbody = substr($sbody, $start);
@@ -1372,4 +1372,3 @@
 		}
 }
 
-?>
