@@ -10,7 +10,7 @@
 	* under the terms of the GNU General Public License as published by the     *
 	* Free Software Foundation; version 2 of the License.                       *
 	\***************************************************************************/
-	/* $Id: class.uifelamimail.inc.php 7026 2011-02-21 07:59:06Z sigurdne $ */
+	/* $Id: class.uifelamimail.inc.php 13903 2015-09-15 10:32:01Z sigurdne $ */
 	if(! is_file(PHPGW_INCLUDE_ROOT.'/felamimail/inc/egw-pear/Net/IMAP.php'))
 	{
 		throw new Exception('missing egw-pear package');
@@ -42,7 +42,7 @@
 		// the object storing the data about the incoming imap server
 		var $icServerID=0;
 		
-		function uifelamimail()
+		function __construct()
 		{
 			require_once(PHPGW_SERVER_ROOT.'/felamimail/inc/xajax.inc.php');
 
@@ -885,4 +885,3 @@
 			$this->t->set_var('lang_updating_view',lang('updating view'));
 		}
 	}
-?>
