@@ -12,7 +12,7 @@
 	* option) any later version.                                                *
 	\***************************************************************************/
 
-	/* $Id: class.uipreferences.inc.php 4237 2009-11-27 23:17:21Z sigurd $ */
+	/* $Id: class.uipreferences.inc.php 13903 2015-09-15 10:32:01Z sigurdne $ */
 
 	phpgw::import_class('felamimail.html');	
 	require_once(PHPGW_INCLUDE_ROOT.'/felamimail/inc/class.felamimail_bosignatures.inc.php');
@@ -33,7 +33,7 @@
 			'getAttachment'		=> 'True'
 		);
 
-		function uipreferences()
+		function __construct()
 		{
 			require_once(PHPGW_SERVER_ROOT.'/felamimail/inc/xajax.inc.php');
 
@@ -743,5 +743,3 @@
 			$this->t->set_var("bg03",$GLOBALS['phpgw_info']["theme"]["bg03"]);
 		}
 	}
-
-?>
