@@ -10,7 +10,7 @@
 	* under the terms of the GNU General Public License as published by the     *
 	* Free Software Foundation; version 2 of the License.                       *
 	\***************************************************************************/
-	/* $Id: class.uisieve.inc.php 4237 2009-11-27 23:17:21Z sigurd $ */
+	/* $Id: class.uisieve.inc.php 13955 2015-09-17 16:45:28Z sigurdne $ */
 
 	class uisieve
 	{
@@ -50,7 +50,7 @@
 		
 		var $errorStack;
 
-		function uisieve()
+		function __construct()
 		{
 			if(empty($GLOBALS['phpgw_info']['user']['preferences']['felamimail']['sieveScriptName'])) {
 				$GLOBALS['phpgw']->preferences->add('felamimail','sieveScriptName','felamimail', 'forced');
@@ -260,7 +260,7 @@
 			
 			if ($_vacation['forwards'])
 			{
-				foreach(split(', ?',$_vacation['forwards']) as $addr)
+				foreach(preg_split('/, ?/',$_vacation['forwards']) as $addr)
 				{
 					if (!preg_match($regexp,$addr)) 
 					{
@@ -1071,4 +1071,3 @@
 			}
 		}
 	}
-?>
