@@ -33,7 +33,7 @@
 	* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.		    *
 	\***************************************************************************/
 
-	/* $Id: class.uiwidgets.inc.php 4237 2009-11-27 23:17:21Z sigurd $ */
+	/* $Id: class.uiwidgets.inc.php 13903 2015-09-15 10:32:01Z sigurdne $ */
 
 	phpgw::import_class('felamimail.html');	
 	/**
@@ -51,7 +51,7 @@
 		* the contructor
 		*
 		*/
-		function uiwidgets()
+		function __construct()
 		{
 			$template =& CreateObject('phpgwapi.Template',PHPGW_APP_TPL);
 			$this->template = $template;
@@ -645,4 +645,3 @@
 			return $this->t->get('out','quota_block');
 		}
 	}
-?>
