@@ -29,7 +29,7 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  * 
  * @package xajax
- * @version $Id: xajaxResponse.inc.php 4237 2009-11-27 23:17:21Z sigurd $
+ * @version $Id: xajaxResponse.inc.php 13903 2015-09-15 10:32:01Z sigurdne $
  * @copyright Copyright (c) 2005-2006  by Jared White & J. Max Wilson
  * @license http://www.gnu.org/copyleft/lesser.html#SEC3 LGPL License
  */
@@ -99,7 +99,7 @@ class xajaxResponse
 	 *                converted to HTML entities
 	 * 
 	 */
-	function xajaxResponse($sEncoding=XAJAX_DEFAULT_CHAR_ENCODING, $bOutputEntities=false)
+	function __construct($sEncoding=XAJAX_DEFAULT_CHAR_ENCODING, $bOutputEntities=false)
 	{
 		$this->setCharEncoding($sEncoding);
 		$this->bOutputEntities = $bOutputEntities;
@@ -576,5 +576,4 @@ class xajaxResponse
 		}
 	}
 	
-}// end class xajaxResponse
-?>
+}// end class xajaxResponse
\ No newline at end of file
