@@ -7,7 +7,7 @@
 	* @copyright Copyright (C) 2005-2006 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package filemanager
-	* @version $Id: class.attached_files.inc.php 690 2008-02-02 10:11:33Z dave $
+	* @version $Id: class.attached_files.inc.php 13905 2015-09-15 10:36:07Z sigurdne $
 	* @internal $Source$
 	*/
 
@@ -32,7 +32,7 @@
 		var $app;
 		var $appdir;
 
-		function attached_files()
+		function __construct()
 		{
 			$this->app			= (isset($_REQUEST['app'])?$_REQUEST['app']:$GLOBALS['phpgw_info']['flags']['currentapp']);
 			$this->appdir		= $GLOBALS['phpgw_info']['server']['files_dir'] . '/' . $this->app;
@@ -190,4 +190,3 @@
 			return $GLOBALS['phpgw']->vfs->file_exists($data);
 		}
 	}
-?>
