@@ -8,7 +8,7 @@
 	 * @copyright Portions Copyright (C) 2000-2005 Free Software Foundation, Inc http://www.fsf.org/
 	 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	 * @package filemanager
-	 * @version $Id: class.bofilemanager.inc.php 7121 2011-03-15 08:53:24Z sigurdne $
+	 * @version $Id: class.bofilemanager.inc.php 13920 2015-09-15 19:47:34Z sigurdne $
 	 * @internal Based on phpWebhosting
 	 */
 
@@ -80,7 +80,7 @@
 			 'load_files'	=> true
 			);
 
-		function bofilemanager()
+		function __construct()
 		{
 			if ( !isset($GLOBALS['phpgw']->vfs) || !is_object($GLOBALS['phpgw']->vfs) )
 			{
@@ -684,7 +684,7 @@
 					$result[] = lang('file names cannot contain %1', $badchar);
 				}
 
-				if (ereg ("/", $to) || ereg ("\\\\", $to))
+				if (preg_match ("/\//", $to) || ereg ("/\\\\/", $to))
 				{
 					//echo $GLOBALS['phpgw']->common->error_list (array ("File names cannot contain \\ or /"));
 					$result[] = lang('file names cannot contain \\ or /');
@@ -1183,9 +1183,9 @@
 			{
 				$rstring = preg_replace("/=(.*)(&|$)/Ue","'='.rawurlencode(base64_encode ('\\1')).'\\2'",$string);
 			}
-			elseif (ereg('^'.$this->hostname,$string))
+			elseif (preg_match("/^{$this->hostname}/",$string))
 			{
-				$rstring = ereg_replace('^'.$this->hostname.'/','',$string);
+				$rstring = str_replace("{$this->hostname}/",'',$string, 1);
 				$rstring = preg_replace("/(.*)(\/|$)/Ue","rawurlencode (base64_encode ('\\1')).'\\2'",$rstring);
 				$rstring = $this->hostname.'/'.$rstring;
 			}
@@ -1544,4 +1544,3 @@ _debug_Array($this->quota);
 		}
 		*/
 	}
-?>
