@@ -6,7 +6,7 @@
 	* @copyright Copyright (C) 2000-2006 Free Software Foundation, Inc http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package filemanager
-	* @version $Id: class.uiaction_edit.inc.php 690 2008-02-02 10:11:33Z dave $
+	* @version $Id: class.uiaction_edit.inc.php 13905 2015-09-15 10:36:07Z sigurdne $
 	*/
 
 	/**
@@ -27,7 +27,7 @@
 			'edit' => True
 		);
 
-		function uiaction_edit()
+		function __construct()
 		{
 			$this->action			= CreateObject('filemanager.uiaction_base');
 			$this->bofilemanager	= $this->action->bofilemanager;
@@ -154,4 +154,4 @@
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw', array('edit' => $output));
 		}
 	}
-?>
+
