@@ -6,7 +6,7 @@
 	* @copyright Copyright (C) 2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package filemanager
-	* @version $Id: class.uiactions.inc.php 690 2008-02-02 10:11:33Z dave $
+	* @version $Id: class.uiactions.inc.php 13905 2015-09-15 10:36:07Z sigurdne $
 	* @internal $Source$
 	*/
 
@@ -22,7 +22,7 @@
 		);
 		var $actions = array();
 		
-		function uiactions()
+		function __construct()
 		{
 			//Construct the action objects
 			foreach($this->action_classes as $action_class)
@@ -63,4 +63,3 @@
 			
 		}*/
 	}
-?>
