@@ -8,7 +8,7 @@
 	* @copyright Portions Copyright (C) 2000-2005 Free Software Foundation, Inc http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package filemanager
-	* @version $Id: class.uifilemanager.inc.php 1906 2008-11-28 22:47:27Z sigurd $
+	* @version $Id: class.uifilemanager.inc.php 13920 2015-09-15 19:47:34Z sigurdne $
 	* @internal Based on phpWebhosting
 	*/
 
@@ -75,7 +75,7 @@
 			'message'			=> 'message'
 		);
 
-		function uifilemanager()
+		function __construct()
 		{
 			$this->action			= CreateObject('filemanager.uiaction_base');
 			$this->bofilemanager	= $this->action->bofilemanager;
@@ -1432,7 +1432,7 @@
 
 			if ($_POST['save'])
 			{
-				if (empty($val) || ereg("^[ 0-9]+(,[ 0-9]+)*$",$val))
+				if (empty($val) || preg_match("/^[ 0-9]+(,[ 0-9]+)*$/",$val))
 				{
 					$this->config->value('set_quota', '0,' . $val . ',unlimited');
 				}
@@ -1731,4 +1731,4 @@
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('config' => $data));
 		}
 	}
-?>
+
