@@ -360,7 +360,7 @@ function setMenuStructureFile($tree_file) {
 	}
 	$this->menuStructure = "";
 	while ($buffer = fgets($fd, 4096)) {
-		$buffer = ereg_replace(chr(13), "", $buffer);	// Microsoft Stupidity Suppression
+		$buffer = str_replace(chr(13), "", $buffer);	// Microsoft Stupidity Suppression
 		$this->menuStructure .= $buffer;
 	}
 	fclose($fd);
@@ -378,7 +378,7 @@ function setMenuStructureFile($tree_file) {
 * @return boolean
 */
 function setMenuStructureString($tree_string) {
-	$this->menuStructure = ereg_replace(chr(13), "", $tree_string);	// Microsoft Stupidity Suppression
+	$this->menuStructure = str_replace(chr(13), "", $tree_string);	// Microsoft Stupidity Suppression
 	if ($this->menuStructure == "") {
 		$this->error("setMenuStructureString: empty string.");
 		return false;
@@ -669,7 +669,7 @@ function _postParse(
 	for ($cnt=$this->_firstItem[$menu_name]; $cnt<=$this->_lastItem[$menu_name]; $cnt++) {	// this counter scans all nodes of the new menu
 		$this->tree[$cnt]["child_of_root_node"] = ($this->tree[$cnt]["level"] == 1);
 		$this->tree[$cnt]["parsed_text"] = stripslashes($this->tree[$cnt]["text"]);
-		$this->tree[$cnt]["parsed_href"] = (ereg_replace(" ", "", $this->tree[$cnt]["href"]) == "") ? "#" : $this->prependedUrl . $this->tree[$cnt]["href"];
+		$this->tree[$cnt]["parsed_href"] = (str_replace(" ", "", $this->tree[$cnt]["href"]) == "") ? "#" : $this->prependedUrl . $this->tree[$cnt]["href"];
 		$this->tree[$cnt]["parsed_title"] = ($this->tree[$cnt]["title"] == "") ? "" : " title=\"" . addslashes($this->tree[$cnt]["title"]) . "\"";
 		$fooimg = $this->imgdir . $this->tree[$cnt]["icon"];
 		if ($this->tree[$cnt]["icon"] == "" || !(file_exists($fooimg))) {
