@@ -8,7 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package hrm
 	* @subpackage user
- 	* @version $Id: class.uiuser.inc.php 4416 2009-12-25 17:33:44Z sigurd $
+ 	* @version $Id: class.uiuser.inc.php 15259 2016-06-06 12:26:20Z sigurdne $
 	*/
 
 	/**
@@ -36,7 +36,7 @@
 			'view_cv'	=> true
 		);
 
-		function hrm_uiuser()
+		function __construct()
 		{
 			$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
 			$this->nextmatchs			= CreateObject('phpgwapi.nextmatchs');
@@ -76,7 +76,7 @@
 			$content = array();
 			foreach ( $account_info as $entry )
 			{
-				if($entry['grants'])
+				if($this->bocommon->check_perms2($entry['account_id'], $this->grants, PHPGW_ACL_READ))
 				{
 					$link_training				= $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> 'hrm.uiuser.training', 'user_id'=> $entry['account_id']));
 					$text_training				= lang('training');
@@ -182,9 +182,9 @@
 		{
 			$user_id	= phpgw::get_var('user_id', 'int');
 
-			if (!$this->grants[$user_id])
+			if (!$this->bocommon->check_perms2($user_id, $this->grants, PHPGW_ACL_READ))
 			{
-				$this->bocommon->no_access($links);
+				phpgw::no_access();
 				return;
 			}
 
@@ -216,13 +216,13 @@
 					$entry['end_date']	= $GLOBALS['phpgw']->common->show_date($entry['end_date'],$dateformat);
 				}
 
-				if($this->bocommon->check_perms($this->grants[$user_id], PHPGW_ACL_EDIT))
+				if($this->bocommon->check_perms2($user_id, $this->grants, PHPGW_ACL_EDIT))
 				{
 					$link_edit	= $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> 'hrm.uiuser.edit', 'user_id'=> $user_id, 'training_id'=> $entry['training_id']));
 					$text_edit	= lang('edit');
 					$lang_edit_text	= lang('edit training item');
 				}
-				if($this->bocommon->check_perms($this->grants[$user_id], PHPGW_ACL_DELETE))
+				if($this->bocommon->check_perms2($user_id,$this->grants, PHPGW_ACL_DELETE))
 				{
 					$link_delete		= $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> 'hrm.uiuser.delete', 'user_id'=> $user_id, 'training_id'=> $entry['training_id']));
 					$text_delete		= lang('delete');
@@ -320,7 +320,7 @@
 				'user_id'	=> $user_id
 			);
 
-			if($this->bocommon->check_perms($this->grants[$user_id], PHPGW_ACL_ADD))
+			if($this->bocommon->check_perms2($user_id, $this->grants, PHPGW_ACL_ADD))
 			{
 				$add_action	= $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> 'hrm.uiuser.edit', 'user_id'=> $user_id));
 				$lang_add	= lang('add');
@@ -388,17 +388,17 @@
 
 			if(!$training_id)
 			{
-				if(!$this->bocommon->check_perms($this->grants[$user_id], PHPGW_ACL_ADD))
+				if(!$this->bocommon->check_perms2($user_id, $this->grants, PHPGW_ACL_ADD))
 				{
-					$this->bocommon->no_access($links);
+					phpgw::no_access();
 					return;
 				}
 			}
 			else
 			{
-				if(!$this->bocommon->check_perms($this->grants[$user_id], PHPGW_ACL_EDIT))
+				if(!$this->bocommon->check_perms2($user_id, $this->grants, PHPGW_ACL_EDIT))
 				{
-					$this->bocommon->no_access($links);
+					phpgw::no_access();
 					return;
 				}
 			}
@@ -605,9 +605,9 @@
 			$training_id		= phpgw::get_var('training_id', 'int');
 			$user_id	= phpgw::get_var('user_id', 'int');
 
-			if(!$this->bocommon->check_perms($this->grants[$user_id], PHPGW_ACL_READ))
+			if(!$this->bocommon->check_perms2($user_id, $this->grants, PHPGW_ACL_READ))
 			{
-				$this->bocommon->no_access($links);
+				phpgw::no_access();
 				return;
 			}
 			$GLOBALS['phpgw']->xslttpl->add_file(array('user'));
@@ -691,9 +691,9 @@
 			$training_id		= phpgw::get_var('training_id', 'int');
 			$user_id	= phpgw::get_var('user_id', 'int');
 
-			if(!$this->bocommon->check_perms($this->grants[$user_id], PHPGW_ACL_DELETE))
+			if(!$this->bocommon->check_perms2($user_id, $this->grants, PHPGW_ACL_DELETE))
 			{
-				$this->bocommon->no_access($links);
+				phpgw::no_access();
 				return;
 			}
 			$confirm = phpgw::get_var('confirm', 'bool', 'POST');
@@ -734,9 +734,9 @@
 		{
 			$user_id	= phpgw::get_var('user_id', 'int');
 
-			if(!$this->bocommon->check_perms($this->grants[$user_id], PHPGW_ACL_READ))
+			if(!$this->bocommon->check_perms2($user_id, $this->grants, PHPGW_ACL_READ))
 			{
-				$this->bocommon->no_access($links);
+				phpgw::no_access();
 				return;
 			}
 
@@ -811,7 +811,7 @@
 			$pdf->ezStartPageNumbers(500,28,10,'right','{PAGENUM} ' . lang('of') . ' {TOTALPAGENUM}',1);
 
 			$pdf->ezTable($content_heading,'','',
-							array('xPos'=>220,'xOrientation'=>'right','width'=>300,0,'shaded'=>0,'fontSize' => 10,'showLines'=> 0,'titleFontSize' => 12,'outerLineThickness'=>0,'showHeadings'=>0
+							array('xPos'=>220,'xOrientation'=>'right','width'=>300,0,'shaded'=>0,'fontSize' => 10,'gridlines'=> 0,'titleFontSize' => 12,'outerLineThickness'=>0,'showHeadings'=>0
 							,'cols'=>array('text'=>array('justification'=>'left','width'=>100),
 									'value'=>array('justification'=>'left','width'=>200))
 							)
@@ -841,7 +841,7 @@
 					);
 					$pdf->ezSetDy(-20);
 					$pdf->ezTable($content,'','',
-							array('xPos'=>50,'xOrientation'=>'right','width'=>500,0,'shaded'=>0,'fontSize' => 12,'showLines'=> 0,'titleFontSize' => 12,'outerLineThickness'=>2,'showHeadings'=>0
+							array('xPos'=>50,'xOrientation'=>'right','width'=>500,0,'shaded'=>0,'fontSize' => 12,'gridlines'=> 0,'titleFontSize' => 12,'outerLineThickness'=>2,'showHeadings'=>0
 							,'cols'=>$table_header
 							)
 						);
@@ -869,7 +869,7 @@
 				);
 
 				$pdf->ezTable($content,'','',
-							array('xPos'=>50,'xOrientation'=>'right','width'=>500,0,'shaded'=>0,'fontSize' => 10,'showLines'=> 0,'titleFontSize' => 12,'outerLineThickness'=>2,'showHeadings'=>0
+							array('xPos'=>50,'xOrientation'=>'right','width'=>500,0,'shaded'=>0,'fontSize' => 10,'gridlines'=> 0,'titleFontSize' => 12,'outerLineThickness'=>2,'showHeadings'=>0
 							,'cols'=>$table_header
 							)
 						);
