@@ -8,11 +8,11 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package hrm
 	* @subpackage setup
- 	* @version $Id: setup.inc.php 17353 2006-10-05 13:14:13Z sigurdne $
+ 	* @version $Id: setup.inc.php 4416 2009-12-25 17:33:44Z sigurd $
 	*/
 
 	$setup_info['hrm']['name']      = 'hrm';
-	$setup_info['hrm']['version']   = '0.9.17.005';
+	$setup_info['hrm']['version']   = '0.9.17.006';
 	$setup_info['hrm']['app_order'] = 20;
 	$setup_info['hrm']['enable']    = 1;
 	$setup_info['hrm']['globals_checked']    = True;
@@ -73,9 +73,8 @@
 		'manual',
 		'settings',
 		'preferences',
-		'admin',
 		'help',
-		'sidebox_menu'
+		'menu'	=> 'hrm.menu.get_menu'
 	);
 
 	/* Dependencies for this app to work */
