@@ -5,7 +5,7 @@
 	* @copyright Copyright (C) 2003-2004, Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.fsf.org/licenses/gpl.html GNU General Public License
 	* @package ipc_test_suite
-	* @version $Id: class.ipc_test_suite.inc.php 690 2008-02-02 10:11:33Z dave $
+	* @version $Id: class.ipc_test_suite.inc.php 13909 2015-09-15 10:53:28Z sigurdne $
 	*/
 
 	/**
@@ -22,7 +22,7 @@
 		/**
 		* Constructor
 		*/
-		function ipc_test_suite()
+		function __construct()
 		{}
 		
 		/**
