@@ -6,7 +6,7 @@
 	* @license http://www.fsf.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage ipc
-	* @version $Id: class.ipc_addressbook.inc.php 1040 2008-05-26 10:27:54Z dave $
+	* @version $Id: class.ipc_addressbook.inc.php 13955 2015-09-17 16:45:28Z sigurdne $
 	*/
 
 	/**
@@ -489,7 +489,7 @@
 		*/
 		function _import_vcard($data)
 		{
-			$data = ereg_replace("\n\n", "\r\n", $data); // xml-rpc bug: \r\n -> \n\n
+			$data = str_replace("\n\n", "\r\n", $data); // xml-rpc bug: \r\n -> \n\n
 			$data_lines = explode("\r\n", $data);
 
 			$buffer = array();
@@ -627,7 +627,7 @@
 							$add_parts = explode(',', utf8_decode($data[$attribute][0]));
 							for($k=0;$k<count($add_parts);++$k)
 							{
-								list($name, $value) = split('=', $add_parts[$k], 2);
+								list($name, $value) = explode('=', $add_parts[$k], 2);
 								$value = utf8_decode($value);
 								switch(strtolower($name))
 								{
@@ -690,7 +690,7 @@
 							$add_parts = explode(';', utf8_decode($data[$attribute][0]));
 							for($k=0;$k<count($add_parts);++$k)
 							{
-								list($name, $value) = split('=', $add_parts[$k], 2);
+								list($name, $value) = explode('=', $add_parts[$k], 2);
 								switch(strtolower($name))
 								{
 									case 'c':
