@@ -1,31 +1,38 @@
-$(document).ready(function(){
+$(document).ready(function ()
+{
 
-	$("#project_details input").focus(function(e){
-		var wrpElem = $(this).parents("dd");
-		$(wrpElem).find(".help_text").fadeIn(200);
-	});
-	
-	$("#project_details textarea").focus(function(e){
+	$("#project_details input").focus(function (e)
+	{
 		var wrpElem = $(this).parents("dd");
 		$(wrpElem).find(".help_text").fadeIn(200);
 	});
 
-	$("#project_details select").focus(function(e){
+	$("#project_details textarea").focus(function (e)
+	{
 		var wrpElem = $(this).parents("dd");
 		$(wrpElem).find(".help_text").fadeIn(200);
 	});
-	
-	$("#project_details textarea").focusout(function(e){
+
+	$("#project_details select").focus(function (e)
+	{
+		var wrpElem = $(this).parents("dd");
+		$(wrpElem).find(".help_text").fadeIn(200);
+	});
+
+	$("#project_details textarea").focusout(function (e)
+	{
 		var wrpElem = $(this).parents("dd");
 		$(wrpElem).find(".help_text").fadeOut();
 	});
-	
-	$("#project_details input").focusout(function(e){
+
+	$("#project_details input").focusout(function (e)
+	{
 		var wrpElem = $(this).parents("dd");
 		$(wrpElem).find(".help_text").fadeOut();
 	});
-		
-	$("#project_details select").focusout(function(e){
+
+	$("#project_details select").focusout(function (e)
+	{
 		var wrpElem = $(this).parents("dd");
 		$(wrpElem).find(".help_text").fadeOut();
 	});
