@@ -1,6 +1,8 @@
 <?php
+
 	class mobilefrontend_menu
 	{
+
 		function get_menu()
 		{
 			$incoming_app = $GLOBALS['phpgw_info']['flags']['currentapp'];
@@ -8,15 +10,15 @@
 
 			$menus = array();
 
-			if ( $GLOBALS['phpgw']->acl->check('run', phpgwapi_acl::READ, 'admin')
-			|| $GLOBALS['phpgw']->acl->check('admin', phpgwapi_acl::ADD, 'mobilefrontend'))
+			if ($GLOBALS['phpgw']->acl->check('run', phpgwapi_acl::READ, 'admin') || $GLOBALS['phpgw']->acl->check('admin', phpgwapi_acl::ADD, 'mobilefrontend'))
 			{
 				$menus['admin'] = array
-				(
-					'index'	=> array
 					(
-						'text'	=> lang('Configuration'),
-						'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'admin.uiconfig.index', 'appname' => 'mobilefrontend') )
+					'index' => array
+						(
+						'text' => lang('Configuration'),
+						'url' => $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'admin.uiconfig.index',
+							'appname' => 'mobilefrontend'))
 					),
 				);
 			}
@@ -24,4 +26,4 @@
 			$GLOBALS['phpgw_info']['flags']['currentapp'] = $incoming_app;
 			return $menus;
 		}
-	}
+	}
\ No newline at end of file
