@@ -1,7 +1,7 @@
 <?php
 /*
 
-@version V5.11 5 May 2010   (c) 2000-2010 John Lim (jlim#natsoft.com). All rights reserved.
+@version V5.19  23-Apr-2014  (c) 2000-2014 John Lim (jlim#natsoft.com). All rights reserved.
   Latest version is available at http://adodb.sourceforge.net
  
   Released under both BSD license and Lesser GPL library license. 
@@ -87,6 +87,8 @@ class ADODB_Active_Record {
 
 	var $foreignName; // CFR: class name when in a relationship
 
+	var $lockMode = ' for update '; // you might want to change to 
+	
 	static function UseDefaultValues($bool=null)
 	{
 	global $ADODB_ACTIVE_DEFVALS;
@@ -631,17 +633,17 @@ class ADODB_Active_Record {
 		switch($t) {
 		case 'L':
 			if (strpos($db->databaseType,'postgres') !== false) return $db->qstr($val);
-		case 'D':
+		case 'D':	
 		case 'T':
 			if (empty($val)) return 'null';
 		
-		case 'B':
+		case 'B':	
 		case 'N':
 		case 'C':
 		case 'X':
 			if (is_null($val)) return 'null';
 			
-			if (strlen($val)>1 && 
+			if (strlen($val)>0 && 
 				(strncmp($val,"'",1) != 0 || substr($val,strlen($val)-1,1) != "'")) { 
 				return $db->qstr($val);
 				break;
@@ -677,7 +679,7 @@ class ADODB_Active_Record {
 	
 	//------------------------------------------------------------ Public functions below
 	
-	function Load($where=null,$bindarr=false)
+	function Load($where=null,$bindarr=false, $lock = false)
 	{
 	global $ADODB_FETCH_MODE;
 	
@@ -689,10 +691,12 @@ class ADODB_Active_Record {
 		if ($db->fetchMode !== false) $savem = $db->SetFetchMode(false);
 		
 		$qry = "select * from ".$this->_table;
-
+		
 		if($where) {
 			$qry .= ' WHERE '.$where;
 		}
+		if ($lock) $qry .= $this->lockMode;
+		
 		$row = $db->GetRow($qry,$bindarr);
 		
 		if (isset($savem)) $db->SetFetchMode($savem);
@@ -701,6 +705,11 @@ class ADODB_Active_Record {
 		return $this->Set($row);
 	}
 	
+	function LoadLocked($where=null, $bindarr=false)
+	{
+		$this->Load($where,$bindarr,true);
+	}
+	
 	# useful for multiple record inserts
 	# see http://phplens.com/lens/lensforum/msgs.php?id=17795
 	function Reset()
@@ -899,10 +908,11 @@ class ADODB_Active_Record {
 					}
 				}
 			}
+
+			if (isset($this->_original[$i]) && strcmp($val,$this->_original[$i]) == 0) continue;
+			
+			if (is_null($this->_original[$i]) && is_null($val)) continue;
 			
-			if (isset($this->_original[$i]) && strcmp($val,$this->_original[$i]) == 0) {
-				continue;
-			}			
 			$valarr[] = $val;
 			$pairs[] = $this->_QName($name,$db).'='.$db->Param($cnt);
 			$cnt += 1;
@@ -989,4 +999,3 @@ global $_ADODB_ACTIVE_DBS;
 
 	return $arr;
 }
-?>
\ No newline at end of file
