@@ -1,7 +1,7 @@
 <?php
 /*
 
-  version V5.11 5 May 2010  (c) 2000-2010 John Lim. All rights reserved.
+  version V5.19  23-Apr-2014  (c) 2000-2014 John Lim. All rights reserved.
 
   Released under both BSD license and Lesser GPL library license. 
   Whenever there is any discrepancy between the two licenses, 
@@ -30,8 +30,8 @@ For Oracle the default is dd-mon-yy or dd-mon-yyyy, and for SQL-92 the default i
 yy-mm-dd or yyyy-mm-dd.
 
 Using 'RR' in the format forces two-digit years less than or equal to 49 to be
-interpreted as years in the 21st century (20002049), and years over 50 as years in
-the 20th century (19501999). Setting the RR format as the default for all two-digit
+interpreted as years in the 21st century (2000-2049), and years over 50 as years in
+the 20th century (1950-1999). Setting the RR format as the default for all two-digit
 year entries allows you to become year-2000 compliant. For example:
 NLS_DATE_FORMAT='RR-MM-DD'
 
@@ -72,8 +72,15 @@ class ADODB_oci8 extends ADOConnection {
   where owner='%s' and table_name='%s' order by column_id"; // when there is a schema
 	var $_bindInputArray = true;
 	var $hasGenID = true;
-	var $_genIDSQL = "SELECT (%s.nextval) FROM DUAL";
-	var $_genSeqSQL = "CREATE SEQUENCE %s START WITH %s";
+	var $_genIDSQL = "SELECT (%s.nextval) FROM DUAL";	
+	var $_genSeqSQL = "
+DECLARE
+  PRAGMA AUTONOMOUS_TRANSACTION;
+BEGIN
+	execute immediate 'CREATE SEQUENCE %s START WITH %s';
+END;
+";
+
 	var $_dropSeqSQL = "DROP SEQUENCE %s";
 	var $hasAffectedRows = true;
 	var $random = "abs(mod(DBMS_RANDOM.RANDOM,10000001)/10000000)";
@@ -81,7 +88,7 @@ class ADODB_oci8 extends ADOConnection {
 	var $connectSID = false;
 	var $_bind = false;
 	var $_nestedSQL = true;
-	var $_hasOCIFetchStatement = false;
+	var $_hasOciFetchStatement = false;
 	var $_getarray = false; // currently not working
 	var $leftOuter = '';  // oracle wierdness, $col = $value (+) for LEFT OUTER, $col (+)= $value for RIGHT OUTER
 	var $session_sharing_force_blob = false; // alter session on updateblob if set to true 
@@ -97,7 +104,7 @@ class ADODB_oci8 extends ADOConnection {
     
 	function ADODB_oci8() 
 	{
-		$this->_hasOCIFetchStatement = ADODB_PHPVER >= 0x4200;
+		$this->_hasOciFetchStatement = ADODB_PHPVER >= 0x4200;
 		if (defined('ADODB_EXTENSION')) $this->rsPrefix .= 'ext_';
 	}
 	
@@ -105,7 +112,7 @@ class ADODB_oci8 extends ADOConnection {
 	function MetaColumns($table, $normalize=true) 
 	{
 	global $ADODB_FETCH_MODE;
-	
+		
 		$schema = '';
 		$this->_findschema($table, $schema);
 		
@@ -113,11 +120,11 @@ class ADODB_oci8 extends ADOConnection {
 		$save = $ADODB_FETCH_MODE;
 		$ADODB_FETCH_MODE = ADODB_FETCH_NUM;
 		if ($this->fetchMode !== false) $savem = $this->SetFetchMode(false);
-		
+
 		if ($schema)
 			$rs = $this->Execute(sprintf($this->metaColumnsSQL2, strtoupper($schema), strtoupper($table)));
 		else
-		$rs = $this->Execute(sprintf($this->metaColumnsSQL,strtoupper($table)));
+			$rs = $this->Execute(sprintf($this->metaColumnsSQL,strtoupper($table)));
 		
 		if (isset($savem)) $this->SetFetchMode($savem);
 		$ADODB_FETCH_MODE = $save;
@@ -158,43 +165,35 @@ class ADODB_oci8 extends ADOConnection {
 		return false;
 	}
  
-/*
-
-  Multiple modes of connection are supported:
-  
-  a. Local Database
-    $conn->Connect(false,'scott','tiger');
-  
-  b. From tnsnames.ora
-    $conn->Connect(false,'scott','tiger',$tnsname); 
-    $conn->Connect($tnsname,'scott','tiger'); 
-  
-  c. Server + service name
-    $conn->Connect($serveraddress,'scott,'tiger',$service_name);
-  
-  d. Server + SID
-  	$conn->connectSID = true;
-	$conn->Connect($serveraddress,'scott,'tiger',$SID);
-
-
-Example TNSName:
----------------
-NATSOFT.DOMAIN =
-  (DESCRIPTION =
-	(ADDRESS_LIST =
-	  (ADDRESS = (PROTOCOL = TCP)(HOST = kermit)(PORT = 1523))
-	)
-	(CONNECT_DATA =
-	  (SERVICE_NAME = natsoft.domain)
-	)
-  )
-  
-  There are 3 connection modes, 0 = non-persistent, 1 = persistent, 2 = force new connection
-	
-*/
-	function _connect($argHostname, $argUsername, $argPassword, $argDatabasename,$mode=0)
+	/**
+	 * Multiple modes of connection are supported:
+	 *
+	 * a. Local Database
+	 *    $conn->Connect(false,'scott','tiger');
+	 *
+	 * b. From tnsnames.ora
+	 *    $conn->Connect($tnsname,'scott','tiger');
+	 *    $conn->Connect(false,'scott','tiger',$tnsname);
+	 *
+	 * c. Server + service name
+	 *    $conn->Connect($serveraddress,'scott,'tiger',$service_name);
+	 *
+	 * d. Server + SID
+	 *    $conn->connectSID = true;
+	 *    $conn->Connect($serveraddress,'scott,'tiger',$SID);
+	 *
+	 * @param string|false $argHostname DB server hostname or TNS name
+	 * @param string $argUsername
+	 * @param string $argPassword
+	 * @param string $argDatabasename Service name, SID (defaults to null)
+	 * @param int $mode Connection mode, defaults to 0
+	 *                  (0 = non-persistent, 1 = persistent, 2 = force new connection)
+	 *
+	 * @return bool
+	 */
+	function _connect($argHostname, $argUsername, $argPassword, $argDatabasename=null, $mode=0)
 	{
-		if (!function_exists('OCIPLogon')) return null;
+		if (!function_exists('oci_pconnect')) return null;
 		#adodb_backtrace(); 
 		
         $this->_errorMsg = false;
@@ -227,32 +226,30 @@ NATSOFT.DOMAIN =
 				
  		//if ($argHostname) print "<p>Connect: 1st argument should be left blank for $this->databaseType</p>";
 		if ($mode==1) {
-			$this->_connectionID = ($this->charSet) ? 
-				OCIPLogon($argUsername,$argPassword, $argDatabasename,$this->charSet)
-				:
-				OCIPLogon($argUsername,$argPassword, $argDatabasename)
-				;
-			if ($this->_connectionID && $this->autoRollback)  OCIrollback($this->_connectionID);
+			$this->_connectionID = ($this->charSet)
+				? oci_pconnect($argUsername,$argPassword, $argDatabasename,$this->charSet)
+				: oci_pconnect($argUsername,$argPassword, $argDatabasename);
+			if ($this->_connectionID && $this->autoRollback)  oci_rollback($this->_connectionID);
 		} else if ($mode==2) {
-			$this->_connectionID = ($this->charSet) ? 
-				OCINLogon($argUsername,$argPassword, $argDatabasename,$this->charSet)
-				:
-				OCINLogon($argUsername,$argPassword, $argDatabasename);
-				
+			$this->_connectionID = ($this->charSet)
+				? oci_new_connect($argUsername,$argPassword, $argDatabasename,$this->charSet)
+				: oci_new_connect($argUsername,$argPassword, $argDatabasename);
 		} else {
-			$this->_connectionID = ($this->charSet) ? 
-				OCILogon($argUsername,$argPassword, $argDatabasename,$this->charSet)
-				:
-				OCILogon($argUsername,$argPassword, $argDatabasename);
+			$this->_connectionID = ($this->charSet)
+				? oci_connect($argUsername,$argPassword, $argDatabasename,$this->charSet)
+				: oci_connect($argUsername,$argPassword, $argDatabasename);
 		}
-		if (!$this->_connectionID) return false;
+		if (!$this->_connectionID) {
+			return false;
+		}
+
 		if ($this->_initdate) {
 			$this->Execute("ALTER SESSION SET NLS_DATE_FORMAT='".$this->NLS_DATE_FORMAT."'");
 		}
 		
 		// looks like: 
 		// Oracle8i Enterprise Edition Release 8.1.7.0.0 - Production With the Partitioning option JServer Release 8.1.7.0.0 - Production
-		// $vers = OCIServerVersion($this->_connectionID);
+		// $vers = oci_server_version($this->_connectionID);
 		// if (strpos($vers,'8i') !== false) $this->ansiOuter = true;
 		return true;
    	}
@@ -260,7 +257,7 @@ NATSOFT.DOMAIN =
 	function ServerInfo()
 	{
 		$arr['compat'] = $this->GetOne('select value from sys.database_compatible_level');
-		$arr['description'] = @OCIServerVersion($this->_connectionID);
+		$arr['description'] = @oci_server_version($this->_connectionID);
 		$arr['version'] = ADOConnection::_findvers($arr['description']);
 		return $arr;
 	}
@@ -278,7 +275,7 @@ NATSOFT.DOMAIN =
 	
 	function _affectedrows()
 	{
-		if (is_resource($this->_stmt)) return @OCIRowCount($this->_stmt);
+		if (is_resource($this->_stmt)) return @oci_num_rows($this->_stmt);
 		return 0;
 	}
 	
@@ -291,7 +288,11 @@ NATSOFT.DOMAIN =
 	function DBDate($d,$isfld=false)
 	{
 		if (empty($d) && $d !== 0) return 'null';
-		if ($isfld) return 'TO_DATE('.$d.",'".$this->dateformat."')";
+		
+		if ($isfld) {
+			$d = _adodb_safedate($d);
+			return 'TO_DATE('.$d.",'".$this->dateformat."')";
+		}
 		
 		if (is_string($d)) $d = ADORecordSet::UnixDate($d);
 		
@@ -326,9 +327,9 @@ NATSOFT.DOMAIN =
 		if (empty($ts) && $ts !== 0) return 'null';
 		if ($isfld) return 'TO_DATE(substr('.$ts.",1,19),'RRRR-MM-DD, HH24:MI:SS')";
 		if (is_string($ts)) $ts = ADORecordSet::UnixTimeStamp($ts);
-		
+	
 		if (is_object($ts)) $tss = $ts->format("'Y-m-d H:i:s'");
-		else $tss = adodb_date("'Y-m-d H:i:s'",$ts);
+		else $tss = date("'Y-m-d H:i:s'",$ts);
 		
 		return 'TO_DATE('.$tss.",'RRRR-MM-DD, HH24:MI:SS')";
 	}
@@ -375,6 +376,13 @@ NATSOFT.DOMAIN =
 
 		$false = false;
 		$rs = $this->Execute(sprintf("SELECT * FROM ALL_CONSTRAINTS WHERE UPPER(TABLE_NAME)='%s' AND CONSTRAINT_TYPE='P'",$table));
+		if (!is_object($rs)) {
+			if (isset($savem)) 
+				$this->SetFetchMode($savem);
+			$ADODB_FETCH_MODE = $save;
+            return $false;
+        }
+		
 		if ($row = $rs->FetchRow())
 		   $primary_key = $row[1]; //constraint_name
 
@@ -440,7 +448,7 @@ NATSOFT.DOMAIN =
 		if (!$ok) return $this->RollbackTrans();
 		
 		if ($this->transCnt) $this->transCnt -= 1;
-		$ret = OCIcommit($this->_connectionID);
+		$ret = oci_commit($this->_connectionID);
 		$this->_commit = OCI_COMMIT_ON_SUCCESS;
 		$this->autoCommit = true;
 		return $ret;
@@ -450,7 +458,7 @@ NATSOFT.DOMAIN =
 	{
 		if ($this->transOff) return true;
 		if ($this->transCnt) $this->transCnt -= 1;
-		$ret = OCIrollback($this->_connectionID);
+		$ret = oci_rollback($this->_connectionID);
 		$this->_commit = OCI_COMMIT_ON_SUCCESS;
 		$this->autoCommit = true;
 		return $ret;
@@ -466,10 +474,10 @@ NATSOFT.DOMAIN =
 	{
 		if ($this->_errorMsg !== false) return $this->_errorMsg;
 
-		if (is_resource($this->_stmt)) $arr = @OCIError($this->_stmt);
+		if (is_resource($this->_stmt)) $arr = @oci_error($this->_stmt);
 		if (empty($arr)) {
-			if (is_resource($this->_connectionID)) $arr = @OCIError($this->_connectionID);
-			else $arr = @OCIError();
+			if (is_resource($this->_connectionID)) $arr = @oci_error($this->_connectionID);
+			else $arr = @oci_error();
 			if ($arr === false) return '';
 		}
 		$this->_errorMsg = $arr['message'];
@@ -481,10 +489,10 @@ NATSOFT.DOMAIN =
 	{
 		if ($this->_errorCode !== false) return $this->_errorCode;
 		
-		if (is_resource($this->_stmt)) $arr = @OCIError($this->_stmt);
+		if (is_resource($this->_stmt)) $arr = @oci_error($this->_stmt);
 		if (empty($arr)) {
-			$arr = @OCIError($this->_connectionID);
-			if ($arr == false) $arr = @OCIError();
+			$arr = @oci_error($this->_connectionID);
+			if ($arr == false) $arr = @oci_error();
 			if ($arr == false) return '';
 		}
 		
@@ -494,7 +502,9 @@ NATSOFT.DOMAIN =
 		return $arr['code'];
 	}
 	
-	// Format date column in sql string given an input format that understands Y M D
+	/**
+	 * Format date column in sql string given an input format that understands Y M D
+	 */
 	function SQLDate($fmt, $col=false)
 	{	
 		if (!$col) $col = $this->sysTimeStamp;
@@ -579,30 +589,36 @@ NATSOFT.DOMAIN =
 		return $this->GetRow($sql,$arr);
 	}
 	
-	/*
-	This algorithm makes use of
-	
-	a. FIRST_ROWS hint
-	The FIRST_ROWS hint explicitly chooses the approach to optimize response time, 
-	that is, minimum resource usage to return the first row. Results will be returned 
-	as soon as they are identified. 
-
-	b. Uses rownum tricks to obtain only the required rows from a given offset.
-	 As this uses complicated sql statements, we only use this if the $offset >= 100. 
-	 This idea by Tomas V V Cox.
-	 
-	 This implementation does not appear to work with oracle 8.0.5 or earlier. Comment
-	 out this function then, and the slower SelectLimit() in the base class will be used.
+	/**
+	 * This algorithm makes use of
+	 *
+	 * a. FIRST_ROWS hint
+	 * The FIRST_ROWS hint explicitly chooses the approach to optimize response
+	 * time, that is, minimum resource usage to return the first row. Results
+	 * will be returned as soon as they are identified.
+	 *
+	 * b. Uses rownum tricks to obtain only the required rows from a given offset.
+	 * As this uses complicated sql statements, we only use this if $offset >= 100.
+	 * This idea by Tomas V V Cox.
+	 *
+	 * This implementation does not appear to work with oracle 8.0.5 or earlier.
+	 * Comment out this function then, and the slower SelectLimit() in the base
+	 * class will be used.
 	*/
 	function SelectLimit($sql,$nrows=-1,$offset=-1, $inputarr=false,$secs2cache=0)
 	{
 		// seems that oracle only supports 1 hint comment in 8i
 		if ($this->firstrows) {
+			if ($nrows > 500 && $nrows < 1000) $hint = "FIRST_ROWS($nrows)";
+			else $hint = 'FIRST_ROWS';
+			
 			if (strpos($sql,'/*+') !== false)
-				$sql = str_replace('/*+ ','/*+FIRST_ROWS ',$sql);
+				$sql = str_replace('/*+ ',"/*+$hint ",$sql);
 			else
-				$sql = preg_replace('/^[ \t\n]*select/i','SELECT /*+FIRST_ROWS*/',$sql);
-		}
+				$sql = preg_replace('/^[ \t\n]*select/i',"SELECT /*+$hint*/",$sql);
+			$hint = "/*+ $hint */";
+		} else
+			$hint = '';
 		
 		if ($offset == -1 || ($offset < $this->selectOffsetAlg1 && 0 < $nrows && $nrows < 1000)) {
 			if ($nrows > 0) {	
@@ -637,46 +653,45 @@ NATSOFT.DOMAIN =
 			 	foreach($inputarr as $k => $v) {
 					if (is_array($v)) {
 						if (sizeof($v) == 2) // suggested by g.giunta@libero.
-							OCIBindByName($stmt,":$k",$inputarr[$k][0],$v[1]);
+							oci_bind_by_name($stmt,":$k",$inputarr[$k][0],$v[1]);
 						else
-							OCIBindByName($stmt,":$k",$inputarr[$k][0],$v[1],$v[2]);
+							oci_bind_by_name($stmt,":$k",$inputarr[$k][0],$v[1],$v[2]);
 					} else {
 						$len = -1;
 						if ($v === ' ') $len = 1;
-						if (isset($bindarr)) {	// is prepared sql, so no need to ocibindbyname again
+						if (isset($bindarr)) {	// is prepared sql, so no need to oci_bind_by_name again
 							$bindarr[$k] = $v;
 						} else { 				// dynamic sql, so rebind every time
-							OCIBindByName($stmt,":$k",$inputarr[$k],$len);
-							
+							oci_bind_by_name($stmt,":$k",$inputarr[$k],$len);
 						}
 					}
 				}
 			}
 			
-			 if (!OCIExecute($stmt, OCI_DEFAULT)) {
-				 OCIFreeStatement($stmt); 
+			 if (!oci_execute($stmt, OCI_DEFAULT)) {
+				 oci_free_statement($stmt); 
 				 return $false;
 			 }
 			 
-			 $ncols = OCINumCols($stmt);
+			 $ncols = oci_num_fields($stmt);
 			 for ( $i = 1; $i <= $ncols; $i++ ) {
-				 $cols[] = '"'.OCIColumnName($stmt, $i).'"';
+				 $cols[] = '"'.oci_field_name($stmt, $i).'"';
 			 }
 			 $result = false;
 			
-			 OCIFreeStatement($stmt); 
+			 oci_free_statement($stmt); 
 			 $fields = implode(',', $cols);
 			 if ($nrows <= 0) $nrows = 999999999999;
 			 else $nrows += $offset;
 			 $offset += 1; // in Oracle rownum starts at 1
 			
 			if ($this->databaseType == 'oci8po') {
-					 $sql = "SELECT /*+ FIRST_ROWS */ $fields FROM".
+					$sql = "SELECT $hint $fields FROM".
 					  "(SELECT rownum as adodb_rownum, $fields FROM".
 					  " ($sql) WHERE rownum <= ?".
 					  ") WHERE adodb_rownum >= ?";
 				} else {
-					 $sql = "SELECT /*+ FIRST_ROWS */ $fields FROM".
+					$sql = "SELECT $hint $fields FROM".
 					  "(SELECT rownum as adodb_rownum, $fields FROM".
 					  " ($sql) WHERE rownum <= :adodb_nrows".
 					  ") WHERE adodb_rownum >= :adodb_offset";
@@ -688,7 +703,6 @@ NATSOFT.DOMAIN =
 			else $rs = $this->Execute($sql,$inputarr);
 			return $rs;
 		}
-	
 	}
 	
 	/**
@@ -696,7 +710,6 @@ NATSOFT.DOMAIN =
 	* Store BLOBs and CLOBs
 	*
 	* Example: to store $var in a blob
-	*
 	*	$conn->Execute('insert into TABLE (id,ablob) values(12,empty_blob())');
 	*	$conn->UpdateBlob('TABLE', 'ablob', $varHoldingBlob, 'ID=12', 'BLOB');
 	*	
@@ -710,7 +723,6 @@ NATSOFT.DOMAIN =
 	*	 $db->Execute('ALTER SESSION SET CURSOR_SHARING=EXACT');
 	* before UpdateBlob() then...
 	*/
-
 	function UpdateBlob($table,$column,$val,$where,$blobtype='BLOB')
 	{
 		
@@ -727,7 +739,7 @@ NATSOFT.DOMAIN =
 		else 
 			$sql = "UPDATE $table set $column=EMPTY_{$blobtype}() WHERE $where RETURNING $column INTO :blob";
 		
-		$desc = OCINewDescriptor($this->_connectionID, OCI_D_LOB);
+		$desc = oci_new_descriptor($this->_connectionID, OCI_D_LOB);
 		$arr['blob'] = array($desc,-1,$type);
 		if ($this->session_sharing_force_blob) $this->Execute('ALTER SESSION SET CURSOR_SHARING=EXACT');
 		$commit = $this->autoCommit;
@@ -758,7 +770,7 @@ NATSOFT.DOMAIN =
 		else 
 			$sql = "UPDATE $table set $column=EMPTY_{$blobtype}() WHERE $where RETURNING $column INTO :blob";
 		
-		$desc = OCINewDescriptor($this->_connectionID, OCI_D_LOB);
+		$desc = oci_new_descriptor($this->_connectionID, OCI_D_LOB);
 		$arr['blob'] = array($desc,-1,$type);
 		
 		$this->BeginTrans();
@@ -785,14 +797,17 @@ NATSOFT.DOMAIN =
 			$ret = $fn($this,$sql,$inputarr);
 			if (isset($ret)) return $ret;
 		}
-		if ($inputarr) {
-			#if (!is_array($inputarr)) $inputarr = array($inputarr);
+		if ($inputarr !== false) {
+			if (!is_array($inputarr)) $inputarr = array($inputarr);
 			
-			$element0 = reset($inputarr);
+			$element0 = reset($inputarr); 
+			$array2d =  $this->bulkBind && is_array($element0) && !is_object(reset($element0));
+			
+			# see http://phplens.com/lens/lensforum/msgs.php?id=18786
+			if ($array2d || !$this->_bindInputArray) {
 			
-			if (!$this->_bindInputArray) {
 			# is_object check because oci8 descriptors can be passed in
-			if (is_array($element0) && !is_object(reset($element0))) {
+			if ($array2d && $this->_bindInputArray) {
 				if (is_string($sql))
 					$stmt = $this->Prepare($sql);
 				else
@@ -802,6 +817,7 @@ NATSOFT.DOMAIN =
 					$ret = $this->_Execute($stmt,$arr);
 					if (!$ret) return $ret;
 				}
+				return $ret;
 			} else {
 				$sqlarr = explode(':',$sql);
 				$sql = '';
@@ -847,20 +863,19 @@ NATSOFT.DOMAIN =
 	}
 	
 	/*
-		Example of usage:
-		
-		$stmt = $this->Prepare('insert into emp (empno, ename) values (:empno, :ename)');
+	 * Example of usage:
+	 *    $stmt = $this->Prepare('insert into emp (empno, ename) values (:empno, :ename)');
 	*/
 	function Prepare($sql,$cursor=false)
 	{
 	static $BINDNUM = 0;
 	
-		$stmt = OCIParse($this->_connectionID,$sql);
+		$stmt = oci_parse($this->_connectionID,$sql);
 
 		if (!$stmt) {
 			$this->_errorMsg = false;
 			$this->_errorCode = false;
-			$arr = @OCIError($this->_connectionID);
+			$arr = @oci_error($this->_connectionID);
 			if ($arr === false) return false;
 		
 			$this->_errorMsg = $arr['message'];
@@ -870,9 +885,9 @@ NATSOFT.DOMAIN =
 		
 		$BINDNUM += 1;
 		
-		$sttype = @OCIStatementType($stmt);
+		$sttype = @oci_statement_type($stmt);
 		if ($sttype == 'BEGIN' || $sttype == 'DECLARE') {
-			return array($sql,$stmt,0,$BINDNUM, ($cursor) ? OCINewCursor($this->_connectionID) : false);
+			return array($sql,$stmt,0,$BINDNUM, ($cursor) ? oci_new_cursor($this->_connectionID) : false);
 		}
 		return array($sql,$stmt,0,$BINDNUM);
 	}
@@ -894,7 +909,7 @@ NATSOFT.DOMAIN =
 	function ExecuteCursor($sql,$cursorName='rs',$params=false)
 	{
 		if (is_array($sql)) $stmt = $sql;
-		else $stmt = ADODB_oci8::Prepare($sql,true); # true to allocate OCINewCursor
+		else $stmt = ADODB_oci8::Prepare($sql,true); # true to allocate oci_new_cursor
 	
 		if (is_array($stmt) && sizeof($stmt) >= 5) {
 			$hasref = true;
@@ -910,41 +925,40 @@ NATSOFT.DOMAIN =
 			
 		$rs = $this->Execute($stmt);
 		if ($rs) {
-			if ($rs->databaseType == 'array') OCIFreeCursor($stmt[4]);
+			if ($rs->databaseType == 'array') oci_free_cursor($stmt[4]);
 			else if ($hasref) $rs->_refcursor = $stmt[4];
 		}
 		return $rs;
 	}
 	
-	/*
-		Bind a variable -- very, very fast for executing repeated statements in oracle. 
-		Better than using
-			for ($i = 0; $i < $max; $i++) {	
-				$p1 = ?; $p2 = ?; $p3 = ?;
-				$this->Execute("insert into table (col0, col1, col2) values (:0, :1, :2)", 
-					array($p1,$p2,$p3));
-			}
-		
-		Usage:
-			$stmt = $DB->Prepare("insert into table (col0, col1, col2) values (:0, :1, :2)");
-			$DB->Bind($stmt, $p1);
-			$DB->Bind($stmt, $p2);
-			$DB->Bind($stmt, $p3);
-			for ($i = 0; $i < $max; $i++) {	
-				$p1 = ?; $p2 = ?; $p3 = ?;
-				$DB->Execute($stmt);
-			}
-			
-		Some timings:		
-			** Test table has 3 cols, and 1 index. Test to insert 1000 records
-			Time 0.6081s (1644.60 inserts/sec) with direct OCIParse/OCIExecute
-			Time 0.6341s (1577.16 inserts/sec) with ADOdb Prepare/Bind/Execute
-			Time 1.5533s ( 643.77 inserts/sec) with pure SQL using Execute
-			
-		Now if PHP only had batch/bulk updating like Java or PL/SQL...
-	
-		Note that the order of parameters differs from OCIBindByName,
-		because we default the names to :0, :1, :2
+	/**
+	 * Bind a variable -- very, very fast for executing repeated statements in oracle.
+	 *
+	 * Better than using
+	 *    for ($i = 0; $i < $max; $i++) {
+	 *        $p1 = ?; $p2 = ?; $p3 = ?;
+	 *        $this->Execute("insert into table (col0, col1, col2) values (:0, :1, :2)", array($p1,$p2,$p3));
+	 *    }
+	 *
+	 * Usage:
+	 *    $stmt = $DB->Prepare("insert into table (col0, col1, col2) values (:0, :1, :2)");
+	 *    $DB->Bind($stmt, $p1);
+	 *    $DB->Bind($stmt, $p2);
+	 *    $DB->Bind($stmt, $p3);
+	 *    for ($i = 0; $i < $max; $i++) {
+	 *        $p1 = ?; $p2 = ?; $p3 = ?;
+	 *        $DB->Execute($stmt);
+	 *    }
+	 *
+	 * Some timings to insert 1000 records, test table has 3 cols, and 1 index.
+	 * - Time 0.6081s (1644.60 inserts/sec) with direct oci_parse/oci_execute
+	 * - Time 0.6341s (1577.16 inserts/sec) with ADOdb Prepare/Bind/Execute
+	 * - Time 1.5533s ( 643.77 inserts/sec) with pure SQL using Execute
+	 *
+	 * Now if PHP only had batch/bulk updating like Java or PL/SQL...
+	 *
+	 * Note that the order of parameters differs from oci_bind_by_name,
+	 * because we default the names to :0, :1, :2
 	*/
 	function Bind(&$stmt,&$var,$size=4000,$type=false,$name=false,$isOutput=false)
 	{
@@ -952,12 +966,12 @@ NATSOFT.DOMAIN =
 		if (!is_array($stmt)) return false;
         
         if (($type == OCI_B_CURSOR) && sizeof($stmt) >= 5) { 
-            return OCIBindByName($stmt[1],":".$name,$stmt[4],$size,$type);
+            return oci_bind_by_name($stmt[1],":".$name,$stmt[4],$size,$type);
         }
         
 		if ($name == false) {
-			if ($type !== false) $rez = OCIBindByName($stmt[1],":".$stmt[2],$var,$size,$type);
-			else $rez = OCIBindByName($stmt[1],":".$stmt[2],$var,$size); // +1 byte for null terminator
+			if ($type !== false) $rez = oci_bind_by_name($stmt[1],":".$stmt[2],$var,$size,$type);
+			else $rez = oci_bind_by_name($stmt[1],":".$stmt[2],$var,$size); // +1 byte for null terminator
 			$stmt[2] += 1;
 		} else if (oci_lob_desc($type)) {
 			if ($this->debug) {
@@ -965,11 +979,11 @@ NATSOFT.DOMAIN =
 			}
             //we have to create a new Descriptor here
 			$numlob = count($this->_refLOBs);
-        	$this->_refLOBs[$numlob]['LOB'] = OCINewDescriptor($this->_connectionID, oci_lob_desc($type));
+        	$this->_refLOBs[$numlob]['LOB'] = oci_new_descriptor($this->_connectionID, oci_lob_desc($type));
 			$this->_refLOBs[$numlob]['TYPE'] = $isOutput;
 			
 			$tmp = $this->_refLOBs[$numlob]['LOB'];
-	        $rez = OCIBindByName($stmt[1], ":".$name, $tmp, -1, $type);
+	        $rez = oci_bind_by_name($stmt[1], ":".$name, $tmp, -1, $type);
 			if ($this->debug) {
 				ADOConnection::outp("<b>Bind</b>: descriptor has been allocated, var (".$name.") binded");
 			}
@@ -990,33 +1004,33 @@ NATSOFT.DOMAIN =
 			if ($this->debug) 
 				ADOConnection::outp("<b>Bind</b>: name = $name");
 			
-			if ($type !== false) $rez = OCIBindByName($stmt[1],":".$name,$var,$size,$type);
-			else $rez = OCIBindByName($stmt[1],":".$name,$var,$size); // +1 byte for null terminator
+			if ($type !== false) $rez = oci_bind_by_name($stmt[1],":".$name,$var,$size,$type);
+			else $rez = oci_bind_by_name($stmt[1],":".$name,$var,$size); // +1 byte for null terminator
 		}
 		
 		return $rez;
 	}
 	
-	function Param($name,$type=false)
+	function Param($name,$type='C')
 	{
 		return ':'.$name;
 	}
 	
-	/* 
-	Usage:
-		$stmt = $db->Prepare('select * from table where id =:myid and group=:group');
-		$db->Parameter($stmt,$id,'myid');
-		$db->Parameter($stmt,$group,'group');
-		$db->Execute($stmt);
-		
-		@param $stmt Statement returned by Prepare() or PrepareSP().
-		@param $var PHP variable to bind to
-		@param $name Name of stored procedure variable name to bind to.
-		@param [$isOutput] Indicates direction of parameter 0/false=IN  1=OUT  2= IN/OUT. This is ignored in oci8.
-		@param [$maxLen] Holds an maximum length of the variable.
-		@param [$type] The data type of $var. Legal values depend on driver.
-		
-		See OCIBindByName documentation at php.net.
+	/**
+	 * Usage:
+	 *    $stmt = $db->Prepare('select * from table where id =:myid and group=:group');
+	 *    $db->Parameter($stmt,$id,'myid');
+	 *    $db->Parameter($stmt,$group,'group');
+	 *    $db->Execute($stmt);
+	 *
+	 * @param $stmt Statement returned by Prepare() or PrepareSP().
+	 * @param $var PHP variable to bind to
+	 * @param $name Name of stored procedure variable name to bind to.
+	 * @param [$isOutput] Indicates direction of parameter 0/false=IN  1=OUT  2= IN/OUT. This is ignored in oci8.
+	 * @param [$maxLen] Holds an maximum length of the variable.
+	 * @param [$type] The data type of $var. Legal values depend on driver.
+	 *
+	 * @link http://php.net/oci_bind_by_name
 	*/
 	function Parameter(&$stmt,&$var,$name,$isOutput=false,$maxLen=4000,$type=false)
 	{
@@ -1028,27 +1042,27 @@ NATSOFT.DOMAIN =
 			return $this->Bind($stmt,$var,$maxLen,$type,$name,$isOutput);
 	}
 	
-	/*
-	returns query ID if successful, otherwise false
-	this version supports:
-	
-	   1. $db->execute('select * from table');
-	   
-	   2. $db->prepare('insert into table (a,b,c) values (:0,:1,:2)');
-		  $db->execute($prepared_statement, array(1,2,3));
-		  
-	   3. $db->execute('insert into table (a,b,c) values (:a,:b,:c)',array('a'=>1,'b'=>2,'c'=>3));
-	   
-	   4. $db->prepare('insert into table (a,b,c) values (:0,:1,:2)');
-		  $db->bind($stmt,1); $db->bind($stmt,2); $db->bind($stmt,3); 
-		  $db->execute($stmt);
+	/**
+	 * returns query ID if successful, otherwise false
+	 * this version supports:
+	 *
+	 * 1. $db->execute('select * from table');
+	 *
+	 * 2. $db->prepare('insert into table (a,b,c) values (:0,:1,:2)');
+	 *    $db->execute($prepared_statement, array(1,2,3));
+	 *
+	 * 3. $db->execute('insert into table (a,b,c) values (:a,:b,:c)',array('a'=>1,'b'=>2,'c'=>3));
+	 *
+	 * 4. $db->prepare('insert into table (a,b,c) values (:0,:1,:2)');
+	 *    $db->bind($stmt,1); $db->bind($stmt,2); $db->bind($stmt,3);
+	 *    $db->execute($stmt);
 	*/ 
 	function _query($sql,$inputarr=false)
 	{
 		if (is_array($sql)) { // is prepared sql
 			$stmt = $sql[1];
 			
-			// we try to bind to permanent array, so that OCIBindByName is persistent
+			// we try to bind to permanent array, so that oci_bind_by_name is persistent
 			// and carried out once only - note that max array element size is 4000 chars
 			if (is_array($inputarr)) {
 				$bindpos = $sql[3];
@@ -1060,27 +1074,27 @@ NATSOFT.DOMAIN =
 					$bindarr = array();
 					foreach($inputarr as $k => $v) {
 						$bindarr[$k] = $v;
-						OCIBindByName($stmt,":$k",$bindarr[$k],is_string($v) && strlen($v)>4000 ? -1 : 4000);
+						oci_bind_by_name($stmt,":$k",$bindarr[$k],is_string($v) && strlen($v)>4000 ? -1 : 4000);
 					}
 					$this->_bind[$bindpos] = $bindarr;
 				}
 			}
 		} else {
-			$stmt=OCIParse($this->_connectionID,$sql);
+			$stmt=oci_parse($this->_connectionID,$sql);
 		}
 			
 		$this->_stmt = $stmt;
 		if (!$stmt) return false;
 	
-		if (defined('ADODB_PREFETCH_ROWS')) @OCISetPrefetch($stmt,ADODB_PREFETCH_ROWS);
+		if (defined('ADODB_PREFETCH_ROWS')) @oci_set_prefetch($stmt,ADODB_PREFETCH_ROWS);
 			
 		if (is_array($inputarr)) {
 			foreach($inputarr as $k => $v) {
 				if (is_array($v)) {
 					if (sizeof($v) == 2) // suggested by g.giunta@libero.
-						OCIBindByName($stmt,":$k",$inputarr[$k][0],$v[1]);
+						oci_bind_by_name($stmt,":$k",$inputarr[$k][0],$v[1]);
 					else
-						OCIBindByName($stmt,":$k",$inputarr[$k][0],$v[1],$v[2]);
+						oci_bind_by_name($stmt,":$k",$inputarr[$k][0],$v[1],$v[2]);
 					
 					if ($this->debug==99) {
 						if (is_object($v[0])) 
@@ -1092,10 +1106,10 @@ NATSOFT.DOMAIN =
 				} else {
 					$len = -1;
 					if ($v === ' ') $len = 1;
-					if (isset($bindarr)) {	// is prepared sql, so no need to ocibindbyname again
+					if (isset($bindarr)) {	// is prepared sql, so no need to oci_bind_by_name again
 						$bindarr[$k] = $v;
 					} else { 				// dynamic sql, so rebind every time
-						OCIBindByName($stmt,":$k",$inputarr[$k],$len);
+						oci_bind_by_name($stmt,":$k",$inputarr[$k],$len);
 					}
 				}
 			}
@@ -1103,8 +1117,8 @@ NATSOFT.DOMAIN =
 		
         $this->_errorMsg = false;
 		$this->_errorCode = false;
-		if (OCIExecute($stmt,$this->_commit)) {
-//OCIInternalDebug(1);			
+		if (oci_execute($stmt,$this->_commit)) {
+			
 			if (count($this -> _refLOBs) > 0) {
 		
 				foreach ($this -> _refLOBs as $key => $value) {
@@ -1126,7 +1140,7 @@ NATSOFT.DOMAIN =
 				}
 			}
 		
-            switch (@OCIStatementType($stmt)) {
+            switch (@oci_statement_type($stmt)) {
                 case "SELECT":
 					return $stmt;
 				
@@ -1135,20 +1149,20 @@ NATSOFT.DOMAIN =
                     if (is_array($sql) && !empty($sql[4])) {
 						$cursor = $sql[4];
 						if (is_resource($cursor)) {
-							$ok = OCIExecute($cursor);	
+							$ok = oci_execute($cursor);	
 	                        return $cursor;
 						}
 						return $stmt;
                     } else {
 						if (is_resource($stmt)) {
-							OCIFreeStatement($stmt);
+							oci_free_statement($stmt);
 							return true;
 						}
                         return $stmt;
                     }
                     break;
                 default :
-					// ociclose -- no because it could be used in a LOB?
+					
                     return true;
             }
 		}
@@ -1186,14 +1200,14 @@ NATSOFT.DOMAIN =
 	{
 		if (!$this->_connectionID) return;
 		
-		if (!$this->autoCommit) OCIRollback($this->_connectionID);
+		if (!$this->autoCommit) oci_rollback($this->_connectionID);
 		if (count($this->_refLOBs) > 0) {
 			foreach ($this ->_refLOBs as $key => $value) {
 				$this->_refLOBs[$key]['LOB']->free();
 				unset($this->_refLOBs[$key]);
 			}
 		}
-		OCILogoff($this->_connectionID);
+		oci_close($this->_connectionID);
 		
 		$this->_stmt = false;
 		$this->_connectionID = false;
@@ -1233,8 +1247,17 @@ SELECT /*+ RULE */ distinct b.column_name
 		else return false;
 	}
 	
-	// http://gis.mit.edu/classes/11.521/sqlnotes/referential_integrity.html
-	function MetaForeignKeys($table, $owner=false)
+	/**
+	 * returns assoc array where keys are tables, and values are foreign keys
+	 *
+	 * @param	str		$table
+	 * @param	str		$owner	[optional][default=NULL]
+	 * @param	bool	$upper	[optional][discarded]
+	 * @return	mixed[]			Array of foreign key information
+	 *
+	 * @link http://gis.mit.edu/classes/11.521/sqlnotes/referential_integrity.html
+	 */
+	function MetaForeignKeys($table, $owner=false, $upper=false)
 	{
 	global $ADODB_FETCH_MODE;
 	
@@ -1288,11 +1311,11 @@ SELECT /*+ RULE */ distinct b.column_name
 	 * Quotes a string.
 	 * An example is  $db->qstr("Don't bother",magic_quotes_runtime());
 	 * 
-	 * @param s			the string to quote
-	 * @param [magic_quotes]	if $s is GET/POST var, set to get_magic_quotes_gpc().
+	 * @param string $s the string to quote
+	 * @param bool $magic_quotes if $s is GET/POST var, set to get_magic_quotes_gpc().
 	 *				This undoes the stupidity of magic quotes for GPC.
 	 *
-	 * @return  quoted string to be sent back to database
+	 * @return string quoted string to be sent back to database
 	 */
 	function qstr($s,$magic_quotes=false)
 	{	
@@ -1360,12 +1383,13 @@ class ADORecordset_oci8 extends ADORecordSet {
 			
 			$this->_currentRow = 0;
 			@$this->_initrs();
-			$this->EOF = !$this->_fetch();
+			if ($this->_numOfFields) $this->EOF = !$this->_fetch();
+			else $this->EOF = true;
 			
 			/*
 			// based on idea by Gaetano Giunta to detect unusual oracle errors
 			// see http://phplens.com/lens/lensforum/msgs.php?id=6771
-			$err = OCIError($this->_queryID);
+			$err = oci_error($this->_queryID);
 			if ($err && $this->connection->debug) ADOConnection::outp($err);
 			*/
 			
@@ -1384,7 +1408,7 @@ class ADORecordset_oci8 extends ADORecordSet {
 	function _initrs()
 	{
 		$this->_numOfRows = -1;
-		$this->_numOfFields = OCInumcols($this->_queryID);
+		$this->_numOfFields = oci_num_fields($this->_queryID);
 		if ($this->_numOfFields>0) {
 			$this->_fieldobjs = array();
 			$max = $this->_numOfFields;
@@ -1392,22 +1416,26 @@ class ADORecordset_oci8 extends ADORecordSet {
 		}
 	}
 
-	  /*		Returns: an object containing field information.
-			  Get column information in the Recordset object. fetchField() can be used in order to obtain information about
-			  fields in a certain query result. If the field offset isn't specified, the next field that wasn't yet retrieved by
-			  fetchField() is retrieved.		*/
-
+	/**
+	 * Get column information in the Recordset object.
+	 * fetchField() can be used in order to obtain information about fields
+	 * in a certain query result. If the field offset isn't specified, the next
+	 * field that wasn't yet retrieved by fetchField() is retrieved
+	 *
+	 * @return object containing field information
+	 */
 	function _FetchField($fieldOffset = -1)
 	{
 		$fld = new ADOFieldObject;
 		$fieldOffset += 1;
-		$fld->name =OCIcolumnname($this->_queryID, $fieldOffset);
-		$fld->type = OCIcolumntype($this->_queryID, $fieldOffset);
-		$fld->max_length = OCIcolumnsize($this->_queryID, $fieldOffset);
+		$fld->name =oci_field_name($this->_queryID, $fieldOffset);
+		$fld->type = oci_field_type($this->_queryID, $fieldOffset);
+		$fld->max_length = oci_field_size($this->_queryID, $fieldOffset);
+
 	 	switch($fld->type) {
 		case 'NUMBER':
-	 		$p = OCIColumnPrecision($this->_queryID, $fieldOffset);
-			$sc = OCIColumnScale($this->_queryID, $fieldOffset);
+	 		$p = oci_field_precision($this->_queryID, $fieldOffset);
+			$sc = oci_field_scale($this->_queryID, $fieldOffset);
 			if ($p != 0 && $sc == 0) $fld->type = 'INT';
 			$fld->scale = $p;
 			break;
@@ -1421,14 +1449,14 @@ class ADORecordset_oci8 extends ADORecordSet {
 		return $fld;
 	}
 	
-	/* For some reason, OCIcolumnname fails when called after _initrs() so we cache it */
+	/* For some reason, oci_field_name fails when called after _initrs() so we cache it */
 	function FetchField($fieldOffset = -1)
 	{
 		return $this->_fieldobjs[$fieldOffset];
 	}
 	
 	
-	/*
+/*
 	// 10% speedup to move MoveNext to child class
 	function _MoveNext() 
 	{
@@ -1437,17 +1465,18 @@ class ADORecordset_oci8 extends ADORecordSet {
 		if ($this->EOF) return false;
 		
 		$this->_currentRow++;
-		if(@OCIfetchinto($this->_queryID,$this->fields,$this->fetchMode))
+		if($this->fields = @oci_fetch_array($this->_queryID,$this->fetchMode))
 			return true;
 		$this->EOF = true;
 		
 		return false;
-	}	*/
+	}
+*/
 	
 	
 	function MoveNext()
 	{
-		if (@OCIfetchinto($this->_queryID,$this->fields,$this->fetchMode)) {
+		if ($this->fields = @oci_fetch_array($this->_queryID,$this->fetchMode)) {
 			$this->_currentRow += 1;
 			return true;
 		}
@@ -1458,7 +1487,7 @@ class ADORecordset_oci8 extends ADORecordSet {
 		return false;
 	}
 	
-	/*
+/*
 	# does not work as first record is retrieved in _initrs(), so is not included in GetArray()
 	function GetArray($nRows = -1) 
 	{
@@ -1467,18 +1496,18 @@ class ADORecordset_oci8 extends ADORecordSet {
 		if (true ||  !empty($ADODB_OCI8_GETARRAY)) {
 			# does not support $ADODB_ANSI_PADDING_OFF
 	
-			//OCI_RETURN_NULLS and OCI_RETURN_LOBS is set by OCIfetchstatement
+			//OCI_RETURN_NULLS and OCI_RETURN_LOBS is set by oci_fetch_all
 			switch($this->adodbFetchMode) {
 			case ADODB_FETCH_NUM:
 			
-				$ncols = @OCIfetchstatement($this->_queryID, $results, 0, $nRows, OCI_FETCHSTATEMENT_BY_ROW+OCI_NUM);
+				$ncols = @oci_fetch_all($this->_queryID, $results, 0, $nRows, oci_fetch_all_BY_ROW+OCI_NUM);
 				$results = array_merge(array($this->fields),$results);
 				return $results;
 				
 			case ADODB_FETCH_ASSOC: 
 				if (ADODB_ASSOC_CASE != 2 || $this->databaseType != 'oci8') break;
 				
-				$ncols = @OCIfetchstatement($this->_queryID, $assoc, 0, $nRows, OCI_FETCHSTATEMENT_BY_ROW);
+				$ncols = @oci_fetch_all($this->_queryID, $assoc, 0, $nRows, oci_fetch_all_BY_ROW);
 				$results = array_merge(array($this->fields),$assoc);
 				return $results;
 			
@@ -1490,9 +1519,10 @@ class ADORecordset_oci8 extends ADORecordSet {
 		$results = ADORecordSet::GetArray($nRows);
 		return $results;
 		
-	} */
+	}
+*/
 	
-	/* Optimize SelectLimit() by using OCIFetch() instead of OCIFetchInto() */
+	// Optimize SelectLimit() by using oci_fetch()
 	function GetArrayLimit($nrows,$offset=-1) 
 	{
 		if ($offset <= 0) {
@@ -1501,9 +1531,9 @@ class ADORecordset_oci8 extends ADORecordSet {
 		}
 		$arr = array();
 		for ($i=1; $i < $offset; $i++) 
-			if (!@OCIFetch($this->_queryID)) return $arr;
+			if (!@oci_fetch($this->_queryID)) return $arr;
 			
-		if (!@OCIfetchinto($this->_queryID,$this->fields,$this->fetchMode)) return $arr;;
+		if (!$this->fields = @oci_fetch_array($this->_queryID,$this->fetchMode)) return $arr;;
 		$results = array();
 		$cnt = 0;
 		while (!$this->EOF && $nrows != $cnt) {
@@ -1515,7 +1545,7 @@ class ADORecordset_oci8 extends ADORecordSet {
 	}
 
 	
-	/* Use associative array to get fields array */
+	// Use associative array to get fields array
 	function Fields($colname)
 	{
 		if (!$this->bind) {
@@ -1538,31 +1568,42 @@ class ADORecordset_oci8 extends ADORecordSet {
 
 	function _fetch() 
 	{
-		return @OCIfetchinto($this->_queryID,$this->fields,$this->fetchMode);
+		return $this->fields = @oci_fetch_array($this->_queryID,$this->fetchMode);
 	}
 
-	/*		close() only needs to be called if you are worried about using too much memory while your script
-			is running. All associated result memory for the specified result identifier will automatically be freed.		*/
-
+	/**
+	 * close() only needs to be called if you are worried about using too much
+	 * memory while your script is running. All associated result memory for the
+	 * specified result identifier will automatically be freed.
+	 */
 	function _close() 
 	{
 		if ($this->connection->_stmt === $this->_queryID) $this->connection->_stmt = false;
 		if (!empty($this->_refcursor)) {
-			OCIFreeCursor($this->_refcursor);
+			oci_free_cursor($this->_refcursor);
 			$this->_refcursor = false;
 		}
-		@OCIFreeStatement($this->_queryID);
+		@oci_free_statement($this->_queryID);
  		$this->_queryID = false;
-		
 	}
 
-	function MetaType($t,$len=-1)
+	/**
+	 * not the fastest implementation - quick and dirty - jlim
+	 * for best performance, use the actual $rs->MetaType().
+	 *
+	 * @param	mixed	$t
+	 * @param	int		$len		[optional] Length of blobsize
+	 * @param	bool	$fieldobj	[optional][discarded]
+	 * @return	str					The metatype of the field
+	 */
+	function MetaType($t, $len=-1, $fieldobj=false)
 	{
 		if (is_object($t)) {
 			$fieldobj = $t;
 			$t = $fieldobj->type;
 			$len = $fieldobj->max_length;
 		}
+
 		switch (strtoupper($t)) {
 	 	case 'VARCHAR':
 	 	case 'VARCHAR2':
@@ -1596,7 +1637,8 @@ class ADORecordset_oci8 extends ADORecordSet {
 		case 'INTEGER': 
 			return 'I';
 			
-		default: return 'N';
+		default:
+			return 'N';
 		}
 	}
 }
@@ -1625,4 +1667,3 @@ class ADORecordSet_ext_oci8 extends ADORecordSet_oci8 {
 		return adodb_movenext($this);
 	}
 }
-?>
\ No newline at end of file
