@@ -1,6 +1,6 @@
 <?php
 /* 
-V4.80 8 Mar 2006  (c) 2000-2007 John Lim (jlim#natsoft.com.my). All rights reserved.
+V5.19  23-Apr-2014  (c) 2000-2014 John Lim (jlim#natsoft.com). All rights reserved.
   Released under both BSD license and Lesser GPL library license. 
   Whenever there is any discrepancy between the two licenses, 
   the BSD license will take precedence. 
@@ -10,7 +10,7 @@ V4.80 8 Mar 2006  (c) 2000-2007 John Lim (jlim#natsoft.com.my). All rights reser
 */
 
 
-if (!defined('E_STRICT')) define('E_STRICT',E_NOTICE);
+//if (!defined('E_STRICT')) define('E_STRICT',0);
 error_reporting(E_ALL|E_STRICT);
 
 $ADODB_FLUSH = true;
@@ -125,11 +125,14 @@ FROM `nuke_stories` `t1`, `nuke_authors` `t2`, `nuke_stories_cat` `t3`, `nuke_to
 	$phpv = phpversion();
 	if (defined('ADODB_EXTENSION')) $ext = ' &nbsp; Extension '.ADODB_EXTENSION.' installed';
 	else $ext = '';
-	print "<h3>ADODB Version: $ADODB_vers Host: <i>$db->host</i> &nbsp; Database: <i>$db->database</i> &nbsp; PHP: $phpv $ext</h3>";
+	print "<h3>ADODB Version: $ADODB_vers";
+	print "<p>Host: <i>$db->host</i>";
+	print "<br>Database: <i>$db->database</i>";
+	print "<br>PHP: <i>$phpv $ext</i></h3>";
 	
 	flush();
 
-	if (function_exists('date_default_timezone_set')) date_default_timezone_set('Asia/Kuala_Lumpur');
+	print "Current timezone: " . date_default_timezone_get() . "<p>";
 	
 	$arr = $db->ServerInfo();
 	print_r($arr);
@@ -146,11 +149,12 @@ FROM `nuke_stories` `t1`, `nuke_authors` `t2`, `nuke_stories_cat` `t3`, `nuke_to
 	echo "Date=",$db->UserDate('2002-04-07'),'<br>';
 	print "<i>date1</i> (1969-02-20) = ".$db->DBDate('1969-2-20');
 	print "<br><i>date1</i> (1999-02-20) = ".$db->DBDate('1999-2-20');
-	print "<br><i>date1.1</i> 1999 = ".$db->DBDate("'1999'");
+	print "<br><i>date1.1</i> 1999 injection attack= ".$db->DBDate("'1999', ' injection attack '");
 	print "<br><i>date2</i> (1970-1-2) = ".$db->DBDate(24*3600)."<p>";
 	print "<i>ts1</i> (1999-02-20 13:40:50) = ".$db->DBTimeStamp('1999-2-20 1:40:50 pm');
 	print "<br><i>ts1.1</i> (1999-02-20 13:40:00) = ".$db->DBTimeStamp('1999-2-20 13:40');
 	print "<br><i>ts2</i> (1999-02-20) = ".$db->DBTimeStamp('1999-2-20');
+	print "<br><i>ts2</i> (1999-02-20) = ".$db->DBTimeStamp("'1999-2-20', 'injection attack'");
 	print "<br><i>ts3</i> (1970-1-2 +/- timezone) = ".$db->DBTimeStamp(24*3600);
 	print "<br> Fractional TS (1999-2-20 13:40:50.91): ".$db->DBTimeStamp($db->UnixTimeStamp('1999-2-20 13:40:50.91+1'));
 	 $dd = $db->UnixDate('1999-02-20');
@@ -483,7 +487,7 @@ GO
 		/*
 		CREATE TABLE PHOTOS
 		(
-		  ID           NUMBER(16),
+		  ID           NUMBER(16) primary key,
 		  PHOTO        BLOB,
 		  DESCRIPTION  VARCHAR2(4000 BYTE),
 		  DESCCLOB     CLOB
@@ -596,7 +600,7 @@ END Adodb;
 		} else {
 			print "<b>Error in using Cursor Variables 1</b><p>";
 		}
-		$rs->Close();
+		if ($rs) $rs->Close();
 		
 		print "<h4>Testing Stored Procedures for oci8</h4>";
 		
@@ -637,11 +641,18 @@ END Adodb;
 	);
 	//$db->debug=1;
 	print "<p>Testing Bulk Insert of 3 rows</p>";
+	
+//	$db->debug=1;
+//	$db->Execute('select * from table where val=? AND value=?', array('val'=>'http ://www.whatever.com/test?=21', 'value'=>'blabl'));
+
 
 	$sql = "insert into ADOXYZ (id,firstname,lastname) values (".$db->Param('0').",".$db->Param('1').",".$db->Param('2').")";
+	$db->bulkBind = true;
 	$db->StartTrans();
+	$db->debug=99;
 	$db->Execute($sql,$arr);
 	$db->CompleteTrans();
+	$db->bulkBind = false;
 	$rs = $db->Execute('select * from ADOXYZ order by id');
 	if (!$rs || $rs->RecordCount() != 3) Err("Bad bulk insert");
 	
@@ -841,19 +852,27 @@ END Adodb;
 	$ADODB_FETCH_MODE = ADODB_FETCH_ASSOC;
 	
 	print "<p>CacheSelectLimit  Test...</p>";
-	$db->debug=1;
 	$rs = $db->CacheSelectLimit('select  id, firstname from  ADOXYZ order by id',2);
 	
+	if (ADODB_ASSOC_CASE == 2 || $db->dataProvider == 'oci8') {
+		$id = 'ID';
+		$fname = 'FIRSTNAME';
+	}else {
+		$id = 'id';
+		$fname = 'firstname';
+	}
+	
+	
 	if ($rs && !$rs->EOF) {
 		if (isset($rs->fields[0])) {
 			Err("ASSOC has numeric fields");
 			print_r($rs->fields);
 		}
-		if ($rs->fields['id'] != 1)  {Err("Error"); print_r($rs->fields);};
-		if (trim($rs->fields['firstname']) != 'Caroline')  {print Err("Error 2"); print_r($rs->fields);};
+		if ($rs->fields[$id] != 1)  {Err("Error"); print_r($rs->fields);};
+		if (trim($rs->fields[$fname]) != 'Caroline')  {print Err("Error 2"); print_r($rs->fields);};
 		
 		$rs->MoveNext();
-		if ($rs->fields['id'] != 2)  {Err("Error 3"); print_r($rs->fields);};
+		if ($rs->fields[$id] != 2)  {Err("Error 3"); print_r($rs->fields);};
 		$rs->MoveNext();
 		if (!$rs->EOF) {
 			Err("Error EOF");
@@ -861,16 +880,10 @@ END Adodb;
 		}
 	}
 	
-	print "<p>FETCH_MODE = ASSOC: Should get 1, Caroline</p>";
+	print "<p>FETCH_MODE = ASSOC: Should get 1, Caroline ASSOC_CASE=".ADODB_ASSOC_CASE."</p>";
 	$rs = $db->SelectLimit('select id,firstname from ADOXYZ order by id',2);
 	if ($rs && !$rs->EOF) {
-		if (ADODB_ASSOC_CASE == 2) {
-			$id = 'ID';
-			$fname = 'FIRSTNAME';
-		}else {
-			$id = 'id';
-			$fname = 'firstname';
-		}
+
 		if ($rs->fields[$id] != 1)  {Err("Error 1"); print_r($rs->fields);};
 		if (trim($rs->fields[$fname]) != 'Caroline')  {Err("Error 2"); print_r($rs->fields);};
 		$rs->MoveNext();
@@ -887,7 +900,7 @@ END Adodb;
 	print "<p>FETCH_MODE = NUM: Should get 1, Caroline</p>";
 	$rs = $db->SelectLimit('select id,firstname from ADOXYZ order by id',1);
 	if ($rs && !$rs->EOF) {
-		if (isset($rs->fields['id'])) Err("FETCH_NUM has ASSOC fields");
+		if (isset($rs->fields[$id])) Err("FETCH_NUM has ASSOC fields");
 		if ($rs->fields[0] != 1)  {Err("Error 1"); print_r($rs->fields);};
 		if (trim($rs->fields[1]) != 'Caroline')  {Err("Error 2");print_r($rs->fields);};
 		$rs->MoveNext();
@@ -901,8 +914,9 @@ END Adodb;
 	$rs = $db->SelectLimit('select id,firstname from ADOXYZ order by id',1);
 	if ($rs && !$rs->EOF) {
 		$arr = $rs->GetRowAssoc();
-		if ($arr['ID'] != 1) {Err("Error 1");print_r($arr);};
-		if (trim($arr['FIRSTNAME']) != 'Caroline') {Err("Error 2"); print_r($arr);};
+		
+		if ($arr[strtoupper($id)] != 1) {Err("Error 1");print_r($arr);};
+		if (trim($arr[strtoupper($fname)]) != 'Caroline') {Err("Error 2"); print_r($arr);};
 		$rs->MoveNext();
 		if (!$rs->EOF) Err("Error EOF");
 
@@ -920,6 +934,11 @@ END Adodb;
 	$col = $db->GetCol('select distinct firstname from ADOXYZ order by 1');
 	if (!is_array($col)) Err("Col size is wrong");
 	if (trim($col[0]) != 'Alan' or trim($col[9]) != 'Yat Sun') Err("Col elements wrong");
+	
+	
+	$col = $db->CacheGetCol('select distinct firstname from ADOXYZ order by 1');
+	if (!is_array($col)) Err("Col size is wrong");
+	if (trim($col[0]) != 'Alan' or trim($col[9]) != 'Yat Sun') Err("Col elements wrong");
 
 	$db->debug = true;
 	
@@ -1086,6 +1105,15 @@ END Adodb;
 		if (sizeof($arr) != 2) Err("Prepare failed 3");
 	}
 	print "Testing GetAssoc() ";
+	
+	
+	if ($db->dataProvider == 'mysql') {
+		$ADODB_FETCH_MODE = ADODB_FETCH_ASSOC;
+		$arr = $db->GetAssoc("SELECT 'adodb', '0'");
+		var_dump($arr);
+		die();
+	}
+	
 	$savecrecs = $ADODB_COUNTRECS;
 	$ADODB_COUNTRECS = false;
 	//$arr = $db->GetArray("select  lastname,firstname from ADOXYZ");
@@ -1166,12 +1194,12 @@ END Adodb;
 	$ADODB_FETCH_MODE = ADODB_FETCH_NUM;
 	$rs = $db->CacheExecute(6,"select distinct firstname,lastname from ADOXYZ");
 	print_r($rs->fields); echo $rs->fetchMode;echo "<br>";
-	echo $rs->Fields('firstname');
+	echo $rs->Fields($fname);
 	
 	$ADODB_FETCH_MODE = ADODB_FETCH_ASSOC;
 	$rs = $db->CacheExecute(6,"select distinct firstname,lastname from ADOXYZ");
 	print_r($rs->fields);echo "<br>";
-	echo $rs->Fields('firstname');
+	echo $rs->Fields($fname);
 	$db->debug = false;
 	
 	$ADODB_FETCH_MODE = ADODB_FETCH_NUM;
@@ -1213,7 +1241,7 @@ END Adodb;
 	
 	echo "<p> GenID test: ";
 	for ($i=1; $i <= 10; $i++) 
-		echo  "($i: ",$val = $db->GenID($db->databaseType.'abcseq6' ,5), ") ";
+		echo  "($i: ",$val = $db->GenID($db->databaseType.'abcseq7' ,5), ") ";
 	if ($val == 0) Err("GenID not supported");
 	
 	if ($val) {
@@ -1327,8 +1355,8 @@ END Adodb;
 		rs2tabout($rs);
 		print "</pre>";
 	}
-	print " CacheFlush ";
-	$db->CacheFlush();
+	#print " CacheFlush ";
+	#$db->CacheFlush();
 	
 	$date = $db->SQLDate('d-m-M-Y-\QQ h:i:s A');
 	$sql = "SELECT $date from ADOXYZ";
@@ -1338,7 +1366,12 @@ END Adodb;
 	if (!$rs) Err("SQLDate query returned no recordset");
 	else if ($d != $rs->fields[0]) Err("SQLDate 1 failed expected: <br>act:$d <br>sql:".$rs->fields[0]);
 	
-	$date = $db->SQLDate('d-m-M-Y-\QQ h:i:s A',$db->DBDate("1974-02-25"));
+	$dbdate = $db->DBDate("1974-02-25");
+	if (substr($db->dataProvider, 0, 8) == 'postgres') {
+		$dbdate .= "::TIMESTAMP";
+	}
+
+	$date = $db->SQLDate('d-m-M-Y-\QQ h:i:s A', $dbdate);
 	$sql = "SELECT $date from ADOXYZ";
 	print "<p>Test SQLDate: ".htmlspecialchars($sql)."</p>";
 	$db->debug=1;
@@ -1435,7 +1468,7 @@ END Adodb;
 	if ($rs) rs2html($rs);
 	else Err("Pivot sql error");
 	
-	$pear = true; //true;
+	$pear = false; //true;
 	$db->debug=false;
 	
 	if ($pear) {
@@ -1709,11 +1742,7 @@ foreach($_GET as $k=>$v)  {
 	//global $$k;
 	$$k = $v;
 }	
-if (strpos(PHP_VERSION,'5') === 0) {
-	//$testaccess=1;
-	//$testmssql = 1;
-	//$testsqlite=1;
-}
+
 ?>
 <html>
 <title>ADODB Testing</title>
@@ -1729,15 +1758,19 @@ Test <a href=test4.php>GetInsertSQL/GetUpdateSQL</a> &nbsp;
 	<a href=testpaging.php>Paging</a> &nbsp;
 	<a href=test-perf.php>Perf Monitor</a><p>
 <?php
-include('./testdatabases.inc.php');
-
-echo "<br>vers=",ADOConnection::Version();
 
 
 include_once('../adodb-time.inc.php');
 if (isset($_GET['time'])) adodb_date_test();
+flush();
+
+include_once('./testdatabases.inc.php');
+
+echo "<br>vers=",ADOConnection::Version();
+
+
 
 ?>
-<p><i>ADODB Database Library  (c) 2000-2007 John Lim. All rights reserved. Released under BSD and LGPL, PHP <?php echo PHP_VERSION ?>.</i></p>
+<p><i>ADODB Database Library  (c) 2000-2014 John Lim. All rights reserved. Released under BSD and LGPL, PHP <?php echo PHP_VERSION ?>.</i></p>
 </body>
 </html>
