@@ -1,7 +1,7 @@
 <?php
   
 /*
-V4.80 8 Mar 2006  (c) 2000-2010 John Lim (jlim#natsoft.com). All rights reserved.
+V5.19  23-Apr-2014  (c) 2000-2014 John Lim (jlim#natsoft.com). All rights reserved.
   Released under both BSD license and Lesser GPL library license. 
   Whenever there is any discrepancy between the two licenses, 
   the BSD license will take precedence.
@@ -15,7 +15,7 @@ V4.80 8 Mar 2006  (c) 2000-2010 John Lim (jlim#natsoft.com). All rights reserved
 <input type=checkbox name="testaccess" value=1 <?php echo !empty($testaccess) ? 'checked' : '' ?>> <b>Access</b><br>
 <input type=checkbox name="testibase" value=1 <?php echo !empty($testibase) ? 'checked' : '' ?>> <b>Interbase</b><br>
 <input type=checkbox name="testmssql" value=1 <?php echo !empty($testmssql) ? 'checked' : '' ?>> <b>MSSQL</b><br>
- <input type=checkbox name="testmysql" value=1 <?php echo !empty($testmysql) ? 'checked' : '' ?>> <b>MySQL</b><br>
+<input type=checkbox name="testmysql" value=1 <?php echo !empty($testmysql) ? 'checked' : '' ?>> <b>MySQL</b><br>
 <input type=checkbox name="testmysqlodbc" value=1 <?php echo !empty($testmysqlodbc) ? 'checked' : '' ?>> <b>MySQL ODBC</b><br>
 <input type=checkbox name="testmysqli" value=1 <?php echo !empty($testmysqli) ? 'checked' : '' ?>> <b>MySQLi</b>
 <br>
@@ -23,6 +23,7 @@ V4.80 8 Mar 2006  (c) 2000-2010 John Lim (jlim#natsoft.com). All rights reserved
 <input type=checkbox name="testproxy" value=1 <?php echo !empty($testproxy) ? 'checked' : '' ?>> <b>MySQL Proxy</b><br>
 <input type=checkbox name="testoracle" value=1 <?php echo !empty($testoracle) ? 'checked' : '' ?>> <b>Oracle (oci8)</b> <br>
 <input type=checkbox name="testpostgres" value=1 <?php echo !empty($testpostgres) ? 'checked' : '' ?>> <b>PostgreSQL</b><br>
+<input type=checkbox name="testpostgres9" value=1 <?php echo !empty($testpostgres9) ? 'checked' : '' ?>> <b>PostgreSQL 9</b><br>
 <input type=checkbox name="testpgodbc" value=1 <?php echo !empty($testpgodbc) ? 'checked' : '' ?>> <b>PostgreSQL ODBC</b><br>
 <td>
 <input type=checkbox name="testpdopgsql" value=1 <?php echo !empty($testpdopgsql) ? 'checked' : '' ?>> <b>PgSQL PDO</b><br>
@@ -63,7 +64,7 @@ if (sizeof($_GET) || !isset($_SERVER['HTTP_HOST'])) {
 	ADOLoadCode2('mysqli');
 	if (defined('ODBC_BINMODE_RETURN')) {
 		ADOLoadCode2("sqlanywhere");
-	ADOLoadCode2("access");
+		ADOLoadCode2("access");
 	}
 	ADOLoadCode2("mysql");
 	ADOLoadCode2("oci8");
@@ -77,15 +78,38 @@ function ADOLoadCode2($d)
 }
 
 flush();
+
+// dregad 2014-04-15 added serial field to avoid error with lastval()
+$pg_test_table = "create table ADOXYZ (id integer, firstname char(24), lastname varchar,created date, ser serial)";
+$pg_hostname = 'localhost';
+$pg_user = 'tester';
+$pg_password = 'test';
+$pg_database = 'northwind';
+$pg_errmsg = "ERROR: PostgreSQL requires a database called '$pg_database' "
+	. "on server '$pg_hostname', user '$pg_user', password '$pg_password'.<BR>";
+
 if (!empty($testpostgres)) {
 	//ADOLoadCode("postgres");
 
 	$db = ADONewConnection('postgres');
 	print "<h1>Connecting $db->databaseType...</h1>";
-	if ($db->Connect("localhost","tester","test","test")) {
-		testdb($db,"create table ADOXYZ (id integer, firstname char(24), lastname varchar,created date)");
-	}else
-		print "ERROR: PostgreSQL requires a database called test on server, user tester, password test.<BR>".$db->ErrorMsg();
+	if ($db->Connect($pg_hostname, $pg_user, $pg_password, $pg_database)) {
+		testdb($db, $pg_test_table);
+	} else {
+		print $pg_errmsg . $db->ErrorMsg();
+	}
+}
+
+if (!empty($testpostgres9)) {
+	//ADOLoadCode("postgres");
+
+	$db = ADONewConnection('postgres9');
+	print "<h1>Connecting $db->databaseType...</h1>";
+	if ($db->Connect($pg_hostname, $pg_user, $pg_password, $pg_database)) {
+		testdb($db, $pg_test_table);
+	} else {
+		print $pg_errmsg . $db->ErrorMsg();
+	}
 }
 
 if (!empty($testpgodbc)) { 
@@ -308,12 +332,12 @@ ADOLoadCode('oci805');
 ADOLoadCode("oci8po");
 	
 if (!empty($testoracle)) {
-	$dsn = "oci8po";//://scott:natsoft@kk2?persist";
+	$dsn = "oci8";//://scott:natsoft@kk2?persist";
 	$db = ADONewConnection($dsn );//'oci8');
 	
 	//$db->debug=1;
 	print "<h1>Connecting $db->databaseType...</h1>";
-	if ($db->Connect('192.168.0.138', "scott", "natsoft",'SID=natsoft'))
+	if ($db->Connect('mobydick', "scott", "natsoft",'SID=mobydick'))
 		testdb($db,"create table ADOXYZ (id int, firstname varchar(24), lastname varchar(24),created date)");
 	else 
 		print "ERROR: Oracle test requires an Oracle server setup with scott/natsoft".'<BR>'.$db->ErrorMsg();
@@ -450,5 +474,3 @@ if (extension_loaded('odbtp') && !empty($testmssql)) { // MS SQL Server via ODBC
 
 
 print "<h3>Tests Completed</h3>";
-
-?>
