@@ -62,7 +62,7 @@
 *    perhaps even message/partial.
 *
 * @author  Richard Heyes <richard@phpguru.org>
-* @version $Revision: 10166 $
+* @version $Revision: 13891 $
 * @package phpgwapi
 * @subpackage communication
 */
@@ -130,7 +130,7 @@ class Mail_mimeDecode
      * @param string The input to decode
      * @access public
      */
-    function Mail_mimeDecode($input)
+    function __construct($input)
     {
         list($header, $body)   = $this->_splitBodyHeader($input);
 
@@ -803,4 +803,4 @@ class Mail_mimeDecode
     }
 
 } // End of class
-?>
+
