@@ -132,7 +132,7 @@ class Services_JSON
     *                                   bubble up with an error, so all return values
     *                                   from encode() should be checked with isError()
     */
-    function Services_JSON($use = 0)
+    function __construct($use = 0)
     {
         $this->use = $use;
     }
@@ -797,5 +797,4 @@ if (class_exists('pear_error')) {
     }
 
 }
-    
-?>
+ 
\ No newline at end of file
