@@ -8,7 +8,7 @@
  * @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
  * @package phpgwapi
  * @subpackage gui
- * @version $Id: class.Template.inc.php 10166 2012-10-09 07:54:03Z sigurdne $
+ * @version $Id: class.Template.inc.php 13891 2015-09-14 19:31:31Z sigurdne $
  * @internal Based on phplib
  *
  */
@@ -160,7 +160,7 @@ class Template
 	 * @access    public
 	 * @return    void
 	 */
-	function Template($root = ".", $unknowns = "remove") {
+	function __construct($root = ".", $unknowns = "remove") {
 		if ($this->debug & 4) {
 			echo "<p><b>Template:</b> root = $root, unknowns = $unknowns</p>\n";
 		}
@@ -1028,4 +1028,3 @@ class Template
 	}
 
 }
-?>
