@@ -7,7 +7,7 @@
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage utilities
-	* @version $Id: class.arrayfunctions.inc.php 10166 2012-10-09 07:54:03Z sigurdne $
+	* @version $Id: class.arrayfunctions.inc.php 13891 2015-09-14 19:31:31Z sigurdne $
 	*/
 
 	/**
@@ -18,7 +18,7 @@
 	*/
 	class arrayfunctions
 	{
-		function arrayfunctions($vars='')
+		function __construct($vars='')
 		{
 		}
 
@@ -75,4 +75,3 @@
 		}
 
 	}
-?>
