@@ -6,7 +6,7 @@
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage application
-	* @version $Id: class.asyncservice.inc.php 10166 2012-10-09 07:54:03Z sigurdne $
+	* @version $Id: class.asyncservice.inc.php 13979 2015-09-21 13:16:45Z sigurdne $
 	*/
 
 	/**
@@ -39,7 +39,7 @@
 		/**
 		* Constructor
 		*/
-		function asyncservice()
+		function __construct()
 		{
 			$this->db =& $GLOBALS['phpgw']->db;
 			$this->cronline = PHPGW_SERVER_ROOT . '/phpgwapi/cron/asyncservices.php '.$GLOBALS['phpgw_info']['user']['domain'];
@@ -384,6 +384,7 @@
 		*/
 		function check_run($run_by='')
 		{
+			@set_time_limit(0);		// dont stop for an execution-time-limit
 			flush();
 			$error = false;
 
@@ -427,8 +428,19 @@
 					{
 						try
 						{
-							echo "{$job['method']}\n";
+							echo 'Start job: ' . date('Y/m/d H:i:s ') . "\n";
+							echo "--id: {$job['id']}\n";
+							echo "--method: {$job['method']}\n";
+							if(isset($job['data']) && $job['data'])
+							{
+								echo "--data: ";
+								print_r($job['data']);
+								echo "\n";
+							}
 							ExecMethod($job['method'],$job['data']);
+
+							echo 'End job: ' . date('Y/m/d H:i:s ') . "\n\n";
+
 						}
 						catch (Exception $e)
 						{
@@ -452,24 +464,24 @@
 
 					$GLOBALS['phpgw']->db->Exception_On_Error = $this->Exception_On_Error;
 
-						if ($job['next'] = $this->next_run($job['times']))
-						{
-							$updated_jobs = $this->read($id);
-							if (isset($updated_jobs[$id]) && isset($updated_jobs[$id]['data']))
-							{ // update async data field, it could be changed during ExecMethod()
-								$job['data'] = $updated_jobs[$id]['data'];
-							}
-							// TK 20.11.06 write job to get 'next' and alarm updated
-							$job['data']['time'] = $job['next'];
-							$this->write($job);
+					if ($job['next'] = $this->next_run($job['times']))
+					{
+						$updated_jobs = $this->read($id);
+						if (isset($updated_jobs[$id]) && isset($updated_jobs[$id]['data']))
+						{ // update async data field, it could be changed during ExecMethod()
+							$job['data'] = $updated_jobs[$id]['data'];
 						}
-						else	// no further runs
+						// TK 20.11.06 write job to get 'next' and alarm updated
+						$job['data']['time'] = $job['next'];
+						$this->write($job);
+					}
+					else	// no further runs
+					{
+						if($job['next'] <= time())
 						{
-							if($job['next'] <= time())
-							{
-								$this->delete($job['id']);
-							}
+							$this->delete($job['id']);
 						}
+					}
 
 				}
 			}
@@ -654,7 +666,7 @@
 				while ($line = fgets($crontab,256))
 				{
 					if ($this->debug) echo 'line '.++$n.": $line<br>\n";
-					$parts = split(' ',$line,6);
+					$parts = explode(' ',$line,6);
 
 					if ($line[0] == '#' || count($parts) < 6 || ($parts[5][0] != '/' && substr($parts[5],0,3) != 'php'))
 					{
