@@ -6,7 +6,7 @@
  * @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
  * @package phpgwapi
  * @subpackage utilities
- * @version $Id: class.calendar_holidays.inc.php 10166 2012-10-09 07:54:03Z sigurdne $
+ * @version $Id: class.calendar_holidays.inc.php 13891 2015-09-14 19:31:31Z sigurdne $
  * @internal Original ANSI-C code (C) 2003 Dipl.-Inform. Kai Hofmann <hofmann@hofmann-int.de>
  * @internal For more about calendar calculations see http://www.datelib.de/
  */
@@ -40,7 +40,7 @@
 	 *
 	 * @static
 	 */
-   function calendar_holidays()
+   function __construct()
    {
    }
    
@@ -566,5 +566,4 @@
  $cal_workdays = new calendar_holidays();
  $cal_workdays->add_number_of_workdays(31,5,2004,3,'Germany','Lower Saxony','Evangelic',$day,$month,$year);
  echo $year . '-' . $month . '-' . $day . "\n";
- */
-?>
\ No newline at end of file
+ */
\ No newline at end of file
