@@ -7,7 +7,7 @@
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage utilities
-	* @version $Id: class.categories.inc.php 11539 2013-12-17 10:28:17Z sigurdne $
+	* @version $Id: class.categories.inc.php 14719 2016-02-10 19:45:46Z sigurdne $
 	*/
 
 	/**
@@ -645,14 +645,17 @@
 		{
 			if(is_array($data))
 			{
-				$format			= isset($data['format']) ? $data['format'] : 'filter';
-				$type			= isset($data['type']) ? $data['type'] : 'all';
+				$format			= isset($data['format'])  && $data['format'] ? $data['format'] : 'filter';
+				$type			= isset($data['type']) && $data['type'] ? $data['type'] : 'all';
 				$selected		= isset($data['selected']) ? $data['selected'] : '';
 				$self			= isset($data['self']) ? $data['self'] : '';
-				$globals		= isset($data['globals']) ? $data['globals'] : true;
-				$link_data		= isset($data['link_data']) ? $data['link_data'] : array();
-				$select_name	= isset($data['select_name'])?$data['select_name'] : 'cat_id';
+				$globals		= isset($data['globals']) && $data['globals'] ? $data['globals'] : true;
+				$link_data		= isset($data['link_data']) && $data['link_data'] ? $data['link_data'] : array();
+				$select_name	= isset($data['select_name']) && $data['select_name'] ? $data['select_name'] : 'cat_id';
 				$use_acl		= isset($data['use_acl']) ? $data['use_acl'] : '';
+				$class			= isset($data['class']) && $data['class'] ? $data['class'] : 'forms';
+				$required		= isset($data['required']) && $data['required'] ? true : false;
+				$disabled		= isset($data['disabled']) && $data['disabled'] ? true : false;
 			}
 			else
 			{
@@ -690,6 +693,10 @@
 			$cat_list = array();
 			while (is_array($cats) && list(,$cat) = each($cats))
 			{
+				if($cat['active'] == 2 && !in_array($cat['id'],$selected))//hidden
+				{
+					continue;
+				}
 				$sel_cat = '';
 				if (in_array($cat['id'],$selected))
 				{
@@ -723,7 +730,10 @@
 				'lang_cat_statustext'	=> lang('Select the category the data belong to. To do not use a category select NO CATEGORY'),
 				'select_url'			=> $GLOBALS['phpgw']->link('/index.php', $link_data),
 				'select_name'			=> $select_name,
-				'lang_submit'			=> lang('submit')
+				'lang_submit'			=> lang('submit'),
+				'class'					=> $class,
+				'required'				=> $required,
+				'disabled'				=> $disabled
 			);
 			return $cat_data;
 		}
