@@ -6,7 +6,7 @@
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage contacts
-	* @version $Id: class.contact_comm.inc.php 10166 2012-10-09 07:54:03Z sigurdne $
+	* @version $Id: class.contact_comm.inc.php 13891 2015-09-14 19:31:31Z sigurdne $
 	*/
 
 	/**
@@ -235,7 +235,7 @@
 								 'sort'		=> '',
 								 'field'	=> 'comm_data'));
 		
-		function contact_comm ($ali = '', $field = '', $criteria = 	'')
+		function __construct ($ali = '', $field = '', $criteria = 	'')
 		{
 			$this->_constructor('phpgw_contact_comm', 'contact_comm');
 			if($field)
