@@ -6,7 +6,7 @@
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage contacts
-	* @version $Id: class.contact_person.inc.php 10166 2012-10-09 07:54:03Z sigurdne $
+	* @version $Id: class.contact_person.inc.php 13891 2015-09-14 19:31:31Z sigurdne $
 	*/
 
 	/**
@@ -282,7 +282,7 @@
 				 'people'		=> array('select'	=> 'relink_org_person'),
 				 'people_local'		=> array('select'	=> 'relink_org_person'));
 
-		function contact_person ($ali = '', $field = '', $criteria = 	'')
+		function __construct ($ali = '', $field = '', $criteria = 	'')
 		{
 			$this->_constructor('phpgw_contact_person', 'contact_person');
 			if($field)
