@@ -6,7 +6,7 @@
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage network
-	* @version $Id: class.crypto.inc.php 10166 2012-10-09 07:54:03Z sigurdne $
+	* @version $Id: class.crypto.inc.php 13891 2015-09-14 19:31:31Z sigurdne $
 	*/
 
 	/**
@@ -26,7 +26,7 @@
 		var $iv = '';
 		var $key = '';
 
-		function crypto($vars='')
+		function __construct($vars='')
 		{
 			if(is_array($vars))
 			{
