@@ -14,7 +14,7 @@
 	* @license http://www.fsf.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage gui
-	* @version $Id: class.csstooltip.inc.php 10166 2012-10-09 07:54:03Z sigurdne $
+	* @version $Id: class.csstooltip.inc.php 13891 2015-09-14 19:31:31Z sigurdne $
 	*/
 	
 	/**
@@ -31,7 +31,7 @@
 		*
 		* @access public
 		*/
-		function csstooltip()
+		function __construct()
 		{
 			if(!is_object($GLOBALS['phpgw']->css))
 			{
@@ -131,5 +131,4 @@
 		{
 			return '<a href="#" class="tooltip">'.$link_content.'<span class="tooltip"><span class="tooltip_headline">'.$tooltip_headline.'</span><span class="tooltip_line">&nbsp;</span><span class="tooltip_content">'.$tooltip_content.'</span></span></a>';
 		}
-	}
-?>
\ No newline at end of file
+	}
\ No newline at end of file
